import { jsx as _jsx } from "react/jsx-runtime";
import { Filters } from 'nmr-processing';
import { memo } from 'react';
import { useChartData } from '../context/ChartContext';
import { useScale } from '../context/ScaleContext';
import useSpectraByActiveNucleus from '../hooks/useSpectraPerNucleus';
import ExclusionZoneAnnotation from './ExclusionZoneAnnotation';
function ExclusionZonesAnnotationsInner({ displayerKey, xDomains, spectra, shiftY, }) {
    return (_jsx("g", { className: "spectrum-exclusion-zones-group", clipPath: `url(#${displayerKey}clip-chart-1d)`, children: spectra
            .filter((d) => d.display.isVisible && xDomains[d.id])
            .map((d, index) => getExclusionZones(d).map((record) => {
            return record.zones.map((zone) => {
                return (_jsx(ExclusionZoneAnnotation, { spectrumID: d.id, vAlign: shiftY * index, zone: zone, filterId: record.id, color: d.display.color }, zone.id));
            });
        })) }));
}
const MemoizedPeakAnnotations = memo(ExclusionZonesAnnotationsInner);
function ExclusionZonesAnnotations() {
    const { displayerKey, xDomains, displayerMode } = useChartData();
    const { shiftY } = useScale();
    const spectra = useSpectraByActiveNucleus();
    if (displayerMode !== '1D')
        return null;
    return (_jsx(MemoizedPeakAnnotations, { spectra: spectra, displayerKey: displayerKey, xDomains: xDomains, shiftY: shiftY }));
}
export default ExclusionZonesAnnotations;
function getExclusionZones(data) {
    const zones = [];
    for (const filter of data.filters) {
        if (filter.name === Filters.exclusionZones.id && filter.flag) {
            zones.push({ id: Filters.exclusionZones.id, zones: filter.value });
        }
        else if (filter.name === Filters.signalProcessing.id && filter.flag) {
            zones.push({
                id: Filters.signalProcessing.id,
                zones: filter.value.exclusionsZones,
            });
        }
    }
    return zones;
}
