import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { xFindClosestIndex } from 'ml-spectra-processing';
import { memo } from 'react';
import { BsCursor } from 'react-icons/bs';
import { IoPulseSharp } from 'react-icons/io5';
import { get1DDataXY } from '../../data/data1d/Spectrum1D/get1DDataXY';
import { useBrushTracker } from '../EventsTrackers/BrushTracker';
import { useMouseTracker } from '../EventsTrackers/MouseTracker';
import { useChartData } from '../context/ChartContext';
import { useScaleChecked } from '../context/ScaleContext';
import { useActiveSpectrum } from '../hooks/useActiveSpectrum';
import { useFormatNumberByNucleus } from '../hooks/useFormatNumberByNucleus';
import useSpectrum from '../hooks/useSpectrum';
const styles = css `
  display: flex;
  align-items: center;
  pointer-events: bounding-box;
  user-select: none;
  background-color: #f7f7f7;
  height: 30px;
  padding: 6px;
  color: #8d0018;
  position: absolute;
  width: 100%;
  bottom: 0;
  container-type: inline-size;

  @container (max-width:600px) {
    .small-width-none {
      display: none !important;
    }
  }

  .flex-row {
    display: flex;
    align-items: center;
  }

  div {
    margin: 0 10px;
    display: inline-block;

    .label {
      font-size: 12px;
      color: #4d4d4d;
      font-weight: bold;
    }

    .value {
      font-weight: bold;
      font-size: 14px;
      display: inline-block;
    }

    .unit {
      font-weight: bold;
      font-size: 10px;
    }

    .x-value {
      min-width: 50px;
    }

    .y-value {
      min-width: 80px;
    }
  }

  .separator {
    border-left: 2px solid gray;
    margin: 0 20px;
    width: 1px;
    height: 100%;
  }
`;
function FooterBannerInner({ margin, width, height, activeSpectrum, spectrum, activeTab, }) {
    const position = useMouseTracker();
    const { startX, endX, step, mouseButton } = useBrushTracker();
    const { scaleX } = useScaleChecked();
    const format = useFormatNumberByNucleus(activeTab);
    if (!position ||
        position.y < margin.top ||
        position.x < margin.left ||
        position.x > width - margin.right ||
        position.y > height - margin.bottom) {
        return _jsx("div", { css: styles });
    }
    function getXIndex(xPosition) {
        if (spectrum) {
            const data = get1DDataXY(spectrum);
            return xFindClosestIndex(data.x, scaleX().invert(xPosition));
        }
        return 0;
    }
    function getYValue(xPosition) {
        if (spectrum) {
            const data = get1DDataXY(spectrum);
            const xIndex = getXIndex(xPosition);
            return data.y[xIndex];
        }
        return 1;
    }
    const isBrushing = step === 'brushing' && mouseButton === 'main';
    return (_jsxs("div", { css: styles, children: [_jsx(BsCursor, {}), _jsxs("div", { children: [_jsx("span", { className: "label", children: " \uD835\uDEC5: " }), _jsx("span", { className: "value", children: format(scaleX().invert(position.x)) }), _jsx("span", { className: "unit", children: "ppm" }), activeSpectrum && spectrum?.info?.originFrequency && (_jsxs(_Fragment, { children: [_jsxs("span", { className: "value", children: ["\u00A0(", format(scaleX().invert(position.x) * spectrum?.info?.originFrequency, 'hz')] }), _jsx("span", { className: "unit", children: "Hz" }), _jsx("span", { className: "value", children: ") " }), _jsxs("span", { className: "small-width-none", children: [_jsx("span", { children: "," }), _jsx("span", { className: "label", children: " Index: " }), _jsx("span", { className: "value", children: getXIndex(position.x) })] })] }))] }), isBrushing && (_jsxs("div", { className: "flex-row small-width-none", children: [_jsx("span", { className: "label", children: " \u0394ppm: " }), _jsx("span", { className: "value", children: (scaleX().invert(startX) - scaleX().invert(endX)).toPrecision(6) })] })), activeSpectrum && (_jsxs("div", { className: " flex-row small-width-none", children: [spectrum?.info?.originFrequency && isBrushing && (_jsxs("div", { children: [_jsx("span", { className: "label", children: " \u0394Hz: " }), _jsx("span", { className: "value", children: ((scaleX().invert(startX) - scaleX().invert(endX)) *
                                    spectrum?.info?.originFrequency).toPrecision(5) })] })), isBrushing && (_jsxs("div", { children: [_jsx("span", { className: "label", children: " ratio :" }), _jsxs("span", { className: "value", children: [((getYValue(startX) / (getYValue(endX) || Number.MIN_VALUE)) *
                                        100).toFixed(2), "%"] })] }))] })), activeSpectrum && (_jsxs("div", { className: "flex-row small-width-none", children: [_jsx("div", { className: "separator" }), _jsx(IoPulseSharp, {}), _jsxs("div", { children: [_jsx("span", { className: "label", children: "Intensity: " }), _jsx("span", { className: "value y-value", children: format(getYValue(position.x)) })] })] }))] }));
}
const MemoizedFooterBanner = memo(FooterBannerInner);
export default function FooterBanner() {
    const { margin, width, height, view: { spectra: { activeTab }, }, } = useChartData();
    const activeSpectrum = useActiveSpectrum();
    const spectrum = useSpectrum(null);
    return (_jsx(MemoizedFooterBanner, { margin, width, height, activeSpectrum, spectrum, activeTab }));
}
