import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { createTree } from 'ml-tree-similarity';
import { Fragment } from 'react';
import { isSpectrum1D } from '../../data/data1d/Spectrum1D';
import { useChartData } from '../context/ChartContext';
import { useScaleChecked } from '../context/ScaleContext';
import { useFormatNumberByNucleus } from '../hooks/useFormatNumberByNucleus';
import useSpectrum from '../hooks/useSpectrum';
const circleSize = 3;
const marginTop = circleSize + 10;
const lineColor = 'black';
const textColor = 'black';
const textPadding = circleSize + 2;
const textSize = 10;
const maxTreeLevels = 25;
export default function SimilarityTree() {
    const { height, view: { spectra: { activeTab, showSimilarityTree }, }, } = useChartData();
    const spectrum = useSpectrum();
    const format = useFormatNumberByNucleus(activeTab);
    const { scaleX } = useScaleChecked();
    const scaleY = (value) => (height * value) / maxTreeLevels;
    const treeHeadLength = height / maxTreeLevels;
    if (!spectrum || !showSimilarityTree || !isSpectrum1D(spectrum))
        return null;
    const { data: { x, re }, display: { color }, } = spectrum;
    const tree = createTree({ x, y: re });
    const data = mapTreeToArray(tree, 0);
    const paths = [];
    for (const { level, center, parentCenter, parentLevel } of data) {
        if (parentCenter === undefined)
            continue;
        const startX = scaleX()(parentCenter);
        const startY = scaleY(parentLevel);
        const midY = startY + treeHeadLength / 2;
        const endX = scaleX()(center);
        const endY = scaleY(level);
        const path = `M ${startX} ${startY} L ${startX} ${midY} L ${endX} ${midY} L${endX} ${endY}`;
        paths.push(path);
    }
    return (_jsxs("g", { className: "similarity-tree", transform: `translate(0,${marginTop})`, children: [_jsx("path", { className: "tree-lines", d: paths.join(' '), fill: "none", stroke: lineColor }), ";", _jsx("g", { className: "tree-nodes", children: data.map(({ level, center }) => {
                    const x = scaleX()(center);
                    const y = scaleY(level);
                    return (_jsxs(Fragment, { children: [_jsx("circle", { cx: x, cy: y, r: circleSize, fill: color }), _jsx("text", { x: x + textPadding, y: y, textAnchor: "start", alignmentBaseline: "middle", fill: textColor, fontSize: textSize, children: format(center) })] }, `${level}${center}`));
                }) })] }));
}
function mapTreeToArray(node, level, parentCenter = null, parentLevel = -1) {
    if (!node)
        return [];
    const { center, sum } = node;
    const result = [{ center, sum, level }];
    for (const obj of result) {
        if (parentCenter) {
            obj.parentCenter = parentCenter;
            obj.parentLevel = parentLevel;
        }
    }
    const left = mapTreeToArray(node.left, level + 1, center, parentLevel + 1);
    const right = mapTreeToArray(node.right, level + 1, center, parentLevel + 1);
    return result.concat(left, right);
}
