import { jsx as _jsx, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import * as d3 from 'd3';
import { useEffect, useRef } from 'react';
import { useChartData } from '../context/ChartContext';
import { useScale } from '../context/ScaleContext';
const axisStyles = css `
  user-select: none;

  path,
  line {
    fill: none;
    stroke: black;
    stroke-width: 1;
    shape-rendering: crispedges;
    user-select: none;
  }
`;
function YAxis(props) {
    const { show = true, label = '' } = props;
    const refAxis = useRef(null);
    const { yDomain, width, height, margin } = useChartData();
    const { scaleY } = useScale();
    useEffect(() => {
        if (show && yDomain && scaleY) {
            const axis = d3.axisRight(scaleY()).ticks(10).tickFormat(d3.format('~s'));
            // @ts-expect-error this line of code is well typed
            d3.select(refAxis.current).call(axis);
        }
    }, [show, yDomain, scaleY]);
    if (!width || !height) {
        return null;
    }
    return (_jsx(_Fragment, { children: show && (_jsx("g", { className: "y", css: axisStyles, transform: `translate(${width - 50})`, ref: refAxis, children: _jsx("text", { fill: "#000", x: -margin.top, y: -(margin.right - 5), dy: "0.71em", transform: "rotate(-90)", textAnchor: "end", children: label }) })) }));
}
export default YAxis;
