import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { useCallback } from 'react';
import { usePreferences } from '../../context/PreferencesContext';
import { useScaleChecked } from '../../context/ScaleContext';
import { ResizerWithScale } from '../../elements/ResizerWithScale';
import { useHighlight } from '../../highlight';
import { useResizerStatus } from '../../hooks/useResizerStatus';
const styles = {
    common: css `
    pointer-events: bounding-box;

    @-moz-document url-prefix("") {
      pointer-events: fill;
    }
  `,
    hover: css `
    .delete-button {
      visibility: hidden;
    }
  `,
    Highlighted: css `
    .range-area {
      height: 100%;
      fill: #ff6f0057;
    }

    .delete-button {
      visibility: visible;
      cursor: pointer;
    }
  `,
};
function AnalysisRange({ rangeData, columnKey, activeTab, }) {
    const highlight = useHighlight([columnKey], {
        type: 'MULTIPLE_ANALYSIS_ZONE',
        extra: { colKey: columnKey },
    });
    const { scaleX } = useScaleChecked();
    const { dispatch } = usePreferences();
    const resizeEndHandler = useCallback((resized) => {
        const { x1, x2 } = resized;
        const start = scaleX().invert(x2);
        const end = scaleX().invert(x1);
        dispatch({
            type: 'ANALYZE_SPECTRA',
            payload: { start, end, columnKey, nucleus: activeTab },
        });
    }, [activeTab, columnKey, dispatch, scaleX]);
    const { from, to } = rangeData;
    const isResizingActive = useResizerStatus('multipleSpectraAnalysis');
    return (_jsx("g", { ...highlight.onHover, ...highlight.onHover, children: _jsx(ResizerWithScale, { onEnd: resizeEndHandler, from: from, to: to, disabled: !isResizingActive, children: ({ x1, x2 }, isActive) => (_jsxs("g", { transform: `translate(0,25)`, css: [
                    styles.common,
                    highlight.isActive || isActive
                        ? styles.Highlighted
                        : styles.hover,
                ], children: [_jsx("rect", { x: "0", width: x2 - x1, height: "6", className: "range-area", fill: "green" }), _jsx("text", { textAnchor: "middle", x: (x2 - x1) / 2, y: "-5", fontSize: "12", fill: "red", fontWeight: "bolder", fillOpacity: highlight.isActive ? 1 : 0.6, children: columnKey })] })) }) }));
}
export default AnalysisRange;
