import { jsx as _jsx } from "react/jsx-runtime";
import { useChartData } from '../../context/ChartContext';
import { useTopicMolecule } from '../../context/TopicMoleculeContext';
const fontSize = 12;
const lineHeight = fontSize * 1.1;
const marginTop = 55;
function getDiaIds(range) {
    const { diaIDs = [], signals } = range;
    const ids = diaIDs.slice();
    for (const signal of signals) {
        if (signal?.diaIDs) {
            ids.push(...signal.diaIDs);
        }
    }
    return ids;
}
function useAtoms(range) {
    const topicMolecule = useTopicMolecule();
    const diaIDs = getDiaIds(range);
    const atomsList = [];
    for (const [id, topicMoleculeObject] of Object.entries(topicMolecule)) {
        const atoms = [];
        const diaIDsObject = topicMoleculeObject.getDiaIDsObject();
        for (const id of diaIDs) {
            const existingAtoms = diaIDsObject[id]?.existingAtoms;
            if (existingAtoms?.length > 0) {
                atoms.push(...existingAtoms);
            }
        }
        if (atoms.length > 0) {
            atomsList.push({ id, atoms: [...new Set(atoms.sort((a, b) => a - b))] });
        }
    }
    return atomsList;
}
export function Atoms(props) {
    const { range, x } = props;
    const { view: { molecules }, } = useChartData();
    const atomsList = useAtoms(range).filter((atomsList) => molecules?.[atomsList.id]?.showAtomNumber);
    return (_jsx("g", { transform: `translate(${x},${marginTop})`, children: atomsList.map((row, rowIndex) => (
        // eslint-disable-next-line react/no-array-index-key
        _jsx("g", { transform: `translate(${rowIndex * lineHeight}, 0)`, children: row.atoms.map((item, colIndex) => (_jsx("text", { x: 0, y: colIndex * lineHeight, fontSize: fontSize, fill: "black", children: item }, colIndex))) }, rowIndex))) }));
}
