import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { isRangeAssigned } from '../../../data/data1d/Spectrum1D/isRangeAssigned';
import { checkRangeKind } from '../../../data/utilities/RangeUtilities';
import { useAssignment, useAssignmentData, } from '../../assignment/AssignmentsContext';
import { filterForIDsWithAssignment } from '../../assignment/utilities/filterForIDsWithAssignment';
import { useDispatch } from '../../context/DispatchContext';
import { ResizerWithScale } from '../../elements/ResizerWithScale';
import { HighlightEventSource, useHighlight } from '../../highlight';
import { useActiveSpectrumRangesViewState } from '../../hooks/useActiveSpectrumRangesViewState';
import { useResizerStatus } from '../../hooks/useResizerStatus';
import { options } from '../../toolbar/ToolTypes';
import { IntegralIndicator } from '../integral/IntegralIndicator';
import { useScaleX } from '../utilities/scale';
import { AssignmentActionsButtons } from './AssignmentActionsButtons';
import { Atoms } from './Atoms';
const style = css `
  .target {
    visibility: hidden;
  }

  &:hover {
    .target {
      visibility: visible;
    }
  }
`;
function Range({ range, selectedTool, relativeFormat }) {
    const { id, integration, signals, from, to, diaIDs: rangeDiaIDs } = range;
    const assignmentData = useAssignmentData();
    const assignmentRange = useAssignment(id);
    const highlightRange = useHighlight([assignmentRange.id].concat(assignmentRange.assigned?.x || []).concat(filterForIDsWithAssignment(assignmentData, signals.map((_signal) => _signal.id))), { type: HighlightEventSource.RANGE, extra: { id } });
    const scaleX = useScaleX();
    const dispatch = useDispatch();
    const { showIntegralsValues } = useActiveSpectrumRangesViewState();
    const isBlockedByEditing = selectedTool && selectedTool === options.editRange.id;
    function handleOnStopResizing(position) {
        dispatch({
            type: 'RESIZE_RANGE',
            payload: {
                range: {
                    ...range,
                    from: scaleX().invert(position.x2),
                    to: scaleX().invert(position.x1),
                },
            },
        });
    }
    function mouseEnterHandler() {
        assignmentRange.show('x');
        highlightRange.show();
    }
    function mouseLeaveHandler() {
        assignmentRange.hide();
        highlightRange.hide();
    }
    function assignHandler() {
        if (!isBlockedByEditing) {
            assignmentRange.setActive('x');
        }
    }
    function unAssignHandler(signalIndex = -1) {
        dispatch({
            type: 'UNLINK_RANGE',
            payload: {
                range,
                assignmentData,
                signalIndex,
            },
        });
    }
    const isNotSignal = !checkRangeKind(range);
    const isHighlighted = isBlockedByEditing || highlightRange.isActive || assignmentRange.isActive;
    const isAssigned = isRangeAssigned(range);
    const isResizingActive = useResizerStatus('rangePicking');
    const startX = scaleX()(from) - 16;
    return (_jsxs("g", { "data-testid": "range", style: { outline: 'none' }, onMouseEnter: mouseEnterHandler, onMouseLeave: mouseLeaveHandler, ...(!assignmentRange.isActive && { css: style }), children: [_jsx(ResizerWithScale, { from: from, to: to, onEnd: handleOnStopResizing, disabled: !isResizingActive, children: ({ x1, x2 }, isActive) => {
                    const width = x2 - x1;
                    return (_jsxs("g", { children: [isAssigned && !isHighlighted && !isActive && (_jsx("rect", { width: width, height: "10px", fill: "#ffd700", opacity: "0.35", "data-no-export": "true" })), _jsx("rect", { width: width, height: "100%", fill: isHighlighted || isActive ? '#ff6f0057' : 'transparent', "data-no-export": "true" }), showIntegralsValues && (_jsx(IntegralIndicator, { value: integration, format: relativeFormat, width: width, opacity: isNotSignal ? 0.5 : 1 }))] }));
                } }), _jsx(Atoms, { range: range, x: startX }), _jsx(AssignmentActionsButtons, { isActive: !!(assignmentRange.isActive || rangeDiaIDs), x: startX, onAssign: assignHandler, onUnAssign: () => unAssignHandler() })] }, id));
}
export default Range;
