import { jsx as _jsx } from "react/jsx-runtime";
import { memo } from 'react';
import { useChartData } from '../../context/ChartContext';
import { useActiveSpectrumRangesViewState } from '../../hooks/useActiveSpectrumRangesViewState';
import { usePanelPreferences } from '../../hooks/usePanelPreferences';
import useSpectrum from '../../hooks/useSpectrum';
import Range from './Range';
function RangesInner({ ranges, displayerKey, selectedTool, showMultiplicityTrees, relativeFormat, }) {
    return (_jsx("g", { clipPath: `url(#${displayerKey}clip-chart-1d)`, children: ranges?.values?.map((range) => (_jsx(Range, { range: range, selectedTool: selectedTool, showMultiplicityTrees: showMultiplicityTrees, relativeFormat: relativeFormat }, range.id))) }));
}
const MemoizedRanges = memo(RangesInner);
const emptyData = { ranges: {}, info: {}, display: {} };
export default function Ranges() {
    const { displayerKey, view: { spectra: { activeTab }, }, toolOptions: { selectedTool }, } = useChartData();
    const { showMultiplicityTrees, showIntegrals } = useActiveSpectrumRangesViewState();
    const spectrum = useSpectrum(emptyData);
    const rangesPreferences = usePanelPreferences('ranges', activeTab);
    if (!spectrum.ranges?.values ||
        !spectrum.display.isVisible ||
        spectrum.info?.isFid) {
        return null;
    }
    return (_jsx(MemoizedRanges, { ranges: spectrum.ranges, showMultiplicityTrees,
        showIntegrals,
        selectedTool,
        displayerKey,
        relativeFormat: rangesPreferences.relative.format }));
}
