import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useChartData } from '../../context/ChartContext';
import { PathBuilder } from '../../utility/PathBuilder';
import { useScale2DX, getSliceYScale } from '../utilities/scale';
function usePath(data, options) {
    const { height = 100, vericalMargin = 10 } = options;
    const { mode } = useChartData();
    const scaleX = useScale2DX();
    if (!data)
        return '';
    const { x, re: y } = data;
    const scaleY = getSliceYScale(y, height, mode, { margin: vericalMargin });
    const pathBuilder = new PathBuilder();
    pathBuilder.moveTo(scaleX(x[0]), scaleY(y[0]));
    for (let i = 1; i < x.length; i++) {
        pathBuilder.lineTo(scaleX(x[i]), scaleY(y[i]));
    }
    return pathBuilder.toString();
}
function HorizontalSliceChart(props) {
    const { vericalMargin = 10, data, reverse = false } = props;
    const { width, margin, displayerKey } = useChartData();
    const height = margin.top;
    const path = usePath(data, { height, reverse, vericalMargin });
    const innerWidth = width - margin.left - margin.right;
    return (_jsxs("svg", { viewBox: `0 0 ${width} ${height}`, width: width, height: height, children: [_jsx("defs", { children: _jsx("clipPath", { id: `${displayerKey}clip-top`, children: _jsx("rect", { width: innerWidth, height: height, x: margin.left }) }) }), _jsx("g", { clipPath: `url(#${displayerKey}clip-top)`, children: _jsx("path", { className: "line", stroke: "red", fill: "none", d: path }) })] }));
}
export default HorizontalSliceChart;
