import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { memo } from 'react';
import { useChartData } from '../../context/ChartContext';
import useXYReduce, { XYReducerDomainAxis } from '../../hooks/useXYReduce';
import { PathBuilder } from '../../utility/PathBuilder';
import { use1DTraceYScale, useScale2DY } from '../utilities/scale';
function usePath(spectrum, options) {
    const { width, horizontalMargin = 10 } = options;
    const scaleX = useScale2DY();
    const scaleY = use1DTraceYScale(spectrum.id, width, horizontalMargin);
    const xyReduce = useXYReduce(XYReducerDomainAxis.YAxis);
    const { x, re: y } = spectrum.data;
    const pathPoints = xyReduce({ x, y });
    const pathBuilder = new PathBuilder();
    pathBuilder.moveTo(scaleY(pathPoints.y.at(-1)), scaleX(pathPoints.x.at(-1)));
    for (let i = pathPoints.x.length - 2; i >= 0; i--) {
        pathBuilder.lineTo(scaleY(pathPoints.y[i]), scaleX(pathPoints.x[i]));
    }
    return pathBuilder.toString();
}
function Left1DChart({ horizontalMargin = 10, data: spectrum, }) {
    const { height, margin, displayerKey } = useChartData();
    const width = margin.left;
    const path = usePath(spectrum, { horizontalMargin, width });
    const innerHeight = height - margin.bottom - margin.top;
    if (!innerHeight || !width)
        return null;
    return (_jsxs("svg", { viewBox: `0 0 ${width} ${innerHeight + margin.top}`, width: width, height: innerHeight + margin.top, children: [_jsx("defs", { children: _jsx("clipPath", { id: `${displayerKey}clip-left`, children: _jsx("rect", { width: width, height: innerHeight, x: "0", y: margin.top }) }) }), _jsx("g", { clipPath: `url(#${displayerKey}clip-left)`, children: _jsx("path", { className: "line", stroke: spectrum.display.color, fill: "none", d: path }) })] }));
}
export default memo(Left1DChart);
