import { scaleLinear } from 'd3';
import { xMaxValue } from 'ml-spectra-processing';
import { useChartData } from '../../context/ChartContext';
import { LAYOUT } from './DimensionLayout';
function get2DXScale(options, reverse) {
    const { width, margin, xDomain, mode } = options;
    const isReversed = reverse !== undefined ? reverse : mode === 'RTL';
    const range = isReversed
        ? [width - margin.right, margin.left]
        : [margin.left, width - margin.right];
    return scaleLinear(xDomain, range);
}
function useScale2DX(reverse) {
    const { width, margin, xDomain, mode } = useChartData();
    return get2DXScale({ width, margin, xDomain, mode }, reverse);
}
function get2DYScale(options, reverse = false) {
    const { height, margin, yDomain } = options;
    return scaleLinear(yDomain, reverse
        ? [height - margin.bottom, margin.top]
        : [margin.top, height - margin.bottom]);
}
function useScale2DY(reverse) {
    const { height, margin, yDomain } = useChartData();
    return get2DYScale({ height, margin, yDomain }, reverse);
}
function get1DXScale(props, layout) {
    if (!['TOP_1D', 'LEFT_1D'].includes(layout)) {
        throw new Error(`layout is required and must be ${LAYOUT.TOP_1D} or ${LAYOUT.LEFT_1D}  `);
    }
    switch (layout) {
        case LAYOUT.TOP_1D: {
            const { width, margin, xDomain } = props;
            return scaleLinear(xDomain, [width - margin.right, margin.left]);
        }
        case LAYOUT.LEFT_1D: {
            const { height, margin, yDomain } = props;
            return scaleLinear(yDomain, [height - margin.bottom, margin.top]);
        }
        default:
            break;
    }
}
function get1DYScale(yDomain, height, margin = 10) {
    return scaleLinear(yDomain, [height - margin, margin]);
}
function use1DTraceYScale(SpectrumId, height, verticalMargin) {
    const { yDomains } = useChartData();
    return get1DYScale(yDomains[SpectrumId], height, verticalMargin);
}
function getSliceYScale(data, size, mode, options = {}) {
    const { margin = 10, scaleRatio = 1 } = options;
    const max = xMaxValue(data);
    size = mode === 'RTL' ? size : size / 2;
    return scaleLinear([0, max * scaleRatio], [
        size - margin,
        margin,
    ]);
}
export { get2DXScale, getSliceYScale, get2DYScale, get1DXScale, get1DYScale, useScale2DX, useScale2DY, use1DTraceYScale, };
