import { createContext, useCallback, useContext, useMemo } from 'react';
export const assignmentState = {
    assignments: {},
    activated: null,
    highlighted: null,
};
export const assignmentContext = createContext({
    data: assignmentState,
    dispatch: () => null,
});
export const AssignmentProvider = assignmentContext.Provider;
export function useAssignmentData() {
    const context = useContext(assignmentContext);
    if (!context) {
        throw new Error('Assignment context was not found');
    }
    return context;
}
// key can be signal id,range id or zone id
export function useAssignment(key) {
    const { data: { activated, highlighted, assignments }, dispatch, } = useAssignmentData();
    if (!['string', 'number'].includes(typeof key)) {
        throw new Error(`assignment key must be a non-empty string or number`);
    }
    const id = String(key);
    const isActive = useMemo(() => {
        return activated?.id === id;
    }, [activated?.id, id]);
    const isOver = useMemo(() => {
        return highlighted?.id === id;
    }, [highlighted?.id, id]);
    const assigned = useMemo(() => {
        if (!(id in assignments)) {
            return {};
        }
        return assignments[id];
    }, [assignments, id]);
    const removeAll = useCallback((axis) => {
        if (id) {
            dispatch({
                type: 'REMOVE',
                payload: { ids: [id], axis },
            });
            return true;
        }
        return false;
    }, [dispatch, id]);
    const toggle = useCallback((atomIDs, dimension) => {
        if (id) {
            dispatch({
                type: 'TOGGLE',
                payload: { atomIDs, id, dimension },
            });
            return true;
        }
        return false;
    }, [dispatch, id]);
    const setActive = useCallback((axis) => {
        if (id) {
            dispatch({
                type: 'SET_ACTIVE',
                payload: {
                    id,
                    axis,
                },
            });
            return true;
        }
        return false;
    }, [dispatch, id]);
    const show = useCallback((axis) => {
        if (id) {
            dispatch({
                type: 'SHOW',
                payload: {
                    id,
                    axis,
                },
            });
            return true;
        }
        return false;
    }, [dispatch, id]);
    const hide = useCallback(() => {
        dispatch({
            type: 'HIDE',
        });
    }, [dispatch]);
    return {
        id,
        activated,
        isActive,
        isOver,
        highlighted,
        assigned,
        removeAll,
        toggle,
        setActive,
        show,
        hide,
    };
}
