import { isSpectrum1D } from '../../../data/data1d/Spectrum1D';
import { assignmentState } from '../AssignmentsContext';
export default function initAssignment(action) {
    const newState = {
        ...assignmentState,
    };
    const spectra = (action.payload.spectra || []);
    for (const spectrum of spectra) {
        if (isSpectrum1D(spectrum)) {
            setRangesAssignments(newState, spectrum.ranges);
        }
        else {
            setZonesAssignments(newState, spectrum.zones);
        }
    }
    return newState;
}
function setRangesAssignments(state, ranges) {
    const diaIDRecords = [];
    for (const { id, diaIDs, signals } of ranges.values) {
        diaIDRecords.push({ id, diaIDs: diaIDs || [] });
        for (const signal of signals) {
            diaIDRecords.push({ id: signal.id, diaIDs: signal.diaIDs || [] });
        }
    }
    for (const { id, diaIDs } of diaIDRecords) {
        for (const diaID of diaIDs) {
            setAssignment(state, id, 'x', diaID);
        }
    }
}
function setZonesAssignments(state, zones) {
    const diaIDRecords = zones.values.flatMap(({ id, x, y, signals }) => {
        const diaIDRecords = signals.map((signal) => ({
            id: signal.id,
            diaIDs: { x: signal.x.diaIDs || [], y: signal.y.diaIDs || [] },
        }));
        return [
            { id, diaIDs: { x: x.diaIDs || [], y: y.diaIDs || [] } },
            ...diaIDRecords,
        ];
    });
    for (const { id, diaIDs } of diaIDRecords) {
        for (const axis of ['x', 'y']) {
            for (const diaID of diaIDs[axis]) {
                setAssignment(state, id, axis, diaID);
            }
        }
    }
}
function setAssignment(state, id, axis, diaID) {
    if (Array.isArray(state.assignments?.[id]?.[axis]) &&
        !state.assignments[id][axis].includes(diaID)) {
        state.assignments[id][axis].push(diaID);
    }
    else {
        state.assignments = {
            ...state.assignments,
            [id]: { ...state.assignments[id], [axis]: [diaID] },
        };
    }
}
