import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { FifoLogger } from 'fifo-logger';
import { createContext, useContext, useRef, useMemo, useState, useCallback, useEffect, } from 'react';
import { LogsHistoryModal } from '../modal/LogsHistoryModal';
import { usePreferences } from './PreferencesContext';
export const LoggerContext = createContext(null);
export function useLogger() {
    const context = useContext(LoggerContext);
    if (!context) {
        throw new Error('Logger context was not found');
    }
    return context;
}
export const LOGGER_LEVELS = {
    fatal: 60,
    error: 50,
    warn: 40,
    info: 30,
    debug: 20,
    trace: 10,
    silent: 0,
};
export function LoggerProvider({ children }) {
    const { current: { general: { loggingLevel, popupLoggingLevel }, }, } = usePreferences();
    const [lastReadLogId, setLastLogId] = useState(0);
    const [logsHistory, setLogsHistory] = useState([]);
    const [isLogHistoryOpened, openLogHistory] = useState(false);
    const popupLoggingLevelRef = useRef();
    const loggerRef = useRef(new FifoLogger({
        onChange: (log, logs) => {
            if (log &&
                popupLoggingLevelRef.current &&
                log.level === LOGGER_LEVELS[popupLoggingLevelRef.current]) {
                openLogHistory(true);
            }
            if (log?.error) {
                // eslint-disable-next-line no-console
                console.error(log.error);
            }
            setLogsHistory(logs.slice());
        },
    }));
    useEffect(() => {
        if (loggingLevel) {
            loggerRef.current.setLevel(loggingLevel);
        }
    }, [loggingLevel]);
    const markAsRead = useCallback(() => {
        if (logsHistory.length > 0) {
            const id = logsHistory.at(-1).id;
            setLastLogId(id);
        }
    }, [logsHistory]);
    const loggerState = useMemo(() => {
        return {
            logger: loggerRef.current,
            logsHistory,
            markAsRead,
            lastReadLogId,
        };
    }, [lastReadLogId, logsHistory, markAsRead]);
    useEffect(() => {
        popupLoggingLevelRef.current = popupLoggingLevel;
    }, [logsHistory, popupLoggingLevel]);
    return (_jsxs(LoggerContext.Provider, { value: loggerState, children: [isLogHistoryOpened && (_jsx(LogsHistoryModal, { autoOpen: true, onClose: () => openLogHistory(false) })), children] }));
}
