/** @jsxImportSource @emotion/react */
import { CSSObject } from '@emotion/react';
import { CSSProperties, ComponentPropsWithoutRef, ElementType } from 'react';
type Size = 'xSmall' | 'small' | 'medium' | 'large';
type Color = CSSProperties['color'];
interface BaseColor {
    base: Color;
    hover: Color;
    active?: Color;
}
type Fill = 'clear' | 'outline' | 'solid';
type ColorTheme = 'success' | 'danger' | 'warning' | 'medium' | 'light' | 'secondary';
interface ButtonStyle {
    color: BaseColor;
    size: Size;
    borderColor: Color;
    backgroundColor: BaseColor;
    borderRadius?: CSSProperties['borderRadius'];
    fill?: Fill;
    style?: CSSObject | CSSProperties;
    wrapperStyle?: CSSProperties;
}
type TooltipOrientation = 'vertical' | 'horizontal';
type ElementProps<E = unknown> = E extends ElementType ? ComponentPropsWithoutRef<E> : never;
export interface InnerButtonProps<E extends ElementType = 'button'> extends Partial<ButtonStyle> {
    toolTip?: string;
    tooltipOrientation?: TooltipOrientation;
    wrapperClassName?: string;
    theme?: ColorTheme;
    as?: E;
    disabled?: boolean;
}
export type ButtonProps<E extends ElementType = 'button'> = InnerButtonProps<E> & Omit<ElementProps<E>, 'color' | 'style' | 'disabled' | 'fill'>;
declare function Button<E extends ElementType = 'button'>(props: ButtonProps<E>): import("@emotion/react/jsx-runtime").JSX.Element;
declare namespace Button {
    var Done: <E extends ElementType = "button">(props: ButtonProps<E>) => import("@emotion/react/jsx-runtime").JSX.Element;
    var Danger: <E extends ElementType = "button">(props: ButtonProps<E>) => import("@emotion/react/jsx-runtime").JSX.Element;
    var Action: <E extends ElementType = "button">(props: ButtonProps<E>) => import("@emotion/react/jsx-runtime").JSX.Element;
    var Secondary: <E extends ElementType = "button">(props: ButtonProps<E>) => import("@emotion/react/jsx-runtime").JSX.Element;
    var Info: <E extends ElementType = "button">(props: Omit<ButtonProps<E>, "children">) => import("@emotion/react/jsx-runtime").JSX.Element;
    var BarButton: <E extends ElementType = "button">(props: ButtonProps<E>) => import("@emotion/react/jsx-runtime").JSX.Element;
}
export default Button;
