import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
//TODO resolve the eslint rules
/* eslint-disable react/no-unused-prop-types */
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { FaInfoCircle } from 'react-icons/fa';
const colorPalettes = {
    success: {
        base: '#2dd36f',
        shade: '#28ba62',
        tint: '#42d77d',
    },
    danger: {
        base: '#eb445a',
        shade: '#cf3c4f',
        tint: '#ed576b',
    },
    warning: {
        base: '#ffc409',
        shade: '#e0ac08',
        tint: '#ffca22',
    },
    medium: {
        base: '#92949c',
        shade: '#808289',
        tint: '#9d9fa6',
    },
    light: {
        base: '#f4f5f8',
        shade: '#d7d8da',
        tint: '#f5f6f9',
    },
    secondary: {
        base: '#3880ff',
        shade: '#3171e0',
        tint: '#4c8dff',
    },
};
const sizeConfig = {
    xSmall: {
        fontSize: '0.75rem',
        padding: '0.15rem 0.3rem',
        borderRadius: '0.15rem',
    },
    small: {
        fontSize: '0.8rem',
        padding: '0.25rem 0.5rem',
        borderRadius: '0.2rem',
    },
    medium: {
        fontSize: '1rem',
        padding: '0.375rem 0.75rem',
        borderRadius: '0.25rem',
    },
    large: {
        fontSize: '1.25rem',
        padding: '0.5rem 1rem',
        borderRadius: '0.3rem',
    },
};
function getFillStyle(props) {
    const { borderColor, fill, backgroundColor, color } = props;
    switch (fill) {
        case 'solid': {
            return css `
        border-color: transparent;
        background-color: ${backgroundColor.base};
        color: ${color.hover};
      `;
        }
        case 'outline': {
            return css `
        border-style: solid;
        border-color: ${backgroundColor.base};
        background-color: transparent;
        color: ${color.base};
      `;
        }
        case 'clear': {
            return css `
        border-color: transparent;
        background-color: transparent;
        color: ${color.base};
      `;
        }
        default:
            return css `
        background-color: ${backgroundColor.base};
        color: ${color.base};
        border-color: ${borderColor};
      `;
    }
}
const styles = {
    button: (props) => {
        const { size, backgroundColor: { hover, active }, color, borderRadius, element, } = props;
        const basic = css `
      display: flex;
      flex-direction: row;
      border-width: 1px;
      align-items: center;

      &:hover + .content {
        display: flex;
      }
    `;
        const fillStyle = getFillStyle(props);
        const basicDisabledStyle = css `
      &:disabled,
      &.disabled {
        opacity: 0.25;
      }
    `;
        const colorStyle = css `
      &:not(${element === 'button' ? '[disabled]' : '.disabled'}):hover {
        background-color: ${hover};
        color: ${color.hover};
      }
      &:not(${element === 'button' ? '[disabled]' : '.disabled'}):active {
        background-color: ${active || hover};
        color: ${color?.active || color.hover};
      }
    `;
        return css([
            basic,
            sizeConfig[size],
            fillStyle,
            basicDisabledStyle,
            colorStyle,
            { borderRadius },
        ]);
    },
};
//based on the tooltip from react-science
const toolTipStyle = (orientation) => {
    const common = {
        display: 'none',
        position: 'absolute',
        backgroundColor: 'gray',
        borderRadius: '2px',
        color: 'white',
        bottom: '0px',
        right: '0px',
        width: 'fit-content',
        height: '100%',
        fontSize: '0.875em',
        whiteSpace: 'nowrap',
        paddingLeft: '3px',
        paddingRight: '3px',
        pointerEvents: 'none',
        zIndex: 99,
    };
    return css([
        common,
        orientation === 'horizontal' && { margin: 'auto', marginLeft: '5px' },
        orientation === 'vertical'
            ? { top: 'calc(100% + 5px)' }
            : { top: '0px', left: 'calc(100%)' },
    ]);
};
function Button(props) {
    const { theme = 'light', ...buttonProps } = props;
    const { base, shade, tint } = colorPalettes[theme];
    const { onClick, size = 'small', color = { base: shade, hover: 'white' }, backgroundColor = {
        base,
        hover: shade,
        active: tint,
    }, borderColor = 'transparent', fill = 'solid', borderRadius, style = {}, wrapperStyle = {}, toolTip, tooltipOrientation = 'vertical', wrapperClassName = '', as: Wrapper = 'button', disabled = false, className = '', ...restProps } = buttonProps;
    const isDivDisabled = Wrapper === 'div' && disabled;
    return (_jsxs("div", { style: { position: 'relative', ...wrapperStyle }, className: wrapperClassName, children: [_jsx(Wrapper, { ...(Wrapper === 'button' && { type: 'button', disabled }), onClick: Wrapper === 'button' || (Wrapper === 'div' && !disabled)
                    ? onClick
                    : (e) => e.stopPropagation(), css: [
                    styles.button({
                        size,
                        backgroundColor,
                        color,
                        borderColor,
                        fill,
                        borderRadius,
                        element: Wrapper,
                    }),
                    style,
                ], className: `${className} ${isDivDisabled ? 'disabled' : ''}`, ...restProps, children: _jsx("span", { style: { flex: 1, pointerEvents: 'none' }, children: props.children }) }), toolTip && (_jsx("div", { className: "content", css: toolTipStyle(tooltipOrientation), children: _jsx("span", { style: {
                        display: 'flex',
                        margin: 'auto',
                        justifyContent: 'center',
                    }, children: toolTip }) }))] }));
}
Button.Done = function ButtonDone(props) {
    return _jsx(Button, { ...props, theme: "success" });
};
Button.Danger = function ButtonDanger(props) {
    return _jsx(Button, { ...props, theme: "danger" });
};
Button.Action = function ButtonAction(props) {
    return _jsx(Button, { ...props, theme: "medium" });
};
Button.Secondary = function ButtonAction(props) {
    return _jsx(Button, { ...props, theme: "secondary" });
};
Button.Info = function ButtonInfo(props) {
    return (_jsx(Button, { ...props, children: _jsx(FaInfoCircle, {}) }));
};
Button.BarButton = function BarButton(props) {
    const { ...otherProps } = props;
    return (_jsx(Button, { backgroundColor: { base: 'white', hover: '#f7f7f7', active: '#e7e7e7' },
        color: {
            base: 'black',
            hover: 'black',
        },
        style: { padding: '0.25rem' },
        ...otherProps }));
};
export default Button;
