import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { useState, Children, useMemo, useEffect, useCallback, memo, } from 'react';
import { FaAngleLeft } from 'react-icons/fa';
import { useMeasure } from 'react-use';
function Arrow({ direction, onClick, style = {} }) {
    return (_jsx("div", { onClick: onClick, css: css `
        display: inline-flex;
        height: 40px;
        width: 40px;
        justify-content: center;
        background: white;
        border-radius: 50%;
        cursor: pointer;
        align-items: center;
        border: none;
        transition: transform ease-in 0.1s;
        background-color: #f7f7f7;
        pointer-events: auto;

        &:hover {
          transform: scale(1.1);
          background-color: #607d8b !important;
          color: white;
        }

        img {
          transform: translateX(${direction === 'left' ? '-2' : '2'}px);

          &:focus {
            outline: 0;
          }
        }
      `, style: style, children: _jsx(FaAngleLeft, { style: { transform: `scaleX(${direction === 'right' ? '-1' : '1'})` } }) }));
}
const transition = 0.45;
function NextPrev(props) {
    const { children, loop = false, defaultIndex = 0, onChange = () => null, style = {}, } = props;
    const [ref, { width }] = useMeasure();
    const [activeIndex, setActiveIndex] = useState(0);
    useEffect(() => {
        setActiveIndex(defaultIndex);
    }, [defaultIndex]);
    const Sliders = useMemo(() => Children.map(children, (child) => {
        return (_jsx("div", { css: css `
              width: ${width}px;
              height: 100%;
            `, children: child }, child.key));
    }), [children, width]);
    const nextHandler = useCallback(() => {
        setActiveIndex((preActiveIndex) => {
            if (Sliders && preActiveIndex === Sliders.length - 1) {
                onChange(preActiveIndex);
                if (loop) {
                    return 0;
                }
                else {
                    return preActiveIndex;
                }
            }
            const nextIndex = preActiveIndex + 1;
            onChange(nextIndex);
            return nextIndex;
        });
    }, [Sliders, loop, onChange]);
    const prevHandler = useCallback(() => {
        setActiveIndex((preActiveIndex) => {
            if (preActiveIndex === 0) {
                onChange(preActiveIndex);
                if (loop) {
                    return 0;
                }
                else {
                    return preActiveIndex;
                }
            }
            const prevIndex = preActiveIndex - 1;
            onChange(prevIndex);
            return prevIndex;
        });
    }, [loop, onChange]);
    if (!width && !Sliders)
        return null;
    const translation = width * activeIndex;
    const slidersWidth = width * (Sliders ? Sliders.length : 1);
    return (_jsxs("div", { css: css `
        position: relative;
        height: 100%;
        width: 100%;
        margin: 0 auto;
        overflow: hidden;
        display: block;
      `, ref: ref, children: [_jsx("div", { css: css `
          transform: translateX(-${translation}px);
          transition: transform ease-out ${transition}s;
          height: 100%;
          width: ${slidersWidth}px;
          display: flex;
        `, children: Sliders }), _jsxs("div", { style: {
                    position: 'absolute',
                    top: '50%',
                    padding: '0 10px',
                    justifyContent: 'space-between',
                    width: '100%',
                    display: 'flex',
                    pointerEvents: 'none',
                    ...style?.arrowContainer,
                }, children: [_jsx(Arrow, { direction: "left", onClick: prevHandler, style: {
                            ...(activeIndex === 0 && {
                                visibility: 'hidden',
                                pointerEvents: 'none',
                            }),
                        } }), _jsx(Arrow, { direction: "right", onClick: nextHandler, style: {
                            ...((!Sliders || activeIndex === Sliders.length - 1) && {
                                visibility: 'hidden',
                                pointerEvents: 'none',
                            }),
                        } })] })] }));
}
export default memo(NextPrev);
