import { useRef } from 'react';
export default function useDraggable(props) {
    const { position: { x, y }, parentElement, fromEdge = false, dragHandleClassName, onChange, } = props;
    const isActive = useRef(false);
    const positionRef = useRef({ x, y });
    function onPointerDown(e) {
        e.stopPropagation();
        isActive.current = true;
        const eventTarget = e.currentTarget;
        positionRef.current = { x, y };
        const classes = e.target.getAttribute('class')?.split(' ') || [];
        if ((dragHandleClassName && classes.includes(dragHandleClassName)) ||
            !dragHandleClassName) {
            const _parentElement = parentElement || eventTarget?.parentElement;
            if (_parentElement) {
                const parentBounding = _parentElement.getBoundingClientRect();
                const currentBounding = eventTarget?.getBoundingClientRect();
                const startPosition = {
                    x: parentBounding.x + (!fromEdge ? e.clientX - currentBounding.x : 0),
                    y: parentBounding.y + (!fromEdge ? e.clientY - currentBounding.y : 0),
                };
                if (parentBounding) {
                    positionRef.current = startPosition;
                }
                onChange({ position: { x, y }, action: 'start', isActive: true });
            }
            window.addEventListener('pointermove', moveCallback);
            window.addEventListener('pointerup', upCallback);
        }
        function upCallback(e) {
            e.stopPropagation();
            if (isActive.current) {
                onChange({
                    position: {
                        x: e.clientX - positionRef.current.x,
                        y: e.clientY - positionRef.current.y,
                    },
                    action: 'end',
                    isActive: false,
                });
                isActive.current = false;
            }
            window.removeEventListener('pointermove', moveCallback);
            window.removeEventListener('pointerup', upCallback);
        }
        function moveCallback(e) {
            e.stopPropagation();
            if (isActive.current) {
                onChange({
                    position: {
                        x: e.clientX - positionRef.current.x,
                        y: e.clientY - positionRef.current.y,
                    },
                    action: 'move',
                    isActive: true,
                });
            }
        }
    }
    return { onPointerDown };
}
