import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { Formik } from 'formik';
import { Filters } from 'nmr-processing';
import { useRef, memo } from 'react';
import * as Yup from 'yup';
import { defaultApodizationOptions } from '../../data/constants/DefaultApodizationOptions';
import { useDispatch } from '../context/DispatchContext';
import ActionButtons from '../elements/ActionButtons';
import Label from '../elements/Label';
import FormikCheckBox from '../elements/formik/FormikCheckBox';
import FormikInput from '../elements/formik/FormikInput';
import FormikOnChange from '../elements/formik/FormikOnChange';
import { useFilter } from '../hooks/useFilter';
import { headerLabelStyle } from './Header';
import { HeaderContainer } from './HeaderContainer';
const inputStyle = {
    input: { width: '60px', textAlign: 'center' },
    inputWrapper: { height: '100%' },
};
const validationSchema = Yup.object().shape({
    lineBroadening: Yup.number().required(),
    gaussBroadening: Yup.number().required(),
    lineBroadeningCenter: Yup.number().required().min(0).max(1),
});
const initialValues = {
    ...defaultApodizationOptions,
    livePreview: true,
};
function ApodizationOptionsInnerPanel(props) {
    const dispatch = useDispatch();
    const previousPreviewRef = useRef(initialValues.livePreview);
    function handleApplyFilter(values, triggerSource = 'apply') {
        const { livePreview, ...options } = values;
        switch (triggerSource) {
            case 'onChange': {
                if (livePreview || previousPreviewRef.current !== livePreview) {
                    dispatch({
                        type: 'CALCULATE_APODIZATION_FILTER',
                        payload: { livePreview, options },
                    });
                }
                break;
            }
            case 'apply': {
                dispatch({
                    type: 'APPLY_APODIZATION_FILTER',
                    payload: { options },
                });
                break;
            }
            default:
                break;
        }
        previousPreviewRef.current = livePreview;
    }
    function handleCancelFilter() {
        dispatch({
            type: 'RESET_SELECTED_TOOL',
        });
    }
    let formData = initialValues;
    if (props.filter) {
        formData = { ...initialValues, ...props.filter.value, livePreview: true };
    }
    return (_jsx(HeaderContainer, { children: _jsx(Formik, { onSubmit: (values) => handleApplyFilter(values), initialValues: formData, validationSchema: validationSchema, children: ({ submitForm }) => (_jsxs(_Fragment, { children: [_jsx(Label, { title: "Line broadening : ", shortTitle: "LB :", style: headerLabelStyle, children: _jsx(FormikInput, { type: "number", name: "lineBroadening", min: 0, max: 1, step: 0.1, style: inputStyle, debounceTime: 250 }) }), _jsx(Label, { title: "Gauss broadening :", shortTitle: "GB :", style: headerLabelStyle, children: _jsx(FormikInput, { type: "number", name: "gaussBroadening", min: 0, max: 1, step: 0.1, style: inputStyle, debounceTime: 250 }) }), _jsx(Label, { title: "lineBroadeningCenter [0 - 1] : ", shortTitle: "LB Center :", style: headerLabelStyle, children: _jsx(FormikInput, { type: "number", name: "lineBroadeningCenter", min: 0, max: 1, step: 0.1, style: inputStyle, debounceTime: 250 }) }), _jsx(Label, { title: "Live preview ", htmlFor: "livePreview", style: { label: { padding: '0 5px' } }, children: _jsx(FormikCheckBox, { name: "livePreview" }) }), _jsx(FormikOnChange, { onChange: (values) => handleApplyFilter(values, 'onChange'), enableOnload: true }), _jsx(ActionButtons, { onDone: submitForm, onCancel: handleCancelFilter })] })) }) }));
}
const MemoizedApodizationPanel = memo(ApodizationOptionsInnerPanel);
export default function ApodizationOptionsPanel() {
    const filter = useFilter(Filters.apodization.id);
    return _jsx(MemoizedApodizationPanel, { filter: filter });
}
