import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { Formik } from 'formik';
import { Filters } from 'nmr-processing';
import { useState, memo, useRef } from 'react';
import * as Yup from 'yup';
import { useDispatch } from '../context/DispatchContext';
import ActionButtons from '../elements/ActionButtons';
import Label from '../elements/Label';
import Select from '../elements/Select';
import FormikCheckBox from '../elements/formik/FormikCheckBox';
import FormikInput from '../elements/formik/FormikInput';
import FormikOnChange from '../elements/formik/FormikOnChange';
import { useFilter } from '../hooks/useFilter';
import { headerLabelStyle } from './Header';
import { HeaderContainer } from './HeaderContainer';
const getAlgorithmsList = () => {
    return ['airPLS', 'Polynomial'].map((val) => ({
        label: val,
        value: val.toLowerCase(),
    }));
};
const inputStyle = {
    input: { width: '50px', textAlign: 'center' },
    inputWrapper: { height: '100%' },
};
const formData = (algorithm, filterValues) => {
    const { zones, algorithm: baseAlgorithm, ...other } = filterValues;
    switch (algorithm) {
        case 'airpls': {
            const validation = Yup.object().shape({
                maxIterations: Yup.number().integer().min(1).required(),
                tolerance: Yup.number().moreThan(0).required(),
            });
            return {
                validation,
                values: {
                    algorithm,
                    livePreview: true,
                    maxIterations: 100,
                    tolerance: 0.001,
                    ...(baseAlgorithm === 'airpls' ? other : {}),
                },
            };
        }
        case 'autoPolynomial':
        case 'polynomial': {
            const validation = Yup.object().shape({
                degree: Yup.number().integer().min(1).max(6).required(),
            });
            return {
                validation,
                values: {
                    algorithm,
                    livePreview: true,
                    degree: 3,
                    ...(baseAlgorithm === 'polynomial' ? other : {}),
                },
            };
        }
        default:
            return {
                validation: {},
                values: { livePreview: true },
            };
    }
};
function BaseLineCorrectionInnerPanel(props) {
    const dispatch = useDispatch();
    const previousPreviewRef = useRef(true);
    const { algorithm: baseAlgorithm = 'polynomial' } = props?.filter?.value || {};
    const [algorithm, setAlgorithm] = useState(baseAlgorithm);
    const handleApplyFilter = (values, triggerSource = 'apply') => {
        const { livePreview, ...options } = values;
        switch (triggerSource) {
            case 'onChange': {
                if (livePreview || previousPreviewRef !== livePreview) {
                    dispatch({
                        type: 'CALCULATE_BASE_LINE_CORRECTION_FILTER',
                        payload: {
                            options,
                            livePreview,
                        },
                    });
                }
                break;
            }
            case 'apply': {
                dispatch({
                    type: 'APPLY_BASE_LINE_CORRECTION_FILTER',
                    payload: {
                        options,
                    },
                });
                break;
            }
            default:
                break;
        }
        previousPreviewRef.current = livePreview;
    };
    const handleCancelFilter = () => {
        dispatch({
            type: 'RESET_SELECTED_TOOL',
        });
    };
    function handleChangeAlgorithm(selectedAlgorithm) {
        setAlgorithm(selectedAlgorithm);
    }
    const form = formData(algorithm, props?.filter?.value || {});
    return (_jsxs(HeaderContainer, { children: [_jsx(Label, { title: "Algorithm: ", style: headerLabelStyle, children: _jsx(Select, { items: getAlgorithmsList(), value: algorithm, onChange: handleChangeAlgorithm }) }), _jsx(Formik, { onSubmit: (values) => handleApplyFilter(values), initialValues: form.values, validationSchema: form.validation, enableReinitialize: true, children: ({ submitForm }) => (_jsxs(_Fragment, { children: [algorithm && algorithm === 'airpls' && (_jsxs("div", { style: { display: 'flex' }, children: [_jsx(Label, { title: "maxIterations:", style: headerLabelStyle, children: _jsx(FormikInput, { type: "number", name: "maxIterations", debounceTime: 250, style: inputStyle }) }), _jsx(Label, { title: "tolerance:", style: headerLabelStyle, children: _jsx(FormikInput, { type: "number", name: "tolerance", debounceTime: 250, style: inputStyle }) })] })), algorithm &&
                            ['autoPolynomial', 'polynomial'].includes(algorithm) && (_jsx(Label, { title: "degree [ 1 - 6 ]:", shortTitle: "degree :", style: headerLabelStyle, children: _jsx(FormikInput, { type: "number", name: "degree", min: 1, max: 6, style: inputStyle, debounceTime: 250 }) })), _jsx(Label, { title: "live preview ", htmlFor: "livePreview", style: headerLabelStyle, children: _jsx(FormikCheckBox, { name: "livePreview" }) }), _jsx(FormikOnChange, { onChange: (values) => handleApplyFilter(values, 'onChange'), enableOnload: true }), _jsx(ActionButtons, { onDone: submitForm, onCancel: handleCancelFilter })] })) })] }));
}
const MemoizedBaseLineCorrectionPanel = memo(BaseLineCorrectionInnerPanel);
export default function BaseLineCorrectionPanel() {
    const filter = useFilter(Filters.baselineCorrection.id);
    return _jsx(MemoizedBaseLineCorrectionPanel, { filter: filter });
}
