import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { Formik } from 'formik';
import { Filters } from 'nmr-processing';
import { memo, useRef } from 'react';
import generateNumbersPowerOfX from '../../data/utilities/generateNumbersPowerOfX';
import { useDispatch } from '../context/DispatchContext';
import ActionButtons from '../elements/ActionButtons';
import Label from '../elements/Label';
import FormikCheckBox from '../elements/formik/FormikCheckBox';
import FormikOnChange from '../elements/formik/FormikOnChange';
import FormikSelect from '../elements/formik/FormikSelect';
import { useFilter } from '../hooks/useFilter';
import useSpectrum from '../hooks/useSpectrum';
import { headerLabelStyle } from './Header';
import { HeaderContainer } from './HeaderContainer';
const Sizes = generateNumbersPowerOfX(8, 21);
function useInitZeroFillingSize() {
    const filter = useFilter(Filters.zeroFilling.id);
    const { data } = useSpectrum();
    if (filter) {
        return filter.value.nbPoints;
    }
    else if (data) {
        return 2 ** Math.round(Math.log2(data.x.length * 2));
    }
    return 0;
}
function ZeroFillingOptionsInnerPanel(props) {
    const { size } = props;
    const dispatch = useDispatch();
    const previousPreviewRef = useRef(true);
    function handleApplyFilter(values, triggerSource = 'apply') {
        const { livePreview, ...options } = values;
        switch (triggerSource) {
            case 'onChange': {
                if (livePreview || previousPreviewRef !== livePreview) {
                    dispatch({
                        type: 'CALCULATE_ZERO_FILLING_FILTER',
                        payload: {
                            options,
                            livePreview,
                        },
                    });
                }
                break;
            }
            case 'apply': {
                dispatch({
                    type: 'APPLY_ZERO_FILLING_FILTER',
                    payload: {
                        options,
                    },
                });
                break;
            }
            default:
                break;
        }
        previousPreviewRef.current = livePreview;
    }
    function handleCancelFilter() {
        dispatch({
            type: 'RESET_SELECTED_TOOL',
        });
    }
    return (_jsx(HeaderContainer, { children: _jsx(Formik, { onSubmit: (values) => handleApplyFilter(values), initialValues: { nbPoints: size, livePreview: true }, children: ({ submitForm }) => (_jsxs(_Fragment, { children: [_jsx(Label, { title: "Size:  ", style: headerLabelStyle, children: _jsx(FormikSelect, { items: Sizes, style: { marginLeft: 10, marginRight: 10 }, name: "nbPoints" }) }), _jsx(Label, { title: "Live preview ", htmlFor: "livePreview", style: { label: { padding: '0 5px' } }, children: _jsx(FormikCheckBox, { name: "livePreview" }) }), _jsx(FormikOnChange, { onChange: (values) => handleApplyFilter(values, 'onChange'), enableOnload: true }), _jsx(ActionButtons, { onDone: submitForm, onCancel: handleCancelFilter })] })) }) }));
}
const MemoizedZeroFillingOptionsPanel = memo(ZeroFillingOptionsInnerPanel);
export default function ZeroFillingOptionsPanel() {
    const size = useInitZeroFillingSize();
    return _jsx(MemoizedZeroFillingOptionsPanel, { size: size });
}
