import { Range } from 'nmr-processing';
import { MouseEvent, CSSProperties } from 'react';
import { ExclusionZone } from '../../data/types/data1d/ExclusionZone';
export declare enum HighlightEventSource {
    PEAK = "PEAK",
    INTEGRAL = "INTEGRAL",
    SIGNAL = "SIGNAL",
    RANGE = "RANGE",
    RANGE_PEAK = "RANGE_PEAK",
    ZONE = "ZONE",
    BASELINE_ZONE = "BASELINE_ZONE",
    EXCLUSION_ZONE = "EXCLUSION_ZONE",
    MATRIX_GENERATION_EXCLUSION_ZONE = "MATRIX_GENERATION_EXCLUSION_ZONE",
    MULTIPLE_ANALYSIS_ZONE = "MULTIPLE_ANALYSIS_ZONE",
    DATABASE = "DATABASE",
    ATOM = "ATOM",
    PHASE_CORRECTION_TRACE = "PHASE_CORRECTION_TRACE",
    UNKNOWN = "UNKNOWN"
}
type HighlightEventSourceType = keyof typeof HighlightEventSource;
interface SourceData {
    type: HighlightEventSourceType;
    extra?: {
        zone?: ExclusionZone;
        spectrumID?: string;
        id?: string;
        jcampURL?: string;
        baseURL?: string;
        ranges?: Range[];
        colKey?: string;
    } | null;
}
type HighlightActions = 'HIDE' | 'SHOW' | 'SET_PERMANENT' | 'UNSET_PERMANENT';
interface HighlightState {
    highlights: Record<string, number>;
    highlighted: string[];
    highlightedPermanently: string[];
    sourceData: SourceData | null;
}
interface HighlightPayload {
    convertedHighlights: string[];
    id?: number | string;
    sourceData?: SourceData | null;
}
interface HighlightContextProps {
    highlight: HighlightState;
    dispatch: (props: {
        type: HighlightActions;
        payload?: HighlightPayload;
    }) => void;
    remove: () => void;
}
export declare function HighlightProvider(props: any): import("react/jsx-runtime").JSX.Element;
export declare function useHighlightData(): HighlightContextProps;
/**
 * @param {Array<string | number>}  highlights
 * @param {SourceData = null} sourceData
 */
export declare function useHighlight(highlights: Array<string | number>, sourceData?: SourceData | null): {
    isActive: boolean;
    defaultActiveStyle: CSSProperties;
    onHover: {
        onMouseEnter: () => void;
        onMouseLeave: () => void;
    };
    onClick: (e: MouseEvent) => void;
    show: () => void;
    hide: () => void;
    isActivePermanently: boolean;
    click: (e: MouseEvent) => void;
    add: (id: number | string) => void;
    remove: (id: number | string) => void;
};
export {};
