import { useMemo } from 'react';
import { useChartData } from '../context/ChartContext';
import nucleusToString from '../utility/nucleusToString';
import { useActiveSpectrum } from './useActiveSpectrum';
const emptyData = { info: {}, datum: {}, ftCounter: 0, fidCounter: 0 };
export default function useDatumWithSpectraStatistics() {
    const { data, view: { spectra: { activeTab }, }, } = useChartData();
    const activeSpectrum = useActiveSpectrum();
    return useMemo(() => {
        if (data) {
            let info = {};
            let datum = {};
            let ftCounter = 0;
            let fidCounter = 0;
            for (const dataInfo of data) {
                const { isFid, isFt, nucleus } = dataInfo.info;
                if (activeTab === nucleusToString(nucleus)) {
                    if (isFid) {
                        fidCounter++;
                    }
                    if (isFt) {
                        ftCounter++;
                    }
                    if (activeSpectrum && dataInfo.id === activeSpectrum.id) {
                        info = dataInfo.info;
                        datum = dataInfo.data;
                    }
                }
            }
            return {
                info,
                datum,
                ftCounter,
                fidCounter,
            };
        }
        return emptyData;
    }, [activeSpectrum, data, activeTab]);
}
