import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Dialog } from '@blueprintjs/core';
import { Formik } from 'formik';
import { useRef, forwardRef } from 'react';
import { useOnOff } from 'react-science/ui';
import * as Yup from 'yup';
import { usePreferences } from '../context/PreferencesContext';
import FormikInput from '../elements/formik/FormikInput';
import { useAlert } from '../elements/popup/Alert/Context';
import ConfirmationDialog from '../elements/popup/Modal/ConfirmDialog';
const schema = Yup.object().shape({
    workspaceName: Yup.string().required(),
});
const WorkspaceAddForm = forwardRef(({ className, message, onSave }, ref) => {
    return (_jsxs("div", { className: className, children: [_jsx("p", { style: { paddingBottom: '10px' }, children: message }), _jsx(Formik, { initialValues: { workspaceName: '' }, validationSchema: schema, onSubmit: onSave, innerRef: ref, children: _jsx(FormikInput, { name: "workspaceName", placeholder: "Enter workspace Name", style: {
                        input: {
                            padding: '0.5em',
                            width: '90%',
                            fontWeight: 'normal',
                            color: 'black',
                        },
                    }, autoFocus: true }) })] }));
});
export function useSaveSettings() {
    const alert = useAlert();
    const [isOpenDialog, openDialog, closeDialog] = useOnOff(false);
    const settingsRef = useRef();
    const { dispatch, current } = usePreferences();
    const formRef = useRef(null);
    function addNewWorkspace({ workspaceName }) {
        dispatch({
            type: 'ADD_WORKSPACE',
            payload: {
                workspaceKey: workspaceName,
                data: settingsRef.current,
            },
        });
        closeDialog();
        alert.success('Preferences saved successfully');
    }
    return {
        saveSettings: (values) => {
            settingsRef.current = values;
            if (current.source !== 'user') {
                openDialog();
            }
            else {
                dispatch({
                    type: 'SET_PREFERENCES',
                    ...(values && { payload: values }),
                });
                closeDialog();
            }
        },
        SaveSettingsModal: () => {
            const alertConfig = {
                message: 'Please enter a new user workspace name in order to save your changes locally',
                render: (props) => (_jsx(WorkspaceAddForm, { ...props, onSave: addNewWorkspace, ref: formRef })),
                buttons: [
                    {
                        text: 'Save',
                        handler: () => {
                            void formRef.current?.submitForm();
                        },
                        preventClose: true,
                    },
                    { text: 'Cancel' },
                ],
                id: 'save-workspace-dialog',
                onClose: closeDialog,
            };
            return (_jsx(Dialog, { onClose: closeDialog, isOpen: isOpenDialog, title: "Save workspace", children: _jsx(ConfirmationDialog, { disableDefaultStyle: true, ...alertConfig }) }));
        },
    };
}
