import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { Dialog, DialogBody, DialogFooter } from '@blueprintjs/core';
import { css } from '@emotion/react';
import { useMemo } from 'react';
import { FaRegTrashAlt } from 'react-icons/fa';
import { IoBugOutline } from 'react-icons/io5';
import { ObjectInspector } from 'react-inspector';
import { useOnOff } from 'react-science/ui';
import { useLogger } from '../context/LoggerContext';
import Button from '../elements/Button';
import { ColumnWrapper } from '../elements/ColumnWrapper';
import ReactTable from '../elements/ReactTable/ReactTable';
const logsDataFormat = new Intl.DateTimeFormat('default', {
    hour: 'numeric',
    minute: 'numeric',
    second: 'numeric',
});
function handleRowStyle(data) {
    const level = (data?.original).level;
    let backgroundColor = 'lightgreen';
    if (level > 40) {
        backgroundColor = 'pink';
    }
    else if (level === 40) {
        backgroundColor = 'lightyellow';
    }
    return { base: { backgroundColor } };
}
function getMaxLevelLogs(logs, lastReadLogId) {
    const logsCounts = {};
    for (const log of logs) {
        if (log.id > lastReadLogId) {
            logsCounts[log.level] = ++logsCounts[log.level] || 1;
        }
    }
    let maxLevel = 0;
    for (const levelKey in logsCounts) {
        const level = Number(levelKey);
        if (level > maxLevel) {
            maxLevel = level;
        }
    }
    let backgroundColor = '#2dd36f';
    if (maxLevel > 40) {
        backgroundColor = '#ff0000';
    }
    else if (maxLevel === 40) {
        backgroundColor = '#ffc409';
    }
    return { backgroundColor, count: logsCounts[maxLevel] };
}
export function LogsHistoryModal(props) {
    const { autoOpen = false, onClose } = props;
    const { logsHistory, logger, markAsRead, lastReadLogId } = useLogger();
    const [isOpenDialog, openDialog, closeDialog] = useOnOff(autoOpen);
    const { count, backgroundColor } = getMaxLevelLogs(logsHistory, lastReadLogId);
    const COLUMNS = useMemo(() => [
        {
            Header: '#',
            accessor: (_, index) => index + 1,
            Cell: ({ row }) => (_jsxs("span", { children: [row.original.id > lastReadLogId && (_jsx("div", { style: {
                            width: '5px',
                            height: '5px',
                            borderRadius: '50%',
                            backgroundColor: '#ffc409',
                            display: 'inline-block',
                            margin: '0 3px',
                        } })), row.index + 1] })),
            style: { width: '40px' },
        },
        {
            Header: 'Time',
            accessor: (row) => logsDataFormat.format(row.time),
            style: { width: '100px' },
        },
        {
            Header: 'Label',
            accessor: 'levelLabel',
            style: { width: '60px' },
        },
        {
            Header: 'Message',
            accessor: 'message',
        },
        {
            Header: 'Error',
            Cell: ({ row }) => {
                const { error } = row.original;
                return (_jsx(ColumnWrapper, { children: _jsx(ObjectInspector, { data: error || {} }) }));
            },
        },
    ], [lastReadLogId]);
    const sortedLogs = logsHistory.slice().sort((a, b) => b.time - a.time);
    return (_jsxs(_Fragment, { children: [!autoOpen && (_jsx(Button.BarButton, { onClick: () => {
                    openDialog();
                }, children: _jsxs("div", { style: { position: 'relative' }, children: [_jsx(IoBugOutline, { fontSize: "1.4em" }), count && (_jsx("span", { style: {
                                position: 'absolute',
                                top: '-0.4em',
                                left: '-0.4em',
                                backgroundColor,
                                borderRadius: '50%',
                                minWidth: '14px',
                                fontSize: '0.75em',
                                color: 'white',
                            }, children: count }))] }) })), _jsxs(Dialog, { isOpen: isOpenDialog, onClose: () => {
                    markAsRead();
                    closeDialog();
                    onClose?.();
                }, title: "Logs History", style: { width: '50vw', height: '50vh' }, children: [_jsx(DialogBody, { css: css `
            background-color: white;
          `, children: _jsx(ReactTable, { columns: COLUMNS, data: sortedLogs, emptyDataRowText: "No Logs", rowStyle: handleRowStyle }) }), _jsx(DialogFooter, { children: _jsx(Button.Danger, { onClick: () => logger.clear(), fill: "outline", children: _jsxs("div", { style: { display: 'flex', alignItems: 'center' }, children: [_jsx(FaRegTrashAlt, {}), _jsx("span", { style: { paddingLeft: '5px' }, children: "Clear Logs" })] }) }) })] })] }));
}
