import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { useFormikContext } from 'formik';
import { useCallback, useState, useEffect, useMemo } from 'react';
import getAtom from '../../../data/utilities/getAtom';
import { useChartData } from '../../context/ChartContext';
import MoleculeSelection from '../../elements/MoleculeSelection';
const styles = css `
  .molecule-container {
    display: flex;
    flex-direction: column;
    flex-grow: 1;

    .title {
      padding: 0 10px;
      width: 100%;
      text-align: center;
    }

    .molecule-selection-container {
      width: 450px;
      display: block;
      margin: 0 auto;
    }

    .new-sum-text {
      margin-top: 15px;
      padding: 0 10px;
      width: 100%;
      text-align: center;
    }
  }

  .empty {
    width: 100%;
    padding: 20%;
    text-align: center;
  }
`;
export default function SelectMolecule(props) {
    const [currentIndex, setCurrentIndex] = useState();
    const { setFieldValue, errors, values } = useFormikContext();
    const { molecules, view: { spectra: { activeTab }, }, } = useChartData();
    const element = getAtom(activeTab);
    const newSum = useMemo(() => {
        return element &&
            molecules &&
            molecules.length > 0 &&
            currentIndex !== undefined &&
            molecules[currentIndex].atoms[element]
            ? molecules[currentIndex].atoms[element]
            : 0;
    }, [currentIndex, element, molecules]);
    const setValue = useCallback((index) => {
        setCurrentIndex(index);
        void setFieldValue(props.name, molecules[index]);
    }, [molecules, props.name, setFieldValue]);
    useEffect(() => {
        if (molecules && molecules.length > 0) {
            const index = values[props.name]
                ? molecules.findIndex((molecule) => molecule.id === values[props.name].id)
                : -1;
            setValue(index !== -1 ? index : 0);
        }
    }, [molecules, props.name, setValue, values]);
    const onChangeMoleculeSelectionHandler = useCallback((index) => {
        setValue(index);
    }, [setValue]);
    return (_jsx("div", { css: styles, children: element && molecules && molecules.length > 0 ? (_jsxs("div", { className: "molecule-container", children: [_jsx("p", { className: "title", children: "Select a molecule as reference!" }), _jsxs("div", { className: "molecule-selection-container", children: [_jsx(MoleculeSelection, { index: currentIndex, molecules: molecules, onChange: onChangeMoleculeSelectionHandler }), _jsxs("p", { className: "new-sum-text", children: ["New sum for ", element, " will be ", newSum, "!"] })] })] })) : (_jsx("p", { className: "empty", style: { color: errors[props.name] ? 'red' : 'black' }, children: "You have to Select a spectrum and Add a molecule from the Structure panel to select as a reference!" })) }));
}
