import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { Formik } from 'formik';
import { useCallback, useEffect, useMemo, useRef } from 'react';
import { FaSearchPlus } from 'react-icons/fa';
import DefaultPathLengths from '../../../data/constants/DefaultPathLengths';
import Button from '../../elements/Button';
import { CloseButton } from '../../elements/CloseButton';
import { SaveButton } from '../../elements/SaveButton';
import SignalsForm from './SignalsForm';
import zoneFormValidation from './validation/EditZoneValidation';
import isDefaultPathLength from './validation/isDefaultPathLength';
const styles = css `
  width: 500px;
  height: 250px;
  padding: 5px;

  button:focus {
    outline: none;
  }

  .header {
    height: 24px;
    border-bottom: 1px solid #f0f0f0;
    display: flex;
    align-items: center;

    span {
      color: #464646;
      font-size: 15px;
      flex: 1;
      border-left: 1px solid #ececec;
      padding-left: 6px;
    }

    button {
      background-color: transparent;
      border: none;
      padding: 5px;

      svg {
        height: 16px;
      }
    }
  }

  .container {
    display: flex;
    margin: 30px 5px;
  }
`;
function EditZoneModal({ onSaveEditZoneModal = () => null, onCloseEditZoneModal = () => null, onZoomEditZoneModal = () => null, rowData, }) {
    const formRef = useRef(null);
    const handleOnZoom = useCallback(() => {
        onZoomEditZoneModal(rowData);
    }, [onZoomEditZoneModal, rowData]);
    useEffect(() => {
        handleOnZoom();
    }, [handleOnZoom]);
    const handleOnClose = useCallback(() => {
        onCloseEditZoneModal();
    }, [onCloseEditZoneModal]);
    const handleOnSave = useCallback((formValues) => {
        void (async () => {
            const _rowData = {
                ...rowData,
                signals: formValues.signals.map((signal) => {
                    if (isDefaultPathLength(signal.j?.pathLength, rowData.tableMetaInfo.experiment)) {
                        delete signal.j?.pathLength;
                        if (signal.j && Object.keys(signal.j).length === 0) {
                            delete signal.j;
                        }
                    }
                    return signal;
                }),
            };
            await onSaveEditZoneModal(_rowData);
            handleOnClose();
        })();
    }, [handleOnClose, onSaveEditZoneModal, rowData]);
    const data = useMemo(() => {
        return {
            activeTab: '0',
            signals: rowData.signals.map((signal) => {
                return {
                    ...signal,
                    j: {
                        pathLength: {
                            from: DefaultPathLengths[rowData.tableMetaInfo.experiment]?.from || 1,
                            to: DefaultPathLengths[rowData.tableMetaInfo.experiment]?.to || 1,
                        },
                        ...signal.j,
                    },
                };
            }),
        };
    }, [rowData.signals, rowData.tableMetaInfo.experiment]);
    return (_jsx("div", { css: styles, children: _jsx(Formik, { innerRef: formRef, initialValues: data, validationSchema: zoneFormValidation, onSubmit: handleOnSave, children: _jsxs(_Fragment, { children: [_jsxs("div", { className: "header handle", children: [_jsx(Button, { onClick: handleOnZoom, className: "zoom-button", children: _jsx(FaSearchPlus, { title: "Set to default view on range in spectrum" }) }), _jsx("span", { children: `Zone and Signal edition` }), _jsx(SaveButton, { onClick: () => formRef.current.submitForm(), title: "Save and Exit" }), _jsx(CloseButton, { title: "Close", onClick: handleOnClose })] }), _jsx(SignalsForm, {})] }) }) }));
}
export default EditZoneModal;
