import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useFormikContext } from 'formik';
import { useCallback, useMemo } from 'react';
import { FaPlus, FaTimes } from 'react-icons/fa';
import { useChartData } from '../../../context/ChartContext';
import Button from '../../../elements/Button';
import { CheckBoxCell } from '../../../elements/CheckBoxCell';
import { GroupPane } from '../../../elements/GroupPane';
import Label from '../../../elements/Label';
import ReactTable from '../../../elements/ReactTable/ReactTable';
import FormikCheckBox from '../../../elements/formik/FormikCheckBox';
import FormikInput from '../../../elements/formik/FormikInput';
import { convertPathArrayToString } from '../../../utility/convertPathArrayToString';
import { getSpectraObjectPaths } from '../../../utility/getSpectraObjectPaths';
const styles = {
    input: {
        width: '100%',
    },
    column: {
        padding: '2px',
    },
};
function InfoBlockTabContent() {
    const { values, setFieldValue } = useFormikContext();
    const { data } = useChartData();
    const { datalist, paths } = useMemo(() => getSpectraObjectPaths(data), [data]);
    const fields = values?.infoBlock.fields;
    const addHandler = useCallback((data, index) => {
        let columns = [];
        const emptyField = {
            label: '',
            jpath: null,
            visible: true,
        };
        if (data && Array.isArray(data)) {
            columns = [...data.slice(0, index), emptyField, ...data.slice(index)];
        }
        else {
            columns.push(emptyField);
        }
        void setFieldValue('infoBlock.fields', columns);
    }, [setFieldValue]);
    const deleteHandler = useCallback((data, index) => {
        const _fields = data.filter((_, columnIndex) => columnIndex !== index);
        void setFieldValue('infoBlock.fields', _fields);
    }, [setFieldValue]);
    const COLUMNS = useMemo(() => [
        {
            Header: '#',
            style: { width: '25px', ...styles.column },
            accessor: (_, index) => index + 1,
        },
        {
            Header: 'Label',
            style: { padding: 0, ...styles.column },
            Cell: ({ row }) => {
                return (_jsx(FormikInput, { name: `infoBlock.fields.${row.index}.label`, style: { input: styles.input } }));
            },
        },
        {
            Header: 'Field',
            style: { padding: 0, ...styles.column },
            Cell: ({ row }) => {
                return (_jsx(FormikInput, { name: `infoBlock.fields.${row.index}.jpath`, style: { input: styles.input }, mapOnChangeValue: (key) => paths?.[key] || key, mapValue: (paths) => convertPathArrayToString(paths), datalist: datalist }));
            },
        },
        {
            Header: 'Format',
            style: { padding: 0, ...styles.column },
            Cell: ({ row }) => {
                return (_jsx(FormikInput, { name: `infoBlock.fields.${row.index}.format`, style: { input: styles.input } }));
            },
        },
        {
            Header: 'Visible',
            style: { width: '30px', ...styles.column },
            Cell: ({ row }) => (_jsx(CheckBoxCell, { name: `infoBlock.fields.${row.index}.visible`, defaultValue: true })),
        },
        {
            Header: '',
            style: { width: '70px', ...styles.column },
            id: 'add-button',
            Cell: ({ data, row }) => {
                const record = row.original;
                return (_jsxs("div", { style: { display: 'flex', justifyContent: 'space-around' }, children: [_jsx(Button.Done, { fill: "outline", onClick: () => addHandler(data, row.index + 1), children: _jsx(FaPlus, {}) }), !record?.name && (_jsx(Button.Danger, { fill: "outline", onClick: () => deleteHandler(data, row.index), children: _jsx(FaTimes, {}) }))] }));
            },
        },
    ], [addHandler, datalist, deleteHandler, paths]);
    return (_jsxs("div", { children: [_jsx(Label, { title: "Display spectrum info block", htmlFor: "infoBlock.visible", style: { wrapper: { padding: '10px 0' } }, children: _jsx(FormikCheckBox, { name: "infoBlock.visible" }) }), _jsx(GroupPane, { text: "Fields", renderHeader: (text) => {
                    return (_jsx(FieldsBlockHeader, { text: text, onAdd: () => addHandler(fields, 0) }));
                }, children: _jsx(ReactTable, { style: {
                        'table, table td, table th': { border: 'none' },
                        'table thead': { borderBottom: '1px solid #f9f9f9' },
                    }, data: fields, columns: COLUMNS, emptyDataRowText: "No Fields" }) })] }));
}
function FieldsBlockHeader({ onAdd, text }) {
    return (_jsxs("div", { className: "section-header", style: { display: 'flex' }, children: [_jsx("p", { style: { flex: 1 }, children: text }), _jsx(Button.Done, { fill: "outline", size: "xSmall", onClick: onAdd, children: "Add Field" })] }));
}
export default InfoBlockTabContent;
