import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useFormikContext } from 'formik';
import { useCallback, useMemo } from 'react';
import { FaPlus, FaTimes } from 'react-icons/fa';
import { useChartData } from '../../../context/ChartContext';
import Button from '../../../elements/Button';
import { GroupPane } from '../../../elements/GroupPane';
import ReactTable from '../../../elements/ReactTable/ReactTable';
import FormikColorPickerDropdown from '../../../elements/formik/FormikColorPickerDropdown';
import FormikInput from '../../../elements/formik/FormikInput';
import { convertPathArrayToString } from '../../../utility/convertPathArrayToString';
import { getSpectraObjectPaths } from '../../../utility/getSpectraObjectPaths';
const styles = {
    input: {
        width: '100%',
    },
    column: {
        padding: '2px',
    },
};
const colorInputStyle = {
    padding: 0,
    minWidth: '80px',
    width: '80px',
    ...styles.column,
};
function getObjectKey(key) {
    return `spectraColors.${key}`;
}
function SpectraColorsTabContent() {
    const { values, setFieldValue } = useFormikContext();
    const { data } = useChartData();
    const { datalist, paths } = useMemo(() => getSpectraObjectPaths(data), [data]);
    const { oneDimension = [], twoDimensions = [] } = values?.spectraColors || {};
    const addHandler = useCallback((data, index, key) => {
        let columns = [];
        const emptyField = key === 'oneDimension'
            ? {
                value: null,
                jpath: ['info', 'experiment'],
                color: 'red',
            }
            : {
                value: null,
                jpath: ['info', 'experiment'],
                positiveColor: 'red',
                negativeColor: 'blue',
            };
        if (data && Array.isArray(data)) {
            columns = [...data.slice(0, index), emptyField, ...data.slice(index)];
        }
        else {
            columns.push(emptyField);
        }
        void setFieldValue(getObjectKey(key), columns);
    }, [setFieldValue]);
    const deleteHandler = useCallback((data, index, key) => {
        const _fields = data.filter((_, columnIndex) => columnIndex !== index);
        void setFieldValue(getObjectKey(key), _fields);
    }, [setFieldValue]);
    return (_jsxs("div", { children: [_jsx(SpectraColorsFields, { groupLabel: "One dimension", baseObjectPath: "oneDimension", data: oneDimension, datalist: datalist, paths: paths, onAdd: addHandler, onDelete: deleteHandler }), _jsx(SpectraColorsFields, { groupLabel: "Two dimensions", baseObjectPath: "twoDimensions", data: twoDimensions, datalist: datalist, paths: paths, onAdd: addHandler, onDelete: deleteHandler })] }));
}
function SpectraColorsFields(props) {
    const { onAdd, onDelete, datalist, paths, data, baseObjectPath, groupLabel } = props;
    const COLUMNS = useMemo(() => {
        const objectPath = getObjectKey(baseObjectPath);
        const baseColumns = [
            {
                Header: '#',
                style: { width: '25px', ...styles.column },
                accessor: (_, index) => index + 1,
            },
            {
                Header: 'Field',
                style: { padding: 0, ...styles.column },
                Cell: ({ row }) => {
                    return (_jsx(FormikInput, { name: `${objectPath}.${row.index}.jpath`, style: { input: styles.input }, mapOnChangeValue: (key) => {
                            return paths?.[key.toString().trim()] || key;
                        }, mapValue: (paths) => convertPathArrayToString(paths), datalist: datalist }));
                },
            },
            {
                Header: 'Value',
                style: { padding: 0, ...styles.column },
                Cell: ({ row }) => {
                    return (_jsx(FormikInput, { name: `${objectPath}.${row.index}.value`, style: { input: styles.input } }));
                },
            },
        ];
        const operationsField = {
            Header: '',
            style: { width: '70px', ...styles.column },
            id: 'operation-button',
            Cell: ({ data, row }) => {
                const record = row.original;
                return (_jsxs("div", { style: { display: 'flex', justifyContent: 'space-around' }, children: [_jsx(Button.Done, { fill: "outline", onClick: () => onAdd(data, row.index + 1, baseObjectPath), children: _jsx(FaPlus, {}) }), !record?.name && (_jsx(Button.Danger, { fill: "outline", onClick: () => onDelete(data, row.index, baseObjectPath), children: _jsx(FaTimes, {}) }))] }));
            },
        };
        if (baseObjectPath === 'oneDimension') {
            const colorField = {
                Header: 'Color',
                style: colorInputStyle,
                Cell: ({ row }) => (_jsx(FormikColorPickerDropdown, { name: `${objectPath}.${row.index}.color` })),
            };
            return [...baseColumns, colorField, operationsField];
        }
        const colorFields = [
            {
                Header: 'Positive color',
                style: colorInputStyle,
                Cell: ({ row }) => (_jsx(FormikColorPickerDropdown, { name: `${objectPath}.${row.index}.positiveColor` })),
            },
            {
                Header: 'Negative color',
                style: colorInputStyle,
                Cell: ({ row }) => (_jsx(FormikColorPickerDropdown, { name: `${objectPath}.${row.index}.negativeColor` })),
            },
        ];
        return [...baseColumns, ...colorFields, operationsField];
    }, [baseObjectPath, datalist, onAdd, onDelete, paths]);
    return (_jsx(GroupPane, { text: groupLabel, renderHeader: (text) => {
            return (_jsx(FieldsBlockHeader, { text: text, onAdd: () => onAdd(data, 0, baseObjectPath) }));
        }, children: _jsx(ReactTable, { style: {
                'table, table td, table th': { border: 'none' },
                'table thead': { borderBottom: '1px solid #f9f9f9' },
            }, data: data, columns: COLUMNS, emptyDataRowText: "No Fields" }) }));
}
function FieldsBlockHeader({ onAdd, text }) {
    return (_jsxs("div", { className: "section-header", style: { display: 'flex' }, children: [_jsx("p", { style: { flex: 1 }, children: text }), _jsx(Button.Done, { fill: "outline", size: "xSmall", onClick: onAdd, children: "Add custom color" })] }));
}
export default SpectraColorsTabContent;
