import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { useFormikContext } from 'formik';
import { FaPlus, FaTimes } from 'react-icons/fa';
import { normalCase } from '../../../data/matrixGeneration';
import Button from '../../elements/Button';
import { GroupPane } from '../../elements/GroupPane';
import Label from '../../elements/Label';
import Select from '../../elements/Select';
import FormikCheckBox from '../../elements/formik/FormikCheckBox';
import FormikInput from '../../elements/formik/FormikInput';
import FormikSelect from '../../elements/formik/FormikSelect';
import { DEFAULT_MATRIX_FILTERS, GroupPanelStyle, } from './MatrixGenerationPanel';
const inputStyle = {
    input: { padding: '0.4em', width: '100%' },
};
export function FiltersOptions() {
    const { values } = useFormikContext();
    if (!values?.filters || !Array.isArray(values.filters)) {
        return null;
    }
    return values.filters.map((filter, index) => {
        return (_jsx(GroupPane
        // eslint-disable-next-line react/no-array-index-key
        , { text: `${index + 1} - ${normalCase(filter.name)} options`, style: { ...GroupPanelStyle, container: { padding: 0 } }, renderHeader: (text) => (_jsx(FiltersPanelGroupHeader, { index, text, name: filter.name })), children: _jsx(Fields, { filter: filter, basePath: `filters.${index}` }) }, `${index}`));
    });
}
function Fields(props) {
    const fields = Object.entries(props.filter.properties);
    return (_jsx("div", { children: fields.map(([key, field]) => {
            const keyPath = `${props.basePath}.options.${key}`;
            switch (field.type) {
                case 'label': {
                    const fieldsGroupName = key.split('.')?.[field.level] || '';
                    return (_jsx(Label, { title: normalCase(fieldsGroupName), style: {
                            label: { fontWeight: 'bold' },
                            container: {
                                paddingLeft: `${10 * field.level}px`,
                                paddingTop: '10px',
                            },
                        }, children: _jsx("span", {}) }, key));
                }
                case 'string':
                case 'number': {
                    const Field = (_jsx(Label, { title: field.name, style: {
                            label: { width: '150px' },
                            container: {
                                paddingLeft: `${10 * field.level}px`,
                                paddingTop: '5px',
                            },
                        }, children: _jsx(FormikInput, { name: keyPath, type: field.type === 'string' ? 'text' : 'number', style: inputStyle, placeholder: `${field.default}` }) }, key));
                    return Field;
                }
                case 'boolean': {
                    return (_jsx(Label, { title: field.name, style: {
                            label: { width: '150px' },
                            container: {
                                paddingTop: '5px',
                                paddingLeft: `${10 * field.level}px`,
                            },
                        }, children: _jsx(FormikCheckBox, { name: keyPath }) }, key));
                }
                case 'select': {
                    return (_jsx(Label, { title: field.name, style: {
                            label: { width: '150px' },
                            container: {
                                paddingTop: '5px',
                                paddingLeft: `${10 * field.level}px`,
                            },
                        }, children: _jsx(FormikSelect, { items: mapSelectList(field.choices), name: keyPath }) }, key));
                }
                default:
                    return null;
            }
        }) }));
}
function mapSelectList(array) {
    return array.map((val) => ({ value: val, label: normalCase(val) }));
}
function FiltersPanelGroupHeader({ index, name }) {
    const { values, setFieldValue } = useFormikContext();
    function handelSelectFilter(value, index) {
        const filters = values.filters.slice(0);
        filters.splice(index, 1, value);
        void setFieldValue('filters', filters);
    }
    function handleAdd(index) {
        if (values.filters) {
            void setFieldValue('filters', [
                ...values.filters.slice(0, index),
                DEFAULT_MATRIX_FILTERS[0],
                ...values.filters.slice(index),
            ]);
        }
    }
    function handleDelete(index) {
        void setFieldValue('filters', values.filters.filter((_, i) => i !== index));
    }
    return (_jsxs("div", { className: "section-header", style: { display: 'flex', padding: '5px 0px' }, children: [_jsxs("p", { style: {
                    flex: 1,
                    margin: 0,
                    paddingRight: '5px',
                    ...GroupPanelStyle.header,
                }, children: [index + 1, "-"] }), _jsx(Select, { value: name, items: DEFAULT_MATRIX_FILTERS, onChange: (value) => handelSelectFilter(value, index), style: { width: '100%' }, returnValue: false, itemTextField: "name", itemValueField: "name", textRender: (text) => normalCase(text) }), _jsxs("div", { style: { display: 'flex' }, children: [_jsx(Button.Danger, { fill: "outline", onClick: () => handleDelete(index), style: { marginLeft: '5px' }, children: _jsx(FaTimes, {}) }), _jsx(Button.Done, { fill: "outline", onClick: () => handleAdd(index + 1), style: { marginLeft: '5px' }, children: _jsx(FaPlus, {}) })] })] }));
}
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function FieldInfo(props) {
    return (_jsxs("div", { style: { display: 'flex', flexDirection: 'column' }, children: [props.children, _jsx("span", { style: { fontSize: '11px', color: 'gray' }, children: props.description })] }));
}
