import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { SvgNmrExportAsMatrix, SvgNmrMultipleAnalysis } from 'cheminfo-font';
import { Formik } from 'formik';
import { useRef } from 'react';
import { FaCheck } from 'react-icons/fa';
import * as yup from 'yup';
import { getMatrixFilters } from '../../../data/matrixGeneration';
import { useChartData } from '../../context/ChartContext';
import { useDispatch } from '../../context/DispatchContext';
import { usePreferences } from '../../context/PreferencesContext';
import StyledButton from '../../elements/Button';
import { GroupPane } from '../../elements/GroupPane';
import Label from '../../elements/Label';
import ToggleButton from '../../elements/ToggleButton';
import FormikInput from '../../elements/formik/FormikInput';
import FormikOnChange from '../../elements/formik/FormikOnChange';
import { usePanelPreferences } from '../../hooks/usePanelPreferences';
import useToolsFunctions from '../../hooks/useToolsFunctions';
import { options } from '../../toolbar/ToolTypes';
import { exportAsMatrix } from '../../utility/export';
import { tablePanelStyle } from '../extra/BasicPanelStyle';
import { PreferencesContainer } from '../extra/preferences/PreferencesContainer';
import DefaultPanelHeader from '../header/DefaultPanelHeader';
import { ExclusionsZonesTable } from './ExclusionsZonesTable';
import { FiltersOptions } from './FiltersOptions';
const schema = yup.object().shape({
    range: yup.object({
        from: yup.number().required(),
        to: yup.number().required(),
    }),
    numberOfPoints: yup.number().required(),
});
const labelStyle = {
    label: { width: '120px' },
    wrapper: { flex: 1, display: 'flex', flexDirection: 'row' },
};
const inputStyle = {
    input: { padding: '0.2em 0.1em', width: '100%' },
};
export const DEFAULT_MATRIX_FILTERS = getMatrixFilters();
const DEFAULT_MATRIX_OPTIONS = {
    filters: [],
    exclusionsZones: [],
    numberOfPoints: 1024,
};
function getMatrixOptions(options, range) {
    return { ...DEFAULT_MATRIX_OPTIONS, range, ...options };
}
export const GroupPanelStyle = {
    container: { padding: '10px' },
    header: { color: 'black', fontWeight: 'bolder' },
};
function MatrixGenerationPanel() {
    const dispatch = useDispatch();
    const preferences = usePreferences();
    const { view: { spectra: { activeTab }, }, xDomain, data, } = useChartData();
    const formRef = useRef(null);
    const nucleusMatrixOptions = usePanelPreferences('matrixGeneration', activeTab);
    const spectraPreferences = usePanelPreferences('spectra', activeTab);
    const matrixOptions = getMatrixOptions(nucleusMatrixOptions, {
        from: xDomain[0],
        to: xDomain[1],
    });
    function handleExportAsMatrix() {
        exportAsMatrix(data, spectraPreferences?.columns || [], 'Spectra Matrix');
    }
    function handleSave(options) {
        dispatch({ type: 'APPLY_SIGNAL_PROCESSING_FILTER', payload: { options } });
    }
    function handleOnChange(options) {
        preferences.dispatch({
            type: 'SET_MATRIX_GENERATION_OPTIONS',
            payload: { options, nucleus: activeTab },
        });
    }
    function handleAddFilter() {
        const filters = matrixOptions.filters.slice();
        filters.push(DEFAULT_MATRIX_FILTERS[0]);
        handleOnChange({ ...matrixOptions, filters });
    }
    if (xDomain[0] === undefined || xDomain[1] === undefined) {
        return null;
    }
    return (_jsxs("div", { css: tablePanelStyle, children: [_jsx(DefaultPanelHeader, { leftButtons: [
                    {
                        icon: _jsx(SvgNmrExportAsMatrix, {}),
                        title: 'Export spectra as a matrix',
                        onClick: handleExportAsMatrix,
                    },
                ], rightButtons: [
                    {
                        onClick: () => formRef.current?.submitForm(),
                        title: 'Signal processing',
                        id: 'save-button',
                        intent: 'success',
                        icon: _jsx(FaCheck, {}),
                    },
                ] }), _jsx("div", { className: "inner-container", children: _jsx(PreferencesContainer, { style: { backgroundColor: 'white' }, children: _jsx(Formik, { innerRef: formRef, onSubmit: handleSave, initialValues: matrixOptions, enableReinitialize: true, validationSchema: schema, children: _jsxs(_Fragment, { children: [_jsx(GroupPane, { text: "Filters", style: GroupPanelStyle, renderHeader: (text) => (_jsx(FiltersPanelGroupHeader, { text: text, onAdd: handleAddFilter })), children: _jsx(FiltersOptions, {}) }), _jsx(GroupPane, { style: GroupPanelStyle, text: "Exclusions zones", renderHeader: (text) => (_jsx(ExclusionZonesGroupHeader, { text: text })), children: _jsx(ExclusionsZonesTable, {}) }), _jsxs(GroupPane, { text: "More options", style: GroupPanelStyle, children: [_jsxs(Label, { title: "Range", style: labelStyle, children: [_jsx(Label, { title: "From", children: _jsx(FormikInput, { name: "range.from", type: "number", style: inputStyle }) }), _jsx(Label, { title: "To", style: { container: { paddingLeft: '10px' } }, children: _jsx(FormikInput, { name: "range.to", type: "number", style: inputStyle }) })] }), _jsx(Label, { title: "Number of points", style: {
                                                ...labelStyle,
                                                wrapper: {},
                                                container: { paddingTop: '10px' },
                                            }, children: _jsx(FormikInput, { name: "numberOfPoints", type: "number", style: inputStyle }) })] }), _jsx(FormikOnChange, { onChange: handleOnChange })] }) }) }) })] }));
}
function FiltersPanelGroupHeader({ text, onAdd }) {
    return (_jsxs("div", { className: "section-header", style: { display: 'flex', padding: '5px 0px' }, children: [_jsx("p", { style: { flex: 1, ...GroupPanelStyle.header }, children: text }), _jsx(StyledButton.Done, { fill: "outline", size: "xSmall", onClick: onAdd, children: "Add Filter" })] }));
}
function ExclusionZonesGroupHeader({ text }) {
    const { toolOptions: { selectedTool }, } = useChartData();
    const { handleChangeOption } = useToolsFunctions();
    return (_jsxs("div", { className: "section-header", style: { display: 'flex', padding: '5px 0px' }, children: [_jsx("p", { style: { flex: 1, ...GroupPanelStyle.header }, children: text }), _jsx(ToggleButton, { defaultValue: selectedTool === options.matrixGenerationExclusionZones.id, popupTitle: "Select exclusions zones", popupPlacement: "left", onClick: () => handleChangeOption(options.matrixGenerationExclusionZones.id), children: _jsx(SvgNmrMultipleAnalysis, { style: {
                        pointerEvents: 'none',
                        fontSize: '12px',
                    } }) }, selectedTool)] }));
}
export default MatrixGenerationPanel;
