import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { xGetFromToIndex } from 'ml-spectra-processing';
import { useCallback, useMemo, memo, useState, useRef } from 'react';
import { FaCopy } from 'react-icons/fa';
import { ClipboardFallbackModal } from '../../../utils/clipboard/clipboardComponents';
import { useClipboard } from '../../../utils/clipboard/clipboardHooks';
import { useAssignmentData } from '../../assignment/AssignmentsContext';
import { useChartData } from '../../context/ChartContext';
import { useDispatch } from '../../context/DispatchContext';
import { useAlert } from '../../elements/popup/Alert';
import { usePanelPreferences } from '../../hooks/usePanelPreferences';
import useSpectrum from '../../hooks/useSpectrum';
import { tablePanelStyle } from '../extra/BasicPanelStyle';
import PreferencesHeader from '../header/PreferencesHeader';
import RangesHeader from './RangesHeader';
import RangesPreferences from './RangesPreferences';
import RangesTable from './RangesTable';
const rangesContextMenuOptions = [
    {
        text: 'Copy to Clipboard',
        icon: _jsx(FaCopy, {}),
    },
];
function RangesTablePanelInner({ id, ranges, data, info, xDomain, preferences, activeTab, molecules, }) {
    const [isFilterActive, setFilterIsActive] = useState(false);
    const assignmentData = useAssignmentData();
    const dispatch = useDispatch();
    const alert = useAlert();
    const [isFlipped, setFlipStatus] = useState(false);
    const settingRef = useRef();
    const rangesData = useMemo(() => {
        const isInView = (from, to) => {
            const factor = 10000;
            to = to * factor;
            from = from * factor;
            return ((to >= xDomain[0] * factor && from <= xDomain[1] * factor) ||
                (from <= xDomain[0] * factor && to >= xDomain[1] * factor));
        };
        const getFilteredRanges = (ranges) => {
            return ranges.filter((range) => isInView(range.from, range.to));
        };
        if (ranges.values) {
            const _ranges = isFilterActive
                ? getFilteredRanges(ranges.values)
                : ranges.values;
            return _ranges.map((range) => {
                return {
                    ...range,
                    tableMetaInfo: {
                        isConstantlyHighlighted: isInView(range.from, range.to),
                    },
                };
            });
        }
        return [];
    }, [isFilterActive, ranges.values, xDomain]);
    const unlinkRangeHandler = useCallback((rangeData, signalIndex = -1) => {
        dispatch({
            type: 'UNLINK_RANGE',
            payload: {
                range: rangeData,
                assignmentData,
                signalIndex,
            },
        });
    }, [assignmentData, dispatch]);
    const { rawWriteWithType, shouldFallback, cleanShouldFallback, text } = useClipboard();
    const saveJSONToClipboardHandler = useCallback(async (value) => {
        if (data.x && data.re) {
            const { x, re } = data;
            const { from, to } = value;
            const { fromIndex, toIndex } = xGetFromToIndex(x, {
                from,
                to,
            });
            const dataToClipboard = {
                x: Array.from(x.slice(fromIndex, toIndex)),
                y: Array.from(re.slice(fromIndex, toIndex)),
                ...value,
            };
            await rawWriteWithType(JSON.stringify(dataToClipboard, undefined, 2));
            alert.show('Data copied to clipboard');
        }
    }, [data, rawWriteWithType, alert]);
    const contextMenuSelectHandler = useCallback((option, data) => {
        void saveJSONToClipboardHandler(data);
    }, [saveJSONToClipboardHandler]);
    const filterHandler = useCallback(() => {
        setFilterIsActive(!isFilterActive);
    }, [isFilterActive]);
    const settingsPanelHandler = useCallback(() => {
        setFlipStatus(!isFlipped);
    }, [isFlipped]);
    const saveSettingHandler = useCallback(() => {
        settingRef.current.saveSetting();
        setFlipStatus(false);
    }, []);
    return (_jsxs("div", { css: [
            tablePanelStyle,
            isFlipped &&
                css `
            th {
              position: relative;
            }
          `,
        ], children: [!isFlipped && (_jsx(RangesHeader, { id,
                ranges,
                info,
                activeTab,
                molecules,
                isFilterActive, onUnlink: unlinkRangeHandler, onFilterActivated: filterHandler, onSettingClick: settingsPanelHandler, filterCounter: rangesData.length })), isFlipped && (_jsx(PreferencesHeader, { onSave: saveSettingHandler, onClose: settingsPanelHandler })), _jsx("div", { className: "inner-container", children: !isFlipped ? (_jsx("div", { className: "table-container", children: _jsx(RangesTable, { activeTab: activeTab, tableData: rangesData, onUnlink: unlinkRangeHandler, contextMenu: rangesContextMenuOptions, onContextMenuSelect: contextMenuSelectHandler, preferences: preferences, info: info }) })) : (_jsx(RangesPreferences, { ref: settingRef })) }), _jsx(ClipboardFallbackModal, { mode: shouldFallback, onDismiss: cleanShouldFallback, text: text, label: "Range" })] }));
}
const MemoizedRangesTablePanel = memo(RangesTablePanelInner);
const emptyData = { ranges: {}, data: {}, info: {} };
export default function RangesPanel() {
    const { ranges, data, info, id } = useSpectrum(emptyData);
    const { displayerKey, xDomain, view: { spectra: { activeTab }, }, molecules, toolOptions: { selectedTool }, } = useChartData();
    const rangesPreferences = usePanelPreferences('ranges', activeTab);
    return (_jsx(MemoizedRangesTablePanel, { id,
        ranges,
        data,
        info,
        selectedTool,
        displayerKey,
        preferences: rangesPreferences,
        xDomain,
        activeTab,
        molecules }));
}
