import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import lodashGet from 'lodash/get';
import { useMemo, useCallback } from 'react';
import { useAssignment, useAssignmentData, } from '../../assignment/AssignmentsContext';
import { filterForIDsWithAssignment } from '../../assignment/utilities/filterForIDsWithAssignment';
import { ContextMenu } from '../../elements/ContextMenuBluePrint';
import { HighlightEventSource, useHighlight, useHighlightData, } from '../../highlight';
import AbsoluteColumn from './TableColumns/AbsoluteColumn';
import ActionsColumn from './TableColumns/ActionsColumn';
import CouplingColumn from './TableColumns/CouplingColumn';
import RangeAssignmentsColumn from './TableColumns/RangeAssignmentsColumn';
import RangeColumn from './TableColumns/RangeColumn';
import RelativeColumn from './TableColumns/RelativeColumn';
import SignalAssignmentsColumn from './TableColumns/SignalAssignmentsColumn';
import SignalDeltaColumn from './TableColumns/SignalDeltaColumn';
import SignalDeltaHzColumn from './TableColumns/SignalDeltaHzColumn';
const HighlightedRowStyle = css `
  background-color: #ff6f0057;
`;
const ConstantlyHighlightedRowStyle = css `
  background-color: #f5f5dc;
`;
function RangesTableRow({ rowData, onUnlink, onContextMenuSelect, contextMenu = [], preferences, info, }) {
    const assignmentData = useAssignmentData();
    const assignmentRange = useAssignment(rowData.id);
    const highlightRange = useHighlight([assignmentRange.id].concat(assignmentRange.assigned?.x || []).concat(filterForIDsWithAssignment(assignmentData, rowData.signals.map((_signal) => _signal.id))), { type: HighlightEventSource.RANGE });
    const highlightRangeAssignmentsColumn = useHighlight(assignmentRange.assigned?.x || [], { type: HighlightEventSource.RANGE });
    const assignmentSignal = useAssignment(rowData?.tableMetaInfo?.id || '');
    const highlightSignal = useHighlight(assignmentSignal?.id
        ? [assignmentSignal.id].concat(assignmentSignal.assigned?.x || [])
        : [], { type: HighlightEventSource.SIGNAL });
    const highlightData = useHighlightData();
    const rowSpanTags = useMemo(() => {
        return {
            rowSpan: rowData.tableMetaInfo.rowSpan,
            style: lodashGet(rowData.tableMetaInfo, 'hide', false)
                ? { display: 'none' }
                : undefined,
        };
    }, [rowData.tableMetaInfo]);
    const unlinkHandler = useCallback((e, isOnRangeLevel) => {
        // stop propagation here to prevent enabling/disabling the assignment mode at the same time
        if (e) {
            e.stopPropagation();
        }
        if (isOnRangeLevel !== undefined) {
            if (isOnRangeLevel) {
                onUnlink(rowData);
                assignmentRange.removeAll('x');
            }
            else {
                onUnlink(rowData, lodashGet(rowData, 'tableMetaInfo.signalIndex', undefined));
                assignmentSignal.removeAll('x');
            }
        }
    }, [assignmentRange, assignmentSignal, onUnlink, rowData]);
    const linkHandler = useCallback((e, assignment) => {
        e.stopPropagation();
        assignment.setActive('x');
    }, []);
    const onHoverRange = useMemo(() => {
        return {
            onMouseEnter: () => {
                assignmentRange.show('x');
                highlightRange.show();
            },
            onMouseLeave: () => {
                assignmentRange.hide();
                highlightRange.hide();
            },
        };
    }, [assignmentRange, highlightRange]);
    const onHoverRangeAssignmentsColumn = useMemo(() => {
        return {
            onMouseEnter: () => {
                assignmentRange.show('x');
                highlightRangeAssignmentsColumn.show();
            },
            onMouseLeave: () => {
                assignmentRange.hide();
                highlightRangeAssignmentsColumn.hide();
            },
        };
    }, [assignmentRange, highlightRangeAssignmentsColumn]);
    const onHoverSignal = useMemo(() => {
        return {
            onMouseEnter: () => {
                assignmentSignal.show('x');
                highlightSignal.show();
            },
            onMouseLeave: () => {
                assignmentSignal.hide();
                highlightSignal.hide();
            },
        };
    }, [assignmentSignal, highlightSignal]);
    const trCss = useMemo(() => {
        return highlightRange.isActive || assignmentRange.isActive
            ? HighlightedRowStyle
            : lodashGet(rowData, 'tableMetaInfo.isConstantlyHighlighted', false)
                ? ConstantlyHighlightedRowStyle
                : null;
    }, [assignmentRange.isActive, highlightRange.isActive, rowData]);
    return (_jsxs(ContextMenu, { options: contextMenu, onSelect: (selected) => onContextMenuSelect?.(selected, rowData), as: "tr", css: trCss, children: [preferences.showSerialNumber && (_jsx("td", { ...rowSpanTags, ...onHoverRange, children: rowData.tableMetaInfo.rowIndex + 1 })), preferences.from.show && (_jsx(RangeColumn, { value: rowData.from, rowSpanTags: rowSpanTags, onHover: onHoverRange, format: preferences.from.format })), preferences.to.show && (_jsx(RangeColumn, { value: rowData.to, rowSpanTags: rowSpanTags, onHover: onHoverRange, format: preferences.to.format })), preferences.deltaPPM.show && (_jsx(SignalDeltaColumn, { row: rowData, rowSpanTags: rowSpanTags, onHover: onHoverSignal, format: preferences.deltaPPM.format })), preferences.deltaHz.show && (_jsx(SignalDeltaHzColumn, { row: rowData, rowSpanTags: rowSpanTags, onHover: onHoverSignal, format: preferences.deltaHz.format, info: info })), preferences.relative.show && (_jsx(RelativeColumn, { row: rowData, rowSpanTags: rowSpanTags, onHover: onHoverRange, format: preferences.relative.format })), preferences.absolute.show && (_jsx(AbsoluteColumn, { row: rowData, rowSpanTags: rowSpanTags, onHover: onHoverRange, format: preferences.absolute.format })), preferences.showMultiplicity && (_jsx("td", { ...onHoverSignal, children: !rowData?.tableMetaInfo?.signal
                    ? 'm'
                    : lodashGet(rowData, 'tableMetaInfo.signal.multiplicity', '') })), preferences.coupling.show && (_jsx(CouplingColumn, { row: rowData, onHover: onHoverSignal, format: preferences.coupling.format })), preferences.showAssignment && (_jsxs(_Fragment, { children: [_jsx(SignalAssignmentsColumn, { row: rowData, assignment: assignmentSignal, highlight: highlightSignal, onHover: onHoverSignal, onLink: linkHandler, onUnlink: unlinkHandler }), _jsx(RangeAssignmentsColumn, { row: rowData, assignment: assignmentRange, highlight: highlightRangeAssignmentsColumn, onHover: onHoverRangeAssignmentsColumn, onLink: linkHandler, onUnlink: unlinkHandler, rowSpanTags: rowSpanTags, highlightData: highlightData })] })), _jsx(ActionsColumn, { row: rowData, onHoverSignal: onHoverSignal, onHoverRange: onHoverRange, rowSpanTags: rowSpanTags, showKind: preferences.showKind, showDeleteAction: preferences.showDeleteAction, showEditAction: preferences.showEditAction, showZoomAction: preferences.showZoomAction })] }));
}
export default RangesTableRow;
