import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { useState, useMemo, memo, useCallback } from 'react';
import { useChartData } from '../../context/ChartContext';
import { useDispatch } from '../../context/DispatchContext';
import IsotopesViewer from '../../elements/IsotopesViewer';
import Tab from '../../elements/Tab/Tab';
import Tabs from '../../elements/Tab/Tabs';
import { useSetActiveSpectrumAction } from '../../hooks/useSetActiveSpectrumAction';
import groupByInfoKey from '../../utility/GroupByInfoKey';
import { SpectraTable } from './SpectraTable';
import SpectrumSetting from './base/setting/SpectrumSetting';
function SpectrumsTabsInner({ data, activeSpectra, activeTab, }) {
    const [selectedSpectrumData, setSelectedSpectrum] = useState(null);
    const [settingModalPosition, setSettingModalPosition] = useState(null);
    const [isSettingModalDisplayed, setIsSettingModalDisplayed] = useState(false);
    const dispatch = useDispatch();
    const spectrumsGroupByNucleus = useMemo(() => {
        if (!data)
            return [];
        const groupByNucleus = groupByInfoKey('nucleus');
        return groupByNucleus(data, true);
    }, [data]);
    const { setActiveSpectrum } = useSetActiveSpectrumAction();
    function onTabChangeHandler(tab) {
        dispatch({ type: 'SET_ACTIVE_TAB', payload: { tab: tab.tabid } });
    }
    const openSettingHandler = useCallback((event, selectedSpectrum) => {
        event.stopPropagation();
        setSettingModalPosition({
            x: event.nativeEvent.clientX,
            y: event.nativeEvent.clientY,
        });
        setSelectedSpectrum(selectedSpectrum);
        setIsSettingModalDisplayed(true);
    }, []);
    const handleChangeVisibility = useCallback((d, key) => {
        dispatch({
            type: 'CHANGE_SPECTRUM_VISIBILITY',
            payload: {
                id: d.id,
                key,
            },
        });
    }, [dispatch]);
    function handleChangeActiveSpectrum(e, spectrum) {
        setActiveSpectrum(e, spectrum.id);
    }
    function mouseLeaveHandler() {
        setIsSettingModalDisplayed(false);
    }
    return (_jsxs("div", { style: { height: 'calc(100% - 25px)' }, css: css `
        tbody tr {
          height: 20px;
        }
      `, children: [_jsx(Tabs, { activeTab: activeTab, onClick: onTabChangeHandler, children: spectrumsGroupByNucleus &&
                    Object.keys(spectrumsGroupByNucleus).map((nucleus) => (_jsx(Tab, { render: ({ title }) => _jsx(IsotopesViewer, { value: title }), title: nucleus, tabid: nucleus, children: _jsx(SpectraTable, { nucleus: nucleus, data: spectrumsGroupByNucleus[nucleus], activeSpectra: activeSpectra?.[nucleus] || null, onChangeVisibility: handleChangeVisibility, onChangeActiveSpectrum: handleChangeActiveSpectrum, onOpenSettingModal: openSettingHandler }) }, nucleus))) }, activeTab), isSettingModalDisplayed ? (_jsx(SpectrumSetting, { onClose: mouseLeaveHandler, data: selectedSpectrumData, position: settingModalPosition })) : null] }));
}
const MemoizedSpectra = memo(SpectrumsTabsInner);
export default function SpectrumsTabs() {
    const { data, view: { spectra: { activeTab, activeSpectra }, }, } = useChartData();
    return _jsx(MemoizedSpectra, { data, activeSpectra, activeTab });
}
