import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { useMemo } from 'react';
import { getLabelColor } from '../utilities/Utilities';
import AdditionalColumnHeader from './AdditionalColumnHeader';
import CorrelationTableRow from './CorrelationTableRow';
const tableStyle = css `
  overflow: auto;
  height: 100%;
  display: block;

  table {
    border-spacing: 0;
    border: 1px solid #dedede;
    width: 100%;
    font-size: 12px;
    height: 100%;
  }

  th {
    position: sticky;
    background-color: white;
    top: 0;
  }

  th,
  td {
    white-space: nowrap;
    text-align: center;
    margin: 0;
    padding: 0.4rem;
    border-bottom: 1px solid #dedede;
    border-right: 1px solid #dedede;

    :last-child {
      border-right: 0;
    }

    button {
      background-color: transparent;
      border: none;
    }
  }

  tr {
    :last-child {
      td {
        border-bottom: 0;
      }
    }
  }

  thead tr {
    background-color: white !important;
  }
`;
function CorrelationTable({ correlationsData, filteredCorrelationsData, additionalColumnData, editEquivalencesSaveHandler, onSaveEditNumericValues, onEditCorrelationTableCellHandler, showProtonsAsRows, spectraData, }) {
    const rows = useMemo(() => {
        if (!filteredCorrelationsData) {
            return [];
        }
        return filteredCorrelationsData.values
            .filter((correlation) => showProtonsAsRows
            ? correlation.atomType === 'H'
            : correlation.atomType !== 'H')
            .map((correlation) => (_jsx(CorrelationTableRow, { additionalColumnData: additionalColumnData, correlations: correlationsData.values, correlation: correlation, styleRow: { backgroundColor: 'mintcream' }, styleLabel: correlation.atomType === 'H'
                ? {
                    color: getLabelColor(correlationsData, correlation),
                }
                : {}, onSaveEditEquivalences: editEquivalencesSaveHandler, onSaveEditNumericValues: onSaveEditNumericValues, onEditCorrelationTableCellHandler: onEditCorrelationTableCellHandler, spectraData: spectraData }, `correlation${correlation.atomType}${correlation.id}`)));
    }, [
        filteredCorrelationsData,
        showProtonsAsRows,
        additionalColumnData,
        correlationsData,
        editEquivalencesSaveHandler,
        onSaveEditNumericValues,
        onEditCorrelationTableCellHandler,
        spectraData,
    ]);
    const additionalColumnHeader = useMemo(() => additionalColumnData.map((correlation) => (_jsx(AdditionalColumnHeader, { spectraData: spectraData, correlationsData: correlationsData, correlation: correlation, onEdit: onEditCorrelationTableCellHandler }, `additionalCorrelationHeader_${correlation.id}`))), [
        additionalColumnData,
        correlationsData,
        onEditCorrelationTableCellHandler,
        spectraData,
    ]);
    return (_jsx("div", { css: tableStyle, children: _jsxs("table", { children: [_jsx("thead", { children: _jsxs("tr", { children: [_jsx("th", { children: "Atom" }), _jsx("th", { children: "\u03B4 (ppm)" }), _jsx("th", { children: "Equiv" }), _jsx("th", { children: "#H" }), _jsx("th", { style: { borderRight: '1px solid' }, children: "Hybrid" }), additionalColumnHeader] }) }), _jsx("tbody", { children: rows })] }) }));
}
export default CorrelationTable;
