import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { getLinkDim } from 'nmr-correlation';
import { useCallback, useMemo, useState } from 'react';
import { CloseButton } from '../../../../elements/CloseButton';
import Tab from '../../../../elements/Tab/Tab';
import Tabs, { PositionsEnum } from '../../../../elements/Tab/Tabs';
import { getEditedCorrelations } from '../../utilities/Utilities';
import EditLinkConfirmation from './Confirmation';
import EditPathLength from './EditPathLength';
import MoveLink from './MoveLink';
const modalContainer = css `
  width: 490px;
  height: 220px;
  padding: 5px;

  button {
    flex: 2;
    padding: 5px;
    border: 1px solid gray;
    border-radius: 5px;
    height: 30px;
    margin: 0 auto;
    margin-top: 15px;
    display: block;
    width: 20%;
    color: white;
    background-color: gray;
  }

  button:focus {
    outline: none;
  }

  .header {
    height: 24px;
    border-bottom: 1px solid #f0f0f0;
    display: flex;
    align-items: center;

    button {
      height: 36px;
      margin: 2px;
      background-color: transparent;
      border: none;

      svg {
        height: 16px;
      }
    }

    p {
      font-weight: bold;
      margin-bottom: 5px;
      margin-right: 30px;
      padding: 0 10px;
      width: 100%;
      text-align: center;
    }
  }

  .tabs-container {
    width: 100%;
    flex: 1;
    overflow: auto;
    border: none;
  }
`;
export default function EditLinkModal({ correlationDim1, correlationDim2, link, correlations, onClose, onEdit, }) {
    const [activeTab, setActiveTab] = useState('move');
    const getLinkLabel = useCallback(() => {
        const linkDim = getLinkDim(link);
        if (linkDim === 1) {
            return ` 1D (${link.signal.delta.toFixed(3)})`;
        }
        else if (linkDim === 2) {
            return `${link.signal.x ? `${link.signal.x.delta.toFixed(2)}` : '?'} (${correlationDim1.label.origin}), ${link.signal.y ? link.signal.y.delta.toFixed(2) : '?'} (${correlationDim2.label.origin})`;
        }
        return '';
    }, [correlationDim1.label.origin, link, correlationDim2]);
    const handleOnEdit = useCallback((action, selectedCorrelationIdDim1, selectedCorrelationIdDim2, editedLink) => {
        const { editedCorrelations, buildCorrelationDataOptions } = getEditedCorrelations({
            correlationDim1,
            correlationDim2,
            selectedCorrelationIdDim1,
            selectedCorrelationIdDim2,
            action,
            link: editedLink || link,
            correlations,
        });
        onEdit(editedCorrelations, action, editedLink || link, buildCorrelationDataOptions);
        onClose?.();
    }, [correlationDim1, correlationDim2, correlations, link, onClose, onEdit]);
    const tabsContainer = useMemo(() => (_jsx("div", { className: "tabs-container", children: _jsxs(Tabs, { position: PositionsEnum.TOP, activeTab: activeTab, onClick: (tab) => setActiveTab(tab.tabid), children: [_jsx(Tab, { title: "Move", tabid: 'move', children: _jsx(MoveLink, { correlationDim1: correlationDim1, correlationDim2: correlationDim2, link: link, correlations: correlations, onEdit: (correlationIdDim1, correlationIdDim2) => handleOnEdit('move', correlationIdDim1, correlationIdDim2) }) }), _jsx(Tab, { title: "Unmove", tabid: "unmove", children: _jsx(EditLinkConfirmation, { description: "Movement of signal to its original place.", onConfirm: () => handleOnEdit('unmove', correlationDim1.id, correlationDim2.id) }) }), _jsx(Tab, { title: "Remove", tabid: 'remove', children: _jsx(EditLinkConfirmation, { description: "Deletion of signal.", onConfirm: () => handleOnEdit('remove', undefined, undefined) }) }), _jsx(Tab, { title: "J Coupling", tabid: 'setPathLength', children: _jsx(EditPathLength, { signal: link.signal, experimentType: link.experimentType, onEdit: (editedSignal) => {
                            const editedLink = { ...link, signal: editedSignal };
                            handleOnEdit('setPathLength', correlationDim1, correlationDim2, editedLink);
                        } }) })] }) })), [
        activeTab,
        correlationDim1,
        correlationDim2,
        correlations,
        handleOnEdit,
        link,
    ]);
    return (_jsxs("div", { css: modalContainer, children: [_jsxs("div", { className: "header handle", children: [_jsx(CloseButton, { title: "Close", onClick: onClose }), _jsx("p", { className: "header-info", children: `${link.experimentType.toUpperCase()} signal at ${getLinkLabel()}` })] }), tabsContainer] }));
}
