import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { useCallback, useEffect, useState } from 'react';
import DefaultPathLengths from '../../../../../data/constants/DefaultPathLengths';
import Button from '../../../../elements/Button';
import Input from '../../../../elements/Input';
import Label from '../../../../elements/Label';
const editPathLengthsStyles = css `
  width: 100%;
  height: 100%;
  margin-top: 10px;
  text-align: center;

  .input-container {
    width: 100%;
    margin-top: 5px;
    text-align: center;
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
  }

  button {
    flex: 2;
    padding: 5px;
    border: 1px solid gray;
    border-radius: 5px;
    height: 30px;
    margin: 0 auto;
    margin-top: 15px;
    display: block;
    width: 60px;
    color: white;
    background-color: gray;
  }

  .warning {
    margin-top: 5px;
    color: red;
  }
`;
function EditPathLength({ signal, experimentType, onEdit }) {
    const [from, setFrom] = useState(signal.j?.pathLength !== undefined
        ? signal.j.pathLength.from
        : DefaultPathLengths[experimentType]?.from || 0);
    const [to, setTo] = useState(signal.j?.pathLength !== undefined
        ? signal.j.pathLength.to
        : DefaultPathLengths[experimentType]?.to || 0);
    const [isError, setIsError] = useState(false);
    const handleOnEdit = useCallback(() => {
        const pathLength = {
            from,
            to,
        };
        const editedSignal = {
            ...signal,
            j: {
                ...signal.j,
                pathLength,
            },
        };
        onEdit(editedSignal);
    }, [to, from, onEdit, signal]);
    useEffect(() => {
        setIsError(from <= 0 || from > to);
    }, [to, from]);
    return (_jsxs("div", { css: editPathLengthsStyles, children: [_jsx("p", { children: "Setting of the minimum and maximum path length (J coupling)." }), _jsxs("div", { className: "input-container", children: [_jsx(Label, { title: "Min:", style: {
                            label: {
                                marginRight: '5px',
                                fontSize: '14px',
                                fontWeight: 'normal',
                            },
                        }, children: _jsx(Input, { type: "number", value: from, onChange: (e) => {
                                setFrom(Number(e.target.value));
                            }, style: { input: { color: isError ? 'red' : 'black' } } }) }), _jsx(Label, { title: "Max:", style: {
                            label: {
                                marginRight: '5px',
                                fontSize: '14px',
                                fontWeight: 'normal',
                            },
                        }, children: _jsx(Input, { type: "number", value: to, onChange: (e) => {
                                setTo(Number(e.target.value));
                            } }) })] }), isError ? (_jsxs("p", { className: "warning", children: ["Minimum must not be 0 or higher than the maximum value.", ' '] })) : (_jsx(Button, { type: "button", onClick: handleOnEdit, disabled: isError, children: "Set" }))] }));
}
export default EditPathLength;
