import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { Formik } from 'formik';
import { useEffect, useCallback, useImperativeHandle, useRef, forwardRef, useMemo, memo, } from 'react';
import { usePreferences } from '../../context/PreferencesContext';
import useNucleus from '../../hooks/useNucleus';
import { usePanelPreferencesByNuclei } from '../../hooks/usePanelPreferences';
import { getUniqueNuclei } from '../../utility/getUniqueNuclei';
import { is2DNucleus } from '../../utility/nucleusToString';
import { NucleusPreferences, } from '../extra/preferences/NucleusPreferences';
import { PreferencesContainer } from '../extra/preferences/PreferencesContainer';
const preferences1DFields = [
    {
        id: 1,
        label: 'δ (ppm) :',
        checkControllerName: 'deltaPPM.show',
        formatControllerName: 'deltaPPM.format',
    },
];
const preferences2DFields = [
    {
        id: 1,
        label: 'Serial number :',
        checkControllerName: 'showSerialNumber',
        hideFormatField: true,
    },
    {
        id: 2,
        label: 'Kind :',
        checkControllerName: 'showKind',
        hideFormatField: true,
    },
    {
        id: 3,
        label: 'Assignment :',
        checkControllerName: 'showAssignment',
        hideFormatField: true,
    },
    {
        id: 4,
        label: 'Delete action :',
        checkControllerName: 'showDeleteAction',
        hideFormatField: true,
    },
    {
        id: 5,
        label: 'Zoom action :',
        checkControllerName: 'showZoomAction',
        hideFormatField: true,
    },
    {
        id: 6,
        label: 'Edit action :',
        checkControllerName: 'showEditAction',
        hideFormatField: true,
    },
];
function ZonesPreferences(props, ref) {
    const formRef = useRef(null);
    const preferences = usePreferences();
    const nucleus = useNucleus();
    const nuclei2D = nucleus.filter((n) => is2DNucleus(n));
    const nuclei = useMemo(() => getUniqueNuclei(nucleus), [nucleus]);
    const zonesPreferences = usePanelPreferencesByNuclei('zones', [
        ...nuclei,
        ...nuclei2D,
    ]);
    useEffect(() => {
        void formRef.current?.setValues(zonesPreferences);
    }, [zonesPreferences]);
    const saveHandler = useCallback((values) => {
        preferences.dispatch({
            type: 'SET_PANELS_PREFERENCES',
            payload: { key: 'zones', value: values },
        });
    }, [preferences]);
    useImperativeHandle(ref, () => ({
        saveSetting: () => {
            void formRef.current?.submitForm();
        },
    }), []);
    return (_jsx(PreferencesContainer, { children: _jsx(Formik, { initialValues: {}, onSubmit: saveHandler, innerRef: formRef, children: _jsxs(_Fragment, { children: [nuclei?.map((n) => (_jsx(NucleusPreferences, { nucleus: n, fields: preferences1DFields }, n))), nuclei2D?.map((n) => (_jsx(NucleusPreferences, { nucleus: n, fields: preferences2DFields }, n)))] }) }) }));
}
export default memo(forwardRef(ZonesPreferences));
