import lodashGet from 'lodash/get';
import { formatNumber } from '../../../utility/formatNumber';
export default class ColumnsHelper {
    constructor(preferences, defaultPreference) {
        this.preferences = preferences;
        this.defaultPreference = defaultPreference;
    }
    checkPreferences(preferencesToCheck, key) {
        const val = !!(preferencesToCheck === undefined ||
            Object.keys(preferencesToCheck).length === 0 ||
            (preferencesToCheck && preferencesToCheck[key] === true));
        return val;
    }
    setCustomColumn(array, index, columnLabel, cellHandler) {
        array.push({
            orderIndex: index,
            Header: columnLabel,
            sortType: 'basic',
            Cell: ({ row }) => cellHandler(row),
        });
    }
    addColumn(columns, flagKey, formatKey, columnKey, columnLabel, columnIndex, options = {}) {
        const preferences = this.preferences || this.defaultPreference;
        if (this.checkPreferences(preferences, flagKey)) {
            this.setCustomColumn(columns, columnIndex, columnLabel, (row) => {
                const format = preferences && Object.hasOwn(preferences, formatKey)
                    ? preferences[formatKey]
                    : this.defaultPreference[formatKey];
                const { formatPrefix = '', formatSuffix = '', showPrefixSuffixCallback = () => true, } = options;
                if (showPrefixSuffixCallback(row)) {
                    return formatNumber(row.original[columnKey], format, {
                        prefix: formatPrefix,
                        suffix: formatSuffix,
                    });
                }
                else {
                    return formatNumber(row.original[columnKey], format);
                }
            });
        }
    }
}
export function isColumnVisible(preferences, key) {
    return lodashGet(preferences, key, false);
}
