import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { Formik } from 'formik';
import { forwardRef } from 'react';
import * as Yup from 'yup';
import { FREQUENCIES, } from '../../../data/PredictionManager';
import generateNumbersPowerOfX from '../../../data/utilities/generateNumbersPowerOfX';
import { GroupPane } from '../../elements/GroupPane';
import IsotopesViewer from '../../elements/IsotopesViewer';
import Label from '../../elements/Label';
import FormikCheckBox from '../../elements/formik/FormikCheckBox';
import FormikErrorsSummary from '../../elements/formik/FormikErrorsSummary';
import FormikInput from '../../elements/formik/FormikInput';
import FormikSelect from '../../elements/formik/FormikSelect';
const NUMBER_OF_POINTS_1D = generateNumbersPowerOfX(12, 19);
const NUMBER_OF_POINTS_2D = generateNumbersPowerOfX(10, 10, {
    format: (value) => value,
});
const predictionFormValidation = Yup.object().shape({
    name: Yup.string().label('Name'),
    frequency: Yup.number().integer().required().label('Frequency'),
    autoExtendRange: Yup.boolean(),
    '1d': Yup.object({
        '1H': Yup.object({
            from: Yup.number().required().label("1H ' From ' "),
            to: Yup.number().required().label("1H ' To ' "),
        }),
        '13C': Yup.object().shape({
            from: Yup.number().required().label("13C ' From ' "),
            to: Yup.number().required().label("13C ' To ' "),
        }),
        lineWidth: Yup.number().integer().min(1).required().label('Line Width'),
        nbPoints: Yup.number().integer().required().label('1D Number Of Points'),
    }),
    '2d': Yup.object({
        nbPoints: Yup.object({
            x: Yup.number().integer().required().label('2D Number Of Points'),
            y: Yup.number().integer().required().label('2D Number Of Points'),
        }),
    }),
    spectra: Yup.object({
        proton: Yup.boolean(),
        carbon: Yup.boolean(),
        cosy: Yup.boolean(),
        hsqc: Yup.boolean(),
        hmbc: Yup.boolean(),
    }).test('check-options', 'You must check one of the options to start prediction', (obj) => {
        if (Object.values(obj).includes(true)) {
            return true;
        }
        return false;
    }),
});
const labelStyle = {
    label: { flex: 4, fontWeight: '500' },
    wrapper: { flex: 8, display: 'flex', alignItems: 'center' },
    container: { padding: '5px 0' },
};
const inputStyle = {
    input: {
        padding: '5px',
    },
};
const styles = {
    select: {
        width: '100%',
        minWidth: '100px',
        maxWidth: '280px',
        height: 30,
        margin: 0,
    },
    groupHeader: {
        borderBottom: '1px solid #efefef',
        paddingBottom: '5px',
        fontWeight: '600',
        color: '#005d9e',
    },
};
function PredictionOptionsPanel(props, ref) {
    const { options, onSubmit, hideName = false } = props;
    return (_jsx(Formik, { initialValues: options, validationSchema: predictionFormValidation, enableReinitialize: true, onSubmit: onSubmit, innerRef: ref, children: _jsxs(_Fragment, { children: [_jsx(FormikErrorsSummary, {}), !hideName && (_jsx(Label, { title: "Name", style: labelStyle, children: _jsx(FormikInput, { name: "name", style: inputStyle }) })), _jsx(Label, { title: "Frequency", style: labelStyle, children: _jsx(FormikSelect, { items: FREQUENCIES, style: styles.select, name: "frequency" }) }), _jsxs(GroupPane, { text: "1D Options", style: {
                        header: styles.groupHeader,
                    }, children: [_jsx(Label, { title: "Auto extend range", style: labelStyle, children: _jsx(FormikCheckBox, { name: "autoExtendRange" }) }), _jsxs(Label, { title: "1H", renderTitle: (title) => (_jsx(IsotopesViewer, { value: title, className: "custom-label" })), style: labelStyle, children: [_jsx(Label, { title: "From", children: _jsx(FormikInput, { name: "1d.1H.from", type: "number", style: inputStyle }) }), _jsx(Label, { title: "To", style: { label: { padding: '0 10px' } }, children: _jsx(FormikInput, { name: "1d.1H.to", type: "number", style: inputStyle }) })] }), _jsxs(Label, { title: "13C", renderTitle: (title) => (_jsx(IsotopesViewer, { value: title, className: "custom-label" })), style: labelStyle, children: [_jsx(Label, { title: "From", children: _jsx(FormikInput, { name: "1d.13C.from", type: "number", style: inputStyle }) }), _jsx(Label, { title: "To", style: { label: { padding: '0 10px' } }, children: _jsx(FormikInput, { name: "1d.13C.to", type: "number", style: inputStyle }) })] }), _jsxs(Label, { title: "Line Width", style: labelStyle, children: [_jsx(FormikInput, { name: "1d.lineWidth", type: "number", style: inputStyle }), _jsx("span", { style: { paddingLeft: '0.4rem' }, children: " Hz " })] }), _jsx(Label, { title: "Number of Points", style: labelStyle, children: _jsx(FormikSelect, { items: NUMBER_OF_POINTS_1D, name: "1d.nbPoints", style: styles.select }) })] }), _jsx(GroupPane, { text: "2D Options", style: {
                        header: styles.groupHeader,
                    }, children: _jsxs(Label, { title: "Number of Points", style: labelStyle, children: [_jsx(FormikSelect, { items: NUMBER_OF_POINTS_2D, name: "2d.nbPoints.x", style: { margin: 0, height: 30 } }), _jsx("span", { style: { padding: '0 10px' }, children: " X " }), _jsx(FormikSelect, { items: NUMBER_OF_POINTS_2D, name: "2d.nbPoints.y", style: { margin: 0, height: 30 } })] }) }), _jsx(GroupPane, { text: "Spectra", style: {
                        header: styles.groupHeader,
                    }, children: _jsxs("div", { style: { display: 'flex', justifyContent: 'space-around' }, children: [_jsx(IsotopesOption, { title: "1H", name: "spectra.proton" }), _jsx(IsotopesOption, { title: "13C", name: "spectra.carbon" }), _jsx(IsotopesOption, { title: "COSY", name: "spectra.cosy" }), _jsx(IsotopesOption, { title: "HSQC", name: "spectra.hsqc" }), _jsx(IsotopesOption, { title: "HMBC", name: "spectra.hmbc" })] }) })] }) }));
}
function IsotopesOption(props) {
    const { name, title } = props;
    return (_jsx(FormikCheckBox, { name: name, style: {
            checkbox: { display: 'flex' },
            container: { flexDirection: 'row-reverse', padding: '0 5px' },
        }, renderLabel: () => (_jsx("label", { htmlFor: name, children: _jsx(IsotopesViewer, { value: title, style: { padding: '0 5px' } }) })) }));
}
export default forwardRef(PredictionOptionsPanel);
