import { original } from 'immer';
import lodashCloneDeep from 'lodash/cloneDeep';
import { buildCorrelationData, setCorrelation, } from 'nmr-correlation';
import { findRange, findSignal1D, findSignal2D, findSpectrum, findZone, } from '../../../data/utilities/FindUtilities';
import { deleteSignal1D } from './RangesActions';
import { deleteSignal2D } from './ZonesActions';
function handleUpdateCorrelations(draft) {
    const { data: spectra, correlations } = draft;
    draft.correlations = buildCorrelationData(spectra, {
        ...correlations.options,
        values: lodashCloneDeep(correlations.values),
    });
}
//action
function handleSetMF(draft, action) {
    const state = original(draft);
    const { data: spectra, correlations } = state;
    const { mf } = action.payload;
    // update of correlation data is needed only if the following is true
    if (correlations.options.mf === '' || correlations.options.mf !== mf) {
        draft.correlations = buildCorrelationData(spectra, {
            ...correlations.options,
            mf,
            values: lodashCloneDeep(correlations.values),
        });
    }
}
//action
function handleSetTolerance(draft, action) {
    const state = original(draft);
    const { data: spectra, correlations } = state;
    const { tolerance } = action.payload;
    draft.correlations = buildCorrelationData(spectra, {
        ...correlations.options,
        tolerance,
        values: lodashCloneDeep(correlations.values),
    });
}
//action
function handleSetCorrelation(draft, action) {
    const state = original(draft);
    const { correlations } = state;
    const { id, correlation, options } = action.payload;
    draft.correlations = setCorrelation(correlations, id, correlation);
    if (options) {
        draft.correlations = {
            ...draft.correlations,
            options: { ...draft.correlations.options, ...options },
        };
    }
    handleUpdateCorrelations(draft);
}
//action
function handleSetCorrelations(draft, action) {
    const { correlations, options } = action.payload;
    const state = original(draft);
    let correlationsData = lodashCloneDeep(state.correlations);
    for (const correlation of correlations) {
        correlationsData = setCorrelation(correlationsData, correlation.id, correlation);
    }
    draft.correlations = correlationsData;
    if (options) {
        draft.correlations = {
            ...draft.correlations,
            options: { ...draft.correlations.options, ...options },
        };
    }
    handleUpdateCorrelations(draft);
}
//action
function handleDeleteCorrelation(draft, action) {
    const { correlation, assignmentData } = action.payload;
    // delete all signals linked to the correlation
    for (const link of correlation.links) {
        const spectrum = findSpectrum(draft.data, link.experimentID, false);
        if (spectrum) {
            if (spectrum.info.dimension === 1) {
                const range = findRange(spectrum, link.signal.id);
                const signal = findSignal1D(spectrum, link.signal.id);
                if (range && signal) {
                    deleteSignal1D(draft, {
                        spectrum,
                        range,
                        signal,
                        assignmentData,
                    });
                }
            }
            else if (spectrum.info.dimension === 2) {
                const zone = findZone(spectrum, link.signal.id);
                const signal = findSignal2D(spectrum, link.signal.id);
                if (zone && signal) {
                    deleteSignal2D(draft, {
                        spectrum,
                        zone,
                        signal,
                        assignmentData,
                    });
                }
            }
        }
    }
}
export { handleDeleteCorrelation, handleSetCorrelation, handleSetCorrelations, handleSetMF, handleSetTolerance, handleUpdateCorrelations, };
