import { Draft } from 'immer';
import { ActiveSpectrum } from 'nmr-load-save';
import { BaselineCorrectionOptions, ApodizationOptions } from 'nmr-processing';
import { ExclusionZone } from '../../../data/types/data1d/ExclusionZone';
import { MatrixOptions } from '../../../data/types/data1d/MatrixOptions';
import { State, TraceDirection } from '../Reducer';
import { ActionType } from '../types/ActionType';
type ShiftSpectrumAlongXAxisAction = ActionType<'SHIFT_SPECTRUM', {
    shift: number;
}>;
type ApodizationFilterAction = ActionType<'APPLY_APODIZATION_FILTER', {
    options: ApodizationOptions;
}>;
type ApodizationFilterLiveAction = ActionType<'CALCULATE_APODIZATION_FILTER', {
    options: ApodizationOptions;
    livePreview: boolean;
}>;
type ZeroFillingFilterAction = ActionType<'APPLY_ZERO_FILLING_FILTER', {
    options: {
        nbPoints: number;
    };
}>;
type ZeroFillingFilterLiveAction = ActionType<'CALCULATE_ZERO_FILLING_FILTER', {
    options: {
        nbPoints: number;
    };
    livePreview: boolean;
}>;
type ManualPhaseCorrectionFilterAction = ActionType<'APPLY_MANUAL_PHASE_CORRECTION_FILTER' | 'CALCULATE_MANUAL_PHASE_CORRECTION_FILTER' | 'APPLY_MANUAL_PHASE_CORRECTION_TOW_DIMENSION_FILTER' | 'CALCULATE_TOW_DIMENSIONS_MANUAL_PHASE_CORRECTION_FILTER', {
    ph0: number;
    ph1: number;
}>;
type BaselineCorrectionFilterOptions = Omit<BaselineCorrectionOptions, 'zones'>;
interface BaselineCorrectionFilterProps {
    options: BaselineCorrectionFilterOptions;
    livePreview: boolean;
}
type BaselineCorrectionFilterAction = ActionType<'APPLY_BASE_LINE_CORRECTION_FILTER', {
    options: BaselineCorrectionFilterOptions;
}>;
type BaselineCorrectionFilterLiveAction = ActionType<'CALCULATE_BASE_LINE_CORRECTION_FILTER', BaselineCorrectionFilterProps>;
type EnableFilterAction = ActionType<'ENABLE_FILTER', {
    id: string;
    enabled: boolean;
}>;
type DeleteFilterAction = ActionType<'DELETE_FILTER', {
    id?: string;
}>;
type DeleteSpectraFilterAction = ActionType<'DELETE_SPECTRA_FILTER', {
    filterName: string;
}>;
type SetFilterSnapshotAction = ActionType<'SET_FILTER_SNAPSHOT', {
    name: string;
    id: string;
}>;
type AddExclusionZoneAction = ActionType<'ADD_EXCLUSION_ZONE', {
    startX: number;
    endX: number;
}>;
type DeleteExclusionZoneAction = ActionType<'DELETE_EXCLUSION_ZONE', {
    zone: ExclusionZone;
    spectrumId?: string;
}>;
type ApplySignalProcessingAction = ActionType<'APPLY_SIGNAL_PROCESSING_FILTER', {
    options: MatrixOptions;
}>;
type AddPhaseCorrectionTraceAction = ActionType<'ADD_PHASE_CORRECTION_TRACE', {
    x: number;
    y: number;
}>;
type ChangePhaseCorrectionDirectionAction = ActionType<'CHANGE_PHASE_CORRECTION_DIRECTION', {
    direction: TraceDirection;
}>;
type DeletePhaseCorrectionTrace = ActionType<'DELETE_PHASE_CORRECTION_TRACE', {
    id: string;
}>;
type SetOneDimensionPhaseCorrectionPivotPoint = ActionType<'SET_ONE_DIMENSION_PIVOT_POINT', {
    value: number;
}>;
type SetTwoDimensionPhaseCorrectionPivotPoint = ActionType<'SET_TWO_DIMENSION_PIVOT_POINT', {
    x: number;
    y: number;
}>;
export type FiltersActions = ShiftSpectrumAlongXAxisAction | ApodizationFilterAction | ApodizationFilterLiveAction | ZeroFillingFilterAction | ZeroFillingFilterLiveAction | ManualPhaseCorrectionFilterAction | BaselineCorrectionFilterAction | BaselineCorrectionFilterLiveAction | EnableFilterAction | DeleteFilterAction | DeleteSpectraFilterAction | SetFilterSnapshotAction | AddExclusionZoneAction | DeleteExclusionZoneAction | ApplySignalProcessingAction | AddPhaseCorrectionTraceAction | ChangePhaseCorrectionDirectionAction | DeletePhaseCorrectionTrace | SetOneDimensionPhaseCorrectionPivotPoint | SetTwoDimensionPhaseCorrectionPivotPoint | ActionType<'APPLY_FFT_FILTER' | 'APPLY_FFT_DIMENSION_1_FILTER' | 'APPLY_FFT_DIMENSION_2_FILTER' | 'APPLY_AUTO_PHASE_CORRECTION_FILTER' | 'APPLY_ABSOLUTE_FILTER'>;
export interface RollbackSpectrumByFilterOptions {
    applyFilter?: boolean;
    reset?: boolean;
    searchBy?: 'id' | 'name';
    key?: string | null;
    activeSpectrum?: ActiveSpectrum | null;
    triggerSource?: 'Apply' | 'none';
}
declare function rollbackSpectrumByFilter(draft: Draft<State>, options?: RollbackSpectrumByFilterOptions): void;
export interface RollbackSpectrumOptions {
    filterKey?: string;
    reset?: boolean;
}
declare function rollbackSpectrum(draft: Draft<State>, options: RollbackSpectrumOptions): void;
declare function handleShiftSpectrumAlongXAxis(draft: Draft<State>, action: ShiftSpectrumAlongXAxisAction): void;
declare function handleApplyZeroFillingFilter(draft: Draft<State>, action: ZeroFillingFilterAction): void;
declare function handleCalculateZeroFillingFilter(draft: Draft<State>, action: ZeroFillingFilterLiveAction): void;
declare function handleCalculateApodizationFilter(draft: Draft<State>, action: ApodizationFilterLiveAction): void;
declare function handleApplyApodizationFilter(draft: Draft<State>, action: ApodizationFilterAction): void;
declare function handleApplyFFTFilter(draft: Draft<State>): void;
declare function handleApplyFFtDimension1Filter(draft: Draft<State>): void;
declare function handleApplyFFtDimension2Filter(draft: Draft<State>): void;
declare function handleApplyManualPhaseCorrectionFilter(draft: Draft<State>, action: ManualPhaseCorrectionFilterAction): void;
declare function handleAddPhaseCorrectionTrace(draft: Draft<State>, action: AddPhaseCorrectionTraceAction): void;
declare function handleChangePhaseCorrectionDirection(draft: Draft<State>, action: ChangePhaseCorrectionDirectionAction): void;
declare function handleDeletePhaseCorrectionTrace(draft: Draft<State>, action: DeletePhaseCorrectionTrace): void;
declare function handleCalculateManualPhaseCorrection(draft: Draft<State>, action: ManualPhaseCorrectionFilterAction): void;
declare function handleApplyAbsoluteFilter(draft: Draft<State>): void;
declare function handleApplyAutoPhaseCorrectionFilter(draft: Draft<State>): void;
declare function handleBaseLineCorrectionFilter(draft: Draft<State>, action: BaselineCorrectionFilterAction): void;
declare function calculateBaseLineCorrection(draft: Draft<State>, baseLineOptions?: BaselineCorrectionFilterProps): void;
declare function handleCalculateBaseLineCorrection(draft: Draft<State>, action: BaselineCorrectionFilterLiveAction): void;
declare function handleEnableFilter(draft: Draft<State>, action: EnableFilterAction): void;
declare function handleDeleteFilter(draft: Draft<State>, action: DeleteFilterAction): void;
declare function handleDeleteSpectraFilter(draft: Draft<State>, action: DeleteSpectraFilterAction): void;
declare function handleSetFilterSnapshotHandler(draft: Draft<State>, action: SetFilterSnapshotAction): void;
declare function handleSignalProcessingFilter(draft: Draft<State>, action: ApplySignalProcessingAction): void;
declare function handleAddExclusionZone(draft: Draft<State>, action: AddExclusionZoneAction): void;
declare function handleDeleteExclusionZone(draft: Draft<State>, action: DeleteExclusionZoneAction): void;
declare function handleSetOneDimensionPhaseCorrectionPivotPoint(draft: Draft<State>, action: SetOneDimensionPhaseCorrectionPivotPoint): void;
declare function handleSetTwoDimensionPhaseCorrectionPivotPoint(draft: Draft<State>, action: SetTwoDimensionPhaseCorrectionPivotPoint): void;
declare function handleCalculateManualTwoDimensionPhaseCorrection(draft: Draft<State>, action: ManualPhaseCorrectionFilterAction): void;
export { handleShiftSpectrumAlongXAxis, handleApplyZeroFillingFilter, handleApplyApodizationFilter, handleApplyFFTFilter, handleApplyFFtDimension1Filter, handleApplyFFtDimension2Filter, handleApplyManualPhaseCorrectionFilter, handleApplyAutoPhaseCorrectionFilter, handleApplyAbsoluteFilter, handleCalculateManualPhaseCorrection, calculateBaseLineCorrection, handleCalculateBaseLineCorrection, handleCalculateApodizationFilter, handleCalculateZeroFillingFilter, handleEnableFilter, handleDeleteFilter, handleDeleteSpectraFilter, handleBaseLineCorrectionFilter, handleSetFilterSnapshotHandler, handleAddExclusionZone, handleDeleteExclusionZone, handleSignalProcessingFilter, rollbackSpectrum, rollbackSpectrumByFilter, handleAddPhaseCorrectionTrace, handleChangePhaseCorrectionDirection, handleDeletePhaseCorrectionTrace, handleSetOneDimensionPhaseCorrectionPivotPoint, handleSetTwoDimensionPhaseCorrectionPivotPoint, handleCalculateManualTwoDimensionPhaseCorrection, };
