import { FifoLogger } from 'fifo-logger';
import { Draft } from 'immer';
import { TopicMolecule } from 'openchemlib-utils';
import { PredictedSpectraResult, PredictionOptions } from '../../../data/PredictionManager';
import { MoleculeBoundingRect, StateMolecule } from '../../../data/molecules/Molecule';
import { AssignmentContext } from '../../assignment/AssignmentsContext';
import { State } from '../Reducer';
import { ActionType } from '../types/ActionType';
interface AddMoleculeProps {
    molfile: string;
    floatMoleculeOnSave?: boolean;
}
type AddMoleculeAction = ActionType<'ADD_MOLECULE', AddMoleculeProps>;
type AddMoleculesAction = ActionType<'ADD_MOLECULES', {
    molecules: StateMolecule[];
}>;
type SetMoleculeAction = ActionType<'SET_MOLECULE', Required<StateMolecule> & {
    mappings?: ReturnType<TopicMolecule['getDiaIDsMapping']>;
}>;
type DeleteMoleculeAction = ActionType<'DELETE_MOLECULE', {
    id: string;
    assignmentData: AssignmentContext;
}>;
type PredictSpectraFromMoleculeAction = ActionType<'PREDICT_SPECTRA', {
    logger: FifoLogger;
    options: PredictionOptions;
    predictedSpectra: PredictedSpectraResult;
    molecule: StateMolecule;
    action?: 'save' | 'add';
}>;
type ToggleMoleculeViewObjectAction = ActionType<'FLOAT_MOLECULE_OVER_SPECTRUM' | 'TOGGLE_MOLECULE_ATOM_NUMBER', {
    id: string;
}>;
type ChangeFloatMoleculePositionAction = ActionType<'CHANGE_FLOAT_MOLECULE_POSITION', {
    id: string;
    bounding: MoleculeBoundingRect;
}>;
type ChangeMoleculeLabelAction = ActionType<'CHANGE_MOLECULE_LABEL', {
    id: string;
    label: string;
}>;
export type MoleculeActions = AddMoleculeAction | AddMoleculesAction | SetMoleculeAction | DeleteMoleculeAction | PredictSpectraFromMoleculeAction | ToggleMoleculeViewObjectAction | ChangeFloatMoleculePositionAction | ChangeMoleculeLabelAction;
declare function handleAddMolecule(draft: Draft<State>, action: AddMoleculeAction): void;
declare function handleAddMolecules(draft: Draft<State>, action: AddMoleculesAction): void;
declare function handleSetMolecule(draft: Draft<State>, action: SetMoleculeAction): void;
declare function handleDeleteMolecule(draft: Draft<State>, action: DeleteMoleculeAction): void;
declare function handlePredictSpectraFromMolecule(draft: Draft<State>, action: PredictSpectraFromMoleculeAction): void;
declare function handleFloatMoleculeOverSpectrum(draft: Draft<State>, action: ToggleMoleculeViewObjectAction): void;
declare function handleToggleMoleculeAtomsNumbers(draft: Draft<State>, action: ToggleMoleculeViewObjectAction): void;
declare function handleChangeFloatMoleculePosition(draft: Draft<State>, action: ChangeFloatMoleculePositionAction): void;
declare function handleChangeMoleculeLabel(draft: Draft<State>, action: ChangeMoleculeLabelAction): void;
export { handleAddMolecule, handleAddMolecules, handleSetMolecule, handleDeleteMolecule, handlePredictSpectraFromMolecule, handleFloatMoleculeOverSpectrum, handleToggleMoleculeAtomsNumbers, handleChangeFloatMoleculePosition, handleChangeMoleculeLabel, };
