import { Draft } from 'immer';
import { PeaksViewState, ViewState } from 'nmr-load-save';
import { Peak1D, OptionsXYAutoPeaksPicking } from 'nmr-processing';
import { FilterType } from '../../utility/filterType';
import { State } from '../Reducer';
import { ActionType } from '../types/ActionType';
type AddPeakAction = ActionType<'ADD_PEAK', {
    x: number;
}>;
type AddPeaksAction = ActionType<'ADD_PEAKS', {
    startX: number;
    endX: number;
}>;
type DeletePeakAction = ActionType<'DELETE_PEAK', {
    id?: string;
}>;
type OptimizePeaksAction = ActionType<'OPTIMIZE_PEAKS', {
    peaks: Peak1D[];
}>;
type AutoPeaksPickingAction = ActionType<'AUTO_PEAK_PICKING', {
    maxNumberOfPeaks: number;
    minMaxRatio: number;
    noiseFactor: number;
    direction: OptionsXYAutoPeaksPicking['direction'];
}>;
type ChangePeaksShapeAction = ActionType<'CHANGE_PEAK_SHAPE', {
    id: string;
    shape: Peak1D['shape'];
}>;
type TogglePeaksViewAction = ActionType<'TOGGLE_PEAKS_VIEW_PROPERTY', {
    key: keyof FilterType<PeaksViewState, boolean>;
}>;
export type PeaksActions = AddPeakAction | AddPeaksAction | DeletePeakAction | OptimizePeaksAction | AutoPeaksPickingAction | ChangePeaksShapeAction | TogglePeaksViewAction | ActionType<'TOGGLE_PEAKS_DISPLAYING_MODE'>;
declare function handleAddPeak(draft: Draft<State>, action: AddPeakAction): void;
declare function handleAddPeaks(draft: Draft<State>, action: AddPeaksAction): void;
declare function handleDeletePeak(draft: Draft<State>, action: DeletePeakAction): void;
declare function handleOptimizePeaks(draft: Draft<State>, action: OptimizePeaksAction): void;
declare function handleAutoPeakPicking(draft: Draft<State>, action: AutoPeaksPickingAction): void;
declare function handleChangePeakShape(draft: Draft<State>, action: ChangePeaksShapeAction): void;
declare function handleTogglePeaksViewProperty(draft: Draft<State>, action: TogglePeaksViewAction): void;
declare function toggleDisplayingPeaks(draft: Draft<State>, key: keyof Pick<ViewState, 'peaks' | 'ranges'>): void;
declare function handleChangePeaksDisplayingMode(draft: Draft<State>): void;
export { handleAddPeak, handleAddPeaks, handleDeletePeak, handleAutoPeakPicking, handleOptimizePeaks, handleChangePeakShape, handleTogglePeaksViewProperty, handleChangePeaksDisplayingMode, toggleDisplayingPeaks, };
