import { Draft } from 'immer';
import { RangesViewState, Spectrum } from 'nmr-load-save';
import { Signal1D, Range } from 'nmr-processing';
import { SetSumOptions } from '../../../data/data1d/Spectrum1D/SumManager';
import { ChangeRangeRelativeValueProps } from '../../../data/data1d/Spectrum1D/ranges/changeRangeRelativeValue';
import { AssignmentContext } from '../../assignment/AssignmentsContext';
import { RangeData } from '../../panels/RangesPanel/hooks/useMapRanges';
import { FilterType } from '../../utility/filterType';
import { State } from '../Reducer';
import { ActionType } from '../types/ActionType';
type AutoRangesDetectionAction = ActionType<'AUTO_RANGES_DETECTION', {
    minMaxRatio: number;
    lookNegative: boolean;
}>;
type DeleteRangeAction = ActionType<'DELETE_RANGE', {
    resetSelectTool?: boolean;
    id?: string;
    assignmentData: AssignmentContext;
}>;
type ChangeRangeSignalKindAction = ActionType<'CHANGE_RANGE_SIGNAL_KIND', {
    kind: string;
    range: RangeData;
}>;
type SaveEditedRangeAction = ActionType<'SAVE_EDITED_RANGE', {
    range: RangeData;
    assignmentData: AssignmentContext;
}>;
interface DeleteSignalProps {
    spectrum: Spectrum;
    range: Range;
    signal: Signal1D;
    assignmentData: AssignmentContext;
}
type DeleteSignalAction = ActionType<'DELETE_1D_SIGNAL', DeleteSignalProps>;
interface UnlinkRangeProps {
    range?: Range;
    signalIndex?: number;
    assignmentData: AssignmentContext;
}
type UnlinkRangeAction = ActionType<'UNLINK_RANGE', UnlinkRangeProps>;
type SetDiaIDRangeAction = ActionType<'SET_DIAID_RANGE', {
    range: Range;
    signalIndex: number;
} & Pick<Range, 'diaIDs' | 'nbAtoms'>>;
type ResizeRangeAction = ActionType<'RESIZE_RANGE', {
    range: Range;
}>;
type ChangeRangeSumAction = ActionType<'CHANGE_RANGE_SUM', {
    options: SetSumOptions;
}>;
type AddRangeAction = ActionType<'ADD_RANGE', {
    startX: number;
    endX: number;
}>;
type ChangeRangeRelativeValueAction = ActionType<'CHANGE_RANGE_RELATIVE', ChangeRangeRelativeValueProps>;
type ChangeRangeSignalValueAction = ActionType<'CHANGE_RANGE_SIGNAL_VALUE', {
    rangeID: string;
    signalID: string;
    value: number;
}>;
type UpdateRangAction = ActionType<'UPDATE_RANGE', {
    range: Range;
}>;
type CutRangAction = ActionType<'CUT_RANGE', {
    cutValue: number;
}>;
type ToggleRangesViewAction = ActionType<'TOGGLE_RANGES_VIEW_PROPERTY', {
    key: keyof FilterType<RangesViewState, boolean>;
}>;
type DeleteRangePeakAction = ActionType<'DELETE_RANGE_PEAK', {
    id: string;
}>;
export type RangesActions = AutoRangesDetectionAction | DeleteRangeAction | ChangeRangeSignalKindAction | SaveEditedRangeAction | DeleteSignalAction | UnlinkRangeAction | SetDiaIDRangeAction | ResizeRangeAction | ChangeRangeSumAction | AddRangeAction | ChangeRangeRelativeValueAction | ChangeRangeSignalValueAction | UpdateRangAction | CutRangAction | ToggleRangesViewAction | DeleteRangePeakAction | ActionType<'AUTO_RANGES_SPECTRA_PICKING' | 'CHANGE_RANGES_SUM_FLAG' | 'TOGGLE_RANGES_PEAKS_DISPLAYING_MODE'>;
declare function handleAutoRangesDetection(draft: Draft<State>, action: AutoRangesDetectionAction): void;
declare function handleAutoSpectraRangesDetection(draft: Draft<State>): void;
declare function handleDeleteRange(draft: Draft<State>, action: DeleteRangeAction): void;
declare function handleChangeRangeSignalKind(draft: Draft<State>, action: ChangeRangeSignalKindAction): void;
declare function handleSaveEditedRange(draft: Draft<State>, action: SaveEditedRangeAction): void;
declare function deleteSignal1D(draft: Draft<State>, props: DeleteSignalProps): void;
declare function handleDeleteSignal(draft: Draft<State>, action: DeleteSignalAction): void;
declare function unlinkRange(draft: Draft<State>, data: UnlinkRangeProps): void;
declare function handleUnlinkRange(draft: Draft<State>, action: UnlinkRangeAction): void;
declare function handleSetDiaIDRange(draft: Draft<State>, action: SetDiaIDRangeAction): void;
declare function handleResizeRange(draft: Draft<State>, action: ResizeRangeAction): void;
declare function handleChangeRangeSum(draft: Draft<State>, action: ChangeRangeSumAction): void;
declare function handleAddRange(draft: Draft<State>, action: AddRangeAction): void;
declare function handleChangeRangeRelativeValue(draft: any, action: ChangeRangeRelativeValueAction): void;
declare function handleChangeRangeSignalValue(draft: any, action: ChangeRangeSignalValueAction): void;
declare function handleChangeRangesSumFlag(draft: Draft<State>): void;
declare function handleUpdateRange(draft: Draft<State>, action: UpdateRangAction): void;
declare function handleToggleRangesViewProperty(draft: Draft<State>, action: ToggleRangesViewAction): void;
declare function handleCutRange(draft: Draft<State>, action: CutRangAction): void;
declare function handleChangePeaksDisplayingMode(draft: Draft<State>): void;
declare function handleDeleteRangePeak(draft: Draft<State>, action: DeleteRangePeakAction): void;
export { handleCutRange, handleAutoRangesDetection, handleDeleteRange, deleteSignal1D, handleDeleteSignal, handleChangeRangeSum, handleAddRange, handleResizeRange, handleChangeRangeRelativeValue, handleChangeRangeSignalValue, handleChangeRangeSignalKind, handleSaveEditedRange, handleUnlinkRange, unlinkRange, handleSetDiaIDRange, handleChangeRangesSumFlag, handleUpdateRange, handleAutoSpectraRangesDetection, handleToggleRangesViewProperty, handleChangePeaksDisplayingMode, handleDeleteRangePeak, };
