import { Draft } from 'immer';
import { Spectrum, Display1D, Display2D } from 'nmr-load-save';
import { NMRRange } from 'nmr-processing';
import { SpectrumSimulationOptions } from '../../../data/data1d/spectrumSimulation';
import { Nuclei, Nucleus } from '../../../data/types/common/Nucleus';
import { State } from '../Reducer';
import { ActionType } from '../types/ActionType';
type ChangeSpectrumVisibilityByIdAction = ActionType<'CHANGE_SPECTRUM_VISIBILITY', {
    id: string;
    key: 'isVisible' | 'isPositiveVisible' | 'isNegativeVisible';
}>;
type ChangeSpectraVisibilityByNucleusAction = ActionType<'CHANGE_SPECTRA_VISIBILITY_BY_NUCLEUS', {
    nucleus: Nucleus;
    flag: boolean;
}>;
type ChangeActiveSpectrumAction = ActionType<'CHANGE_ACTIVE_SPECTRUM', {
    modifier?: 'shift[false]_ctrl[true]' | 'shift[true]_ctrl[false]' | 'shift[true]_ctrl[true]' | (string & {});
    id?: string;
}>;
type ChangeSpectrumSettingAction = ActionType<'CHANGE_SPECTRUM_SETTING', {
    id: string;
    display: Display1D | Display2D;
}>;
type DeleteSpectraAction = ActionType<'DELETE_SPECTRA', {
    id?: string;
}>;
type AddMissingProjectionAction = ActionType<'ADD_MISSING_PROJECTION', {
    nucleus: Nuclei[];
}>;
type AlignSpectraAction = ActionType<'ALIGN_SPECTRA', {
    from: number;
    to: number;
    nbPeaks: number;
    targetX: number;
}>;
type GenerateSpectrumFromPublicationStringAction = ActionType<'GENERATE_SPECTRUM_FROM_PUBLICATION_STRING', {
    ranges: NMRRange[];
    info: {
        nucleus: string;
        solvent: string;
        frequency: number;
        name: string;
    };
}>;
type ImportSpectraMetaInfoAction = ActionType<'IMPORT_SPECTRA_META_INFO', {
    spectraMeta: Record<string, Record<string, any>>;
}>;
type RecolorSpectraBasedOnDistinctValueAction = ActionType<'RECOLOR_SPECTRA_COLOR', {
    jpath?: string[];
}>;
type OrderSpectraAction = ActionType<'ORDER_SPECTRA', {
    data: Spectrum[];
}>;
type SimulateSpectrumAction = ActionType<'SIMULATE_SPECTRUM', {
    keepSpectrum?: boolean;
    spinSystem: string;
} & SpectrumSimulationOptions>;
export type SpectrumActions = ActionType<'TOGGLE_SPECTRA_LEGEND'> | ChangeSpectrumVisibilityByIdAction | ChangeSpectraVisibilityByNucleusAction | ChangeActiveSpectrumAction | ChangeSpectrumSettingAction | DeleteSpectraAction | AddMissingProjectionAction | AlignSpectraAction | GenerateSpectrumFromPublicationStringAction | ImportSpectraMetaInfoAction | RecolorSpectraBasedOnDistinctValueAction | OrderSpectraAction | SimulateSpectrumAction;
declare function setSpectraMetaInfo(draft: Draft<State>, spectraMetaInfo: Record<string, Record<string, any>>): void;
declare function handleChangeSpectrumVisibilityById(draft: Draft<State>, action: ChangeSpectrumVisibilityByIdAction): void;
declare function handleChangeSpectraVisibilityByNucleus(draft: Draft<State>, action: ChangeSpectraVisibilityByNucleusAction): void;
declare function handleChangeActiveSpectrum(draft: Draft<State>, action: ChangeActiveSpectrumAction): void;
declare function handleChangeSpectrumSetting(draft: Draft<State>, action: ChangeSpectrumSettingAction): void;
declare function handleDeleteSpectra(draft: Draft<State>, action: DeleteSpectraAction): void;
declare function handleAddMissingProjectionHandler(draft: any, action: AddMissingProjectionAction): void;
declare function handleAlignSpectraHandler(draft: Draft<State>, action: AlignSpectraAction): void;
declare function handleGenerateSpectrumFromPublicationStringHandler(draft: Draft<State>, action: GenerateSpectrumFromPublicationStringAction): void;
declare function handleImportSpectraMetaInfo(draft: Draft<State>, action: ImportSpectraMetaInfoAction): void;
declare function handleToggleSpectraLegend(draft: Draft<State>): void;
declare function handleRecolorSpectraBasedOnDistinctValue(draft: Draft<State>, action: RecolorSpectraBasedOnDistinctValueAction): void;
declare function handleOrderSpectra(draft: Draft<State>, action: OrderSpectraAction): void;
declare function handleSimulateSpectrum(draft: Draft<State>, simulateSpectrumOptions: SimulateSpectrumAction): void;
export { handleChangeSpectrumVisibilityById, handleChangeSpectraVisibilityByNucleus, handleChangeActiveSpectrum, handleChangeSpectrumSetting, handleDeleteSpectra, handleAddMissingProjectionHandler, handleAlignSpectraHandler, handleGenerateSpectrumFromPublicationStringHandler, handleImportSpectraMetaInfo, handleToggleSpectraLegend, handleRecolorSpectraBasedOnDistinctValue, handleOrderSpectra, handleSimulateSpectrum, setSpectraMetaInfo, };
