import { Draft } from 'immer';
import { BaselineCorrectionZone } from 'nmr-processing';
import { Nucleus } from '../../../data/types/common/Nucleus';
import { Layout } from '../../2d/utilities/DimensionLayout';
import { Tool } from '../../toolbar/ToolTypes';
import { State } from '../Reducer';
import { ZoomType } from '../helper/Zoom1DManager';
import { ActionType } from '../types/ActionType';
import { SetDomainOptions } from './DomainActions';
interface BrushBoundary {
    startX: number;
    startY: number;
    endX: number;
    endY: number;
    trackID?: Layout | null;
}
interface SetActiveTabOptions {
    tab?: Nucleus | null;
    refreshActiveTab?: boolean;
    domainOptions?: SetDomainOptions;
}
type SetSelectedToolAction = ActionType<'SET_SELECTED_TOOL', {
    selectedTool: Tool;
}>;
type AddBaseLineZoneAction = ActionType<'ADD_BASE_LINE_ZONE', {
    startX: number;
    endX: number;
}>;
type ResizeBaseLineZoneAction = ActionType<'RESIZE_BASE_LINE_ZONE', BaselineCorrectionZone>;
type DeleteBaseLineZoneAction = ActionType<'DELETE_BASE_LINE_ZONE', {
    id: string;
}>;
type BrushEndAction = ActionType<'BRUSH_END', BrushBoundary>;
type ZoomAction = ActionType<'SET_ZOOM', {
    event: any;
    trackID?: Layout;
    selectedTool?: Tool;
}>;
type ZoomOutAction = ActionType<'FULL_ZOOM_OUT', {
    zoomType?: ZoomType;
    trackID?: Layout;
}>;
type SetActiveTabAction = ActionType<'SET_ACTIVE_TAB', {
    tab?: Nucleus;
}>;
type LevelChangeAction = ActionType<'SET_2D_LEVEL', {
    deltaY: number;
    shiftKey: boolean;
}>;
export type ToolsActions = ActionType<'TOGGLE_REAL_IMAGINARY_VISIBILITY' | 'RESET_SELECTED_TOOL' | 'SET_SPECTRUMS_VERTICAL_ALIGN' | 'CHANGE_SPECTRUM_DISPLAY_VIEW_MODE' | 'SET_SPECTRA_SAME_TOP' | 'RESET_SPECTRA_SCALE'> | SetSelectedToolAction | AddBaseLineZoneAction | DeleteBaseLineZoneAction | ResizeBaseLineZoneAction | BrushEndAction | ZoomAction | ZoomOutAction | SetActiveTabAction | LevelChangeAction;
declare function handleResetSelectedTool(draft: Draft<State>): void;
declare function resetSelectedTool(draft: Draft<State>): void;
interface ActivateToolOptions {
    toolId: Tool;
    reset?: boolean;
}
declare function activateTool(draft: Draft<State>, options: ActivateToolOptions): void;
declare function setSelectedTool(draft: Draft<State>, action: SetSelectedToolAction): void;
declare function setSpectrumsVerticalAlign(draft: Draft<State>): void;
declare function handleChangeSpectrumDisplayMode(draft: Draft<State>): void;
declare function handleAddBaseLineZone(draft: Draft<State>, action: AddBaseLineZoneAction): void;
declare function handleResizeBaseLineZone(draft: Draft<State>, action: ResizeBaseLineZoneAction): void;
declare function handleDeleteBaseLineZone(draft: Draft<State>, action: DeleteBaseLineZoneAction): void;
declare function handleToggleRealImaginaryVisibility(draft: Draft<State>): void;
declare function handleBrushEnd(draft: Draft<State>, action: BrushEndAction): void;
declare function handleZoom(draft: Draft<State>, action: ZoomAction): void;
declare function zoomOut(draft: Draft<State>, action: ZoomOutAction): void;
declare function setMargin(draft: Draft<State>): void;
declare function setTab(draft: Draft<State>, dataGroupByTab: any, tab: any, refresh?: boolean): void;
declare function setActiveTab(draft: Draft<State>, options?: SetActiveTabOptions): void;
declare function handelSetActiveTab(draft: Draft<State>, action: SetActiveTabAction): void;
declare function levelChangeHandler(draft: Draft<State>, action: LevelChangeAction): void;
declare function setSpectraSameTopHandler(draft: Draft<State>): void;
declare function resetSpectraScale(draft: Draft<State>): void;
export { handleResetSelectedTool, resetSelectedTool, setSelectedTool, activateTool, setSpectrumsVerticalAlign, handleChangeSpectrumDisplayMode, handleAddBaseLineZone, handleDeleteBaseLineZone, handleResizeBaseLineZone, handleToggleRealImaginaryVisibility, handleBrushEnd, handleZoom, zoomOut, handelSetActiveTab, levelChangeHandler, setActiveTab, setTab, setSpectraSameTopHandler, resetSpectraScale, setMargin, };
