import { FromTo } from 'cheminfo-types';
import { Draft } from 'immer';
import type { Spectrum, Spectrum2D, ZonesViewState } from 'nmr-load-save';
import type { Signal2D, Zone } from 'nmr-processing';
import { AssignmentContext, Axis } from '../../assignment/AssignmentsContext';
import { ZoneData } from '../../panels/ZonesPanel/hooks/useMapZones';
import { FilterType } from '../../utility/filterType';
import { State } from '../Reducer';
import { ZoneBoundary } from '../helper/get2DRange';
import { ActionType } from '../types/ActionType';
interface DeleteSignal2DProps {
    spectrum: Spectrum;
    zone: Zone;
    signal: Signal2D;
    assignmentData: AssignmentContext;
}
type ChangeZonesFactorAction = ActionType<'CHANGE_ZONES_NOISE_FACTOR', {
    zonesNoiseFactor: number;
}>;
type Add2dZoneAction = ActionType<'ADD_2D_ZONE', ZoneBoundary>;
type AutoZonesDetectionAction = ActionType<'AUTO_ZONES_DETECTION', {
    zonesNoiseFactor: number;
}>;
type ChangeZoneSignalDeltaAction = ActionType<'CHANGE_ZONE_SIGNAL_VALUE', {
    zoneId: string;
    signal: {
        id?: string;
        deltaX?: number;
        deltaY?: number;
    };
}>;
type ChangeZoneSignalKindAction = ActionType<'CHANGE_ZONE_SIGNAL_KIND', {
    zoneData: ZoneData;
    kind: string;
}>;
type DeleteZoneAction = ActionType<'DELETE_2D_ZONE', {
    id?: string;
    assignmentData: AssignmentContext;
}>;
type DeleteSignal2DAction = ActionType<'DELETE_2D_SIGNAL', DeleteSignal2DProps>;
type SetSignalPathLengthAction = ActionType<'SET_2D_SIGNAL_PATH_LENGTH', {
    spectrum: Spectrum2D;
    zone: Zone;
    signal: Signal2D;
    pathLength: number | FromTo | undefined;
}>;
type SetZoneDiaIDAction = ActionType<'SET_ZONE_DIAID', {
    zone: Zone;
    axis?: Axis;
    signalIndex?: number;
} & Pick<Zone['x'], 'diaIDs' | 'nbAtoms'>>;
type SaveEditedZoneAction = ActionType<'SAVE_EDITED_ZONE', {
    zone: ZoneData;
}>;
interface UnlinkZoneProps {
    zone?: ZoneData;
    assignmentData: AssignmentContext;
    isOnZoneLevel?: boolean;
    signalIndex?: number;
    axis?: Axis;
}
type UnlinkZoneAction = ActionType<'UNLINK_ZONE', UnlinkZoneProps>;
type ToggleZonesViewAction = ActionType<'TOGGLE_ZONES_VIEW_PROPERTY', {
    key: keyof FilterType<ZonesViewState, boolean>;
}>;
export type ZonesActions = AutoZonesDetectionAction | ChangeZonesFactorAction | Add2dZoneAction | ChangeZoneSignalDeltaAction | ChangeZoneSignalKindAction | DeleteZoneAction | DeleteSignal2DAction | SetSignalPathLengthAction | SetZoneDiaIDAction | SaveEditedZoneAction | UnlinkZoneAction | ToggleZonesViewAction | ActionType<'AUTO_ZONES_SPECTRA_PICKING'>;
declare function handleChangeZonesFactor(draft: Draft<State>, action: ChangeZonesFactorAction): void;
declare function handleAdd2dZone(draft: Draft<State>, action: Add2dZoneAction): void;
declare function handleAutoZonesDetection(draft: Draft<State>, action: AutoZonesDetectionAction): void;
declare function handleAutoSpectraZonesDetection(draft: Draft<State>): void;
declare function handleChangeZoneSignalDelta(draft: Draft<State>, action: ChangeZoneSignalDeltaAction): void;
declare function handleChangeZoneSignalKind(draft: Draft<State>, action: ChangeZoneSignalKindAction): void;
declare function handleDeleteZone(draft: Draft<State>, action: DeleteZoneAction): void;
declare function deleteSignal2D(draft: Draft<State>, options: DeleteSignal2DProps): void;
declare function handleDeleteSignal(draft: Draft<State>, action: DeleteSignal2DAction): void;
declare function handleSetSignalPathLength(draft: Draft<State>, action: SetSignalPathLengthAction): void;
declare function unlinkZone(draft: Draft<State>, props: UnlinkZoneProps): void;
declare function handleUnlinkZone(draft: Draft<State>, action: UnlinkZoneAction): void;
declare function handleSetDiaIDZone(draft: Draft<State>, action: SetZoneDiaIDAction): void;
declare function handleSaveEditedZone(draft: Draft<State>, action: SaveEditedZoneAction): void;
declare function handleToggleZonesViewProperty(draft: Draft<State>, action: ToggleZonesViewAction): void;
export { handleAdd2dZone, handleAutoZonesDetection, handleDeleteSignal, deleteSignal2D, handleDeleteZone, handleChangeZoneSignalDelta, handleChangeZoneSignalKind, handleUnlinkZone, unlinkZone, handleSaveEditedZone, handleSetDiaIDZone, handleSetSignalPathLength, handleChangeZonesFactor, handleAutoSpectraZonesDetection, handleToggleZonesViewProperty, };
