import { MultipleSpectraAnalysisPreferences, Workspace, WorkSpaceSource } from 'nmr-load-save';
import { Reducer } from 'react';
import { SplitPaneSize } from 'react-science/ui';
import { MatrixOptions } from '../../../data/types/data1d/MatrixOptions';
import type { NMRiumWorkspace, NMRiumPreferences } from '../../main';
import { ActionType } from '../types/ActionType';
export declare const WORKSPACES_KEYS: {
    componentKey: string;
    nmriumKey: string;
};
type InitPreferencesAction = ActionType<'INIT_PREFERENCES', {
    display: NMRiumPreferences;
    workspace: NMRiumWorkspace;
    customWorkspaces: Record<string, Workspace>;
    dispatch: any;
}>;
type SetPreferencesAction = ActionType<'SET_PREFERENCES', Partial<Workspace>> | ActionType<'SET_PREFERENCES'>;
type SetPanelsPreferencesAction = ActionType<'SET_PANELS_PREFERENCES', {
    key: string;
    value: string;
}>;
export type SetWorkspaceAction = ActionType<'SET_WORKSPACE', {
    workspaceSource: 'any';
    workspace: string;
} | {
    workspaceSource: 'nmriumFile';
    data: Workspace;
}>;
export type WorkspaceAction = ActionType<'REMOVE_WORKSPACE' | 'SET_ACTIVE_WORKSPACE', {
    workspace: string;
}>;
export type AddWorkspaceAction = ActionType<'ADD_WORKSPACE', {
    workspaceKey: string;
    data?: Omit<Workspace, 'version' | 'label'>;
}>;
export type ApplyGeneralPreferences = ActionType<'APPLY_General_PREFERENCES', {
    data: Omit<Workspace, 'version' | 'label'>;
}>;
export type AnalyzeSpectraAction = ActionType<'ANALYZE_SPECTRA', {
    start: number;
    end: number;
    nucleus: string;
    columnKey?: string;
}>;
export type ChangeAnalysisColumnValueKeyAction = ActionType<'CHANGE_ANALYSIS_COLUMN_VALUE_KEY', {
    columnKey: string;
    valueKey: string;
    nucleus: string;
}>;
export type DeleteAnalysisColumn = ActionType<'DELETE_ANALYSIS_COLUMN', {
    columnKey: string;
    nucleus: string;
}>;
export type SetSpectraAnalysisPanelPreferencesAction = ActionType<'SET_SPECTRA_ANALYSIS_PREFERENCES', {
    nucleus: string;
    data: MultipleSpectraAnalysisPreferences;
}>;
export type setMatrixGenerationOptionsAction = ActionType<'SET_MATRIX_GENERATION_OPTIONS', {
    nucleus: string;
    options: MatrixOptions;
}>;
export type addMatrixGenerationExclusionZoneAction = ActionType<'ADD_MATRIX_GENERATION_EXCLUSION_ZONE', {
    zone: {
        from: number;
        to: number;
    };
    range: {
        from: number;
        to: number;
    };
    nucleus: string;
}>;
export type deleteMatrixGenerationExclusionZoneAction = ActionType<'DELETE_MATRIX_GENERATION_EXCLUSION_ZONE', {
    zone: {
        id: string;
        from: number;
        to: number;
    };
    nucleus: string;
}>;
export type SetVerticalSplitterPositionAction = ActionType<'SET_VERTICAL_SPLITTER_POSITION', {
    value: SplitPaneSize;
}>;
type PreferencesActions = InitPreferencesAction | SetPreferencesAction | SetPanelsPreferencesAction | SetWorkspaceAction | WorkspaceAction | AddWorkspaceAction | ApplyGeneralPreferences | AnalyzeSpectraAction | ChangeAnalysisColumnValueKeyAction | DeleteAnalysisColumn | SetSpectraAnalysisPanelPreferencesAction | setMatrixGenerationOptionsAction | addMatrixGenerationExclusionZoneAction | deleteMatrixGenerationExclusionZoneAction | SetVerticalSplitterPositionAction;
export declare const WORKSPACES: Array<{
    key: NMRiumWorkspace;
    label: string;
}>;
export type WorkspaceWithSource = Workspace & {
    source: WorkSpaceSource;
};
export type WorkspacesWithSource = Record<NMRiumWorkspace, WorkspaceWithSource> | Record<string, WorkspaceWithSource>;
export interface PreferencesState {
    version: number;
    workspaces: WorkspacesWithSource;
    originalWorkspaces: WorkspacesWithSource;
    dispatch: (action?: PreferencesActions) => void;
    workspace: {
        current: NMRiumWorkspace;
        base: NMRiumWorkspace | null;
    };
}
export declare const preferencesInitialState: PreferencesState;
export declare function initPreferencesState(state: PreferencesState): PreferencesState;
declare const preferencesReducer: Reducer<PreferencesState, any>;
export default preferencesReducer;
