import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { SvgNmrAlignBottom, SvgNmrAlignCenter, SvgNmrApodization, SvgNmrBaselineCorrection, SvgNmrFourierTransform, SvgNmrIntegrate, SvgNmrMultipleAnalysis, SvgNmrOverlay3, SvgNmrOverlay3Aligned, SvgNmrPeakPicking, SvgNmrPhaseCorrection, SvgNmrRangePicking, SvgNmrRealImag, SvgNmrZeroFilling, } from 'cheminfo-font';
import { useCallback } from 'react';
import { FaSearchPlus, FaExpand, FaDiceFour, FaFileImport, FaFileExport, } from 'react-icons/fa';
import { PiKnifeBold } from 'react-icons/pi';
import { Toolbar, useOnOff } from 'react-science/ui';
import { useChartData } from '../context/ChartContext';
import { useDispatch } from '../context/DispatchContext';
import { useLoader } from '../context/LoaderContext';
import { ToolbarPopoverItem, } from '../elements/ToolbarPopoverItem';
import useCheckExperimentalFeature from '../hooks/useCheckExperimentalFeature';
import { useCheckToolsVisibility, } from '../hooks/useCheckToolsVisibility';
import useDatumWithSpectraStatistics from '../hooks/useDatumWithSpectraStatistics';
import useExport from '../hooks/useExport';
import useToolsFunctions from '../hooks/useToolsFunctions';
import { useVerticalAlign } from '../hooks/useVerticalAlign';
import ImportPublicationStringModal from '../modal/ImportPublicationStringModal';
import { LoadJCAMPModal } from '../modal/LoadJCAMPModal';
import { useMetaInformationImportationModal } from '../modal/metaImportation';
import { options } from './ToolTypes';
import { EXPORT_MENU, IMPORT_MENU } from './toolbarMenu';
function isPopoverToolItem(item) {
    return !!item?.menuItems;
}
export default function ToolBar() {
    const { toolOptions: { selectedTool }, } = useChartData();
    const isButtonVisible = useCheckToolsVisibility();
    const dispatch = useDispatch();
    const { isRealSpectrumShown, changeSpectrumViewHandler, changeDisplayViewModeHandler, alignSpectrumsVerticallyHandler, handleChangeOption, handleFullZoomOut, } = useToolsFunctions();
    const handleChange = useCallback((selectedOption) => {
        handleChangeOption(selectedOption);
    }, [handleChangeOption]);
    const openLoader = useLoader();
    const openMetaInformationModal = useMetaInformationImportationModal();
    const isExperimentalFeature = useCheckExperimentalFeature();
    const [isLoadJCAMPModalOpened, openLoadJCAMPModal, closeLoadJCAMPModal] = useOnOff(false);
    const [isPublicationStringModalOpened, openPublicationStringModal, closePublicationStringModal,] = useOnOff(false);
    const verticalAlign = useVerticalAlign();
    const { fidCounter, ftCounter } = useDatumWithSpectraStatistics();
    const importMenu = isExperimentalFeature
        ? IMPORT_MENU
        : IMPORT_MENU.filter((item) => item.id !== 'importPublicationString');
    const exportMenu = isExperimentalFeature
        ? EXPORT_MENU
        : EXPORT_MENU.filter((item) => item.id !== 'nmre');
    const handleOnFFTFilter = useCallback(() => {
        dispatch({
            type: 'APPLY_FFT_FILTER',
        });
    }, [dispatch]);
    const handleFFtDimension1Filter = useCallback(() => {
        dispatch({
            type: 'APPLY_FFT_DIMENSION_1_FILTER',
        });
    }, [dispatch]);
    const handleFFtDimension2Filter = useCallback(() => {
        dispatch({
            type: 'APPLY_FFT_DIMENSION_2_FILTER',
        });
    }, [dispatch]);
    const { saveAsSVGHandler, saveAsPNGHandler, saveAsJSONHandler, saveToClipboardHandler, saveAsHandler, } = useExport();
    function importHandler(data) {
        switch (data?.id) {
            case 'importFile':
                openLoader();
                break;
            case 'importJDX':
                openLoadJCAMPModal();
                break;
            case 'importPublicationString':
                openPublicationStringModal();
                break;
            case 'importMetaInformation':
                openMetaInformationModal();
                break;
            default:
        }
    }
    function exportHandler(data) {
        switch (data?.id) {
            case 'svg':
                void saveAsSVGHandler();
                break;
            case 'png':
                void saveAsPNGHandler();
                break;
            case 'json':
                saveAsJSONHandler();
                break;
            case 'advance_save':
                void saveAsHandler();
                break;
            case 'copy':
                void saveToClipboardHandler();
                break;
            default:
                break;
        }
    }
    const toolItems = [
        {
            id: 'zoom',
            title: options.zoom.label,
            icon: _jsx(FaSearchPlus, {}),
        },
        {
            id: 'zoomOut',
            title: 'Horizontal zoom out ( Press f ), Horizontal and Vertical zoom out, double click ( Press ff )',
            onClick: handleFullZoomOut,
            icon: _jsx(FaExpand, {}),
        },
        {
            id: 'peakPicking',
            title: `${options.peakPicking.label} ( Press p )`,
            icon: _jsx(SvgNmrPeakPicking, {}),
        },
        {
            id: 'integral',
            title: `${options.integral.label} ( Press i )`,
            icon: _jsx(SvgNmrIntegrate, {}),
        },
        {
            id: 'zonePicking',
            title: `${options.zonePicking.label} ( Press r )`,
            icon: _jsx(FaDiceFour, {}),
        },
        {
            id: 'slicing',
            title: options.slicing.label,
            icon: _jsx(PiKnifeBold, {}),
        },
        {
            id: 'rangePicking',
            title: `${options.rangePicking.label} ( Press r )`,
            icon: _jsx(SvgNmrRangePicking, {}),
        },
        {
            id: 'multipleSpectraAnalysis',
            title: options.multipleSpectraAnalysis.label,
            icon: _jsx(SvgNmrMultipleAnalysis, {}),
            checkOptions: { checkSpectrumType: false },
            condition: ftCounter > 1,
        },
        {
            id: 'apodization',
            title: `${options.apodization.label} (Press a)`,
            icon: _jsx(SvgNmrApodization, {}),
        },
        {
            id: 'zeroFilling',
            title: `${options.zeroFilling.label} ( Press z )`,
            icon: _jsx(SvgNmrZeroFilling, {}),
        },
        {
            id: 'phaseCorrection',
            title: `${options.phaseCorrection.label} ( Press a )`,
            icon: _jsx(SvgNmrPhaseCorrection, {}),
        },
        {
            id: 'phaseCorrectionTwoDimensions',
            title: `${options.phaseCorrectionTwoDimensions.label} ( Press a )`,
            icon: _jsx(SvgNmrPhaseCorrection, {}),
        },
        {
            id: 'baselineCorrection',
            title: `${options.baselineCorrection.label} ( Press b )`,
            icon: _jsx(SvgNmrBaselineCorrection, {}),
        },
        {
            id: 'exclusionZones',
            title: `${options.exclusionZones.label} ( Press e )`,
            icon: _jsx(SvgNmrMultipleAnalysis, {}),
            checkOptions: { checkSpectrumType: false },
            condition: ftCounter > 0,
        },
        {
            id: 'fft',
            title: `${options.fft.label} ( Press t )`,
            onClick: handleOnFFTFilter,
            icon: _jsx(SvgNmrFourierTransform, {}),
        },
        {
            id: 'fftDimension1',
            title: options.fftDimension1.label,
            onClick: handleFFtDimension1Filter,
            icon: _jsx(SvgNmrFourierTransform, {}),
        },
        {
            id: 'fftDimension2',
            title: options.fftDimension2.label,
            onClick: handleFFtDimension2Filter,
            icon: _jsx(SvgNmrFourierTransform, {}),
        },
        {
            id: 'import',
            title: options.import.label,
            icon: _jsx(FaFileImport, {}),
            menuItems: importMenu,
            onClick: importHandler,
        },
        {
            id: 'exportAs',
            title: options.exportAs.label,
            icon: _jsx(FaFileExport, {}),
            menuItems: exportMenu,
            onClick: exportHandler,
        },
        {
            id: 'spectraStackAlignments',
            title: `${options.spectraStackAlignments.label} ( Press s )`,
            icon: verticalAlign === 'stack' ? (_jsx(SvgNmrOverlay3Aligned, {})) : (_jsx(SvgNmrOverlay3, {})),
            condition: ftCounter > 1,
            onClick: changeDisplayViewModeHandler,
        },
        {
            id: 'realImaginary',
            title: isRealSpectrumShown ? 'Display real ' : 'Display imaginary',
            icon: _jsx(SvgNmrRealImag, {}),
            onClick: changeSpectrumViewHandler,
        },
        {
            id: 'spectraCenterAlignments',
            title: `Baseline ${verticalAlign === 'bottom' ? 'center' : 'bottom'} ( Press c )`,
            icon: verticalAlign === 'bottom' ? (_jsx(SvgNmrAlignCenter, {})) : (_jsx(SvgNmrAlignBottom, {})),
            condition: ftCounter > 0 || fidCounter > 0,
            onClick: alignSpectrumsVerticallyHandler,
        },
    ];
    return (_jsxs(_Fragment, { children: [_jsx(LoadJCAMPModal, { isOpen: isLoadJCAMPModalOpened, onCloseDialog: closeLoadJCAMPModal }), _jsx(ImportPublicationStringModal, { isOpen: isPublicationStringModalOpened, onClose: closePublicationStringModal }), _jsx(Toolbar, { vertical: true, children: toolItems.map((item) => {
                    const { id, icon, title, checkOptions, condition } = item;
                    const show = isButtonVisible(id, checkOptions) &&
                        (condition === undefined || condition);
                    if (!show)
                        return null;
                    if (isPopoverToolItem(item)) {
                        const { menuItems, onClick } = item;
                        return (_jsx(ToolbarPopoverItem, { options: menuItems, title: title, id: id, active: selectedTool === id, icon: icon, onClick: onClick }, id));
                    }
                    const { onClick } = item;
                    return (_jsx(Toolbar.Item, { onClick: onClick || (() => handleChange(id)), title: title, id: id, active: selectedTool === id, icon: icon }, id));
                }) })] }));
}
