import { Logger } from 'cheminfo-types';
import { Spectrum } from 'nmr-load-save';
import { Predicted, PredictionBase1D, PredictionBase2D } from 'nmr-processing';
export type Experiment = 'proton' | 'carbon' | 'cosy' | 'hsqc' | 'hmbc';
export type SpectraPredictionOptions = Record<Experiment, boolean>;
export type PredictedSpectraResult = Partial<Record<Experiment, PredictionBase1D | PredictionBase2D>>;
export interface PredictionOptions {
    name: string;
    frequency: number;
    '1d': {
        '1H': {
            from: number;
            to: number;
        };
        '13C': {
            from: number;
            to: number;
        };
        nbPoints: number;
        lineWidth: number;
    };
    '2d': {
        nbPoints: {
            x: number;
            y: number;
        };
    };
    autoExtendRange: boolean;
    spectra: SpectraPredictionOptions;
    logger?: Logger;
}
export declare const getDefaultPredictionOptions: () => PredictionOptions;
export declare const FREQUENCIES: Array<{
    value: number;
    label: string;
}>;
export declare function predictSpectra(molfile: string, options: any): Promise<Predicted>;
export declare function generateSpectra(predictedSpectra: PredictedSpectraResult, inputOptions: PredictionOptions, color: string, logger: Logger): Spectrum[];
