import type { FilterXYType } from 'ml-signal-processing';
interface BaseField {
    key: string;
    level: number;
    name: string;
    description: string;
}
interface Field<T> extends BaseField {
    default: T;
}
interface LabelField extends BaseField {
    type: 'label';
}
interface SelectField extends Field<any> {
    type: 'select';
    choices: any[];
}
interface StringField extends Field<string> {
    type: 'string';
}
interface NumberField extends Field<number> {
    type: 'number';
}
interface BooleanField extends Field<boolean> {
    type: 'boolean';
}
type CommonField = SelectField | StringField | NumberField | BooleanField | LabelField;
interface ListField extends Field<string[]> {
    type: 'list';
    properties: Record<string, CommonField>;
}
type Properties = ListField | SelectField | StringField | NumberField | BooleanField | LabelField;
export declare function normalCase(str: string): string;
export type MatrixProperties = Record<string, Properties>;
export interface MatrixFilter {
    name: FilterXYType['name'];
    properties: MatrixProperties;
    options: any;
}
export declare function getMatrixFilters(): MatrixFilter[];
export {};
