import { DATUM_KIND } from '../constants/signalsKinds';
export function getDiaIDs(zone, axis) {
    return [].concat(zone[axis].diaIDs || [], zone.signals
        ? zone.signals.flatMap((signal) => signal[axis].diaIDs || [])
        : []);
}
export function getNbAtoms(zone, axis) {
    let sum = 0;
    if (zone.signals) {
        for (const signal of zone.signals) {
            sum += signal[axis].nbAtoms || 0;
        }
    }
    return sum;
}
export function setNbAtoms(zone, axis) {
    zone[axis].nbAtoms = getNbAtoms(zone, axis);
    if (zone[axis].nbAtoms === 0) {
        delete zone[axis].nbAtoms;
    }
}
export function resetDiaIDs(zone, axis) {
    delete zone[axis].diaIDs;
    delete zone[axis].nbAtoms;
    for (const signal of zone.signals) {
        delete signal[axis].diaIDs;
        delete signal[axis].nbAtoms;
    }
    return zone;
}
export function checkZoneKind(zone) {
    return zone.kind === DATUM_KIND.signal;
}
export function checkSignalKinds(zone, kinds) {
    return !zone.signals.some((_signal) => _signal.kind === undefined || !kinds.includes(_signal.kind));
}
export function unlink(zone, isOnZoneLevel, signalIndex, axis) {
    if (isOnZoneLevel !== undefined && axis !== undefined) {
        if (isOnZoneLevel) {
            delete zone[axis].diaIDs;
            delete zone[axis].nbAtoms;
        }
        else if (typeof signalIndex === 'number' &&
            signalIndex !== -1 &&
            zone.signals[signalIndex]) {
            delete zone.signals[signalIndex][axis].diaIDs;
            delete zone.signals[signalIndex][axis].nbAtoms;
        }
    }
    else if (axis !== undefined) {
        resetDiaIDs(zone, axis);
        setNbAtoms(zone, axis);
    }
    else {
        for (const key of ['x', 'y']) {
            resetDiaIDs(zone, key);
            setNbAtoms(zone, key);
        }
    }
    return zone;
}
export function unlinkInAssignmentData(assignmentData, zones, axis) {
    const ids = zones.flatMap((zone) => {
        if (zone.id) {
            return zone.id;
        }
        if (zone.signals) {
            return zone.signals.map((signal) => signal.id);
        }
        return [];
    });
    if (axis) {
        assignmentData.dispatch({
            type: 'REMOVE',
            payload: { ids, axis },
        });
    }
    else {
        assignmentData.dispatch({
            type: 'REMOVE',
            payload: { ids, axis: 'x' },
        });
        assignmentData.dispatch({
            type: 'REMOVE',
            payload: { ids, axis: 'y' },
        });
    }
}
