import { ClipboardMode } from './types';
export interface CFBP {
    mode: ClipboardMode | undefined;
    label?: string;
    onDismiss: () => void;
}
export interface ClipboardFallbackProps extends CFBP, Partial<Omit<ClipboardFallbackReadProps, 'mode' | 'label' | 'onDismiss'>>, Partial<Omit<ClipboardFallbackReadTextProps, 'mode' | 'label' | 'onDismiss'>>, Partial<Omit<ClipboardFallbackWriteProps, 'mode' | 'label' | 'onDismiss'>>, Partial<Omit<ClipboardFallbackWriteTextProps, 'mode' | 'label' | 'onDismiss'>> {
}
/**
 * switch between ClipboardFallback variant over mode props
 * mode === read => ClipboardFallbackReadProps
 * mode === readText => ClipboardFallbackReadTextProps
 * mode === write => ClipboardFallbackWriteProps
 * mode === writeText => ClipboardFallbackWriteTextProps
 *
 * implement what you need in function what part of the clipboard api from useClipboard you use
 * props will be checked at runtime
 *
 * @param props
 */
export declare function ClipboardFallback(props: ClipboardFallbackProps): import("@emotion/react/jsx-runtime").JSX.Element | null;
/**
 * return null if !props.mode
 *
 * @param props
 * @see ClipboardFallback
 */
export declare function ClipboardFallbackModal(props: ClipboardFallbackProps): import("@emotion/react/jsx-runtime").JSX.Element | null;
interface ClipboardFallbackReadProps extends CFBP {
    onRead: (file: File) => void;
    mode: 'read';
}
interface ClipboardFallbackReadTextProps extends CFBP {
    onReadText: (text: string) => void;
    mode: 'readText';
}
interface ClipboardFallbackWriteProps extends CFBP {
    file: File;
    mode: 'write';
}
interface ClipboardFallbackWriteTextProps extends CFBP {
    text: string;
    mode: 'writeText';
}
export {};
