import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { Dialog, DialogBody } from '@blueprintjs/core';
import { css } from '@emotion/react';
import styled from '@emotion/styled';
import { useCallback, useEffect, useMemo, useRef } from 'react';
import Button from '../../component/elements/Button';
const ClipboardForm = styled.form `
  padding: 0.5rem;

  & > label {
    display: flex;
    flex-direction: column;
    gap: 0.5rem;
  }

  textarea {
    padding: 0.5rem;
  }
`;
const Actions = styled.div `
  display: flex;
  gap: 0.5rem;
  justify-content: flex-end;
`;
function throwError(props, prop) {
    throw new Error(`props.${prop} is mandatory with ${String(props.mode)} mode`);
}
function assertReadProps(props) {
    if (typeof props.onRead !== 'function')
        throwError(props, 'onRead');
}
function assertReadTextProps(props) {
    if (typeof props.onReadText !== 'function')
        throwError(props, 'onReadText');
}
function assertWriteProps(props) {
    if (!props.file)
        throwError(props, 'file');
    if (typeof props.onDismiss !== 'function')
        throwError(props, 'onDismiss');
}
function assertWriteTextProps(props) {
    if (typeof props.text !== 'string')
        throwError(props, 'text');
    if (typeof props.onDismiss !== 'function')
        throwError(props, 'onDismiss');
}
/**
 * switch between ClipboardFallback variant over mode props
 * mode === read => ClipboardFallbackReadProps
 * mode === readText => ClipboardFallbackReadTextProps
 * mode === write => ClipboardFallbackWriteProps
 * mode === writeText => ClipboardFallbackWriteTextProps
 *
 * implement what you need in function what part of the clipboard api from useClipboard you use
 * props will be checked at runtime
 *
 * @param props
 */
export function ClipboardFallback(props) {
    switch (props.mode) {
        case 'read':
            assertReadProps(props);
            return _jsx(ClipboardFallbackRead, { ...props });
        case 'readText':
            assertReadTextProps(props);
            return _jsx(ClipboardFallbackReadText, { ...props });
        case 'write': {
            assertWriteProps(props);
            return _jsx(ClipboardFallbackWrite, { ...props });
        }
        case 'writeText':
            assertWriteTextProps(props);
            return _jsx(ClipboardFallbackWriteText, { ...props });
        default:
            return null;
    }
}
/**
 * return null if !props.mode
 *
 * @param props
 * @see ClipboardFallback
 */
export function ClipboardFallbackModal(props) {
    if (!props.mode)
        return null;
    const titles = {
        read: `Import data from file`,
        readText: `Paste text from clipboard`,
        write: `Export data to file`,
        writeText: `Copy text from text area`,
    };
    return (_jsx(Dialog, { isOpen: true, onClose: props.onDismiss, title: titles[props.mode], children: _jsx(DialogBody, { css: css `
          padding: 0;
          background-color: white;
        `, children: _jsx(ClipboardFallback, { ...props }) }) }));
}
function ClipboardFallbackRead(props) {
    const onFileRef = useRef(props.onRead);
    onFileRef.current = props.onRead;
    const onSubmit = useCallback((event) => {
        event.preventDefault();
        const data = new FormData(event.currentTarget);
        const file = data.get('file');
        if (!(file instanceof File))
            return;
        onFileRef.current(file);
    }, []);
    if (props.mode !== 'read')
        return null;
    return (_jsxs(ClipboardForm, { onSubmit: onSubmit, children: [_jsxs("label", { children: [_jsx("span", { children: props.label ?? 'File' }), _jsx("input", { name: "file", type: "file" })] }), _jsx("p", { children: "We were not able to read from your clipboard. Please input your data in the file field" }), _jsxs(Actions, { children: [_jsx(Button.Done, { type: "submit", children: "Submit" }), _jsx(Button.Secondary, { type: "reset", onClick: props.onDismiss, children: "Cancel" })] })] }));
}
function ClipboardFallbackReadText(props) {
    const onTextRef = useRef(props.onReadText);
    onTextRef.current = props.onReadText;
    const onSubmit = useCallback((event) => {
        event.preventDefault();
        const data = new FormData(event.currentTarget);
        const text = data.get('text');
        if (typeof text !== 'string')
            return;
        onTextRef.current(text);
    }, []);
    if (props.mode !== 'readText')
        return null;
    return (_jsxs(ClipboardForm, { onSubmit: onSubmit, children: [_jsxs("label", { children: [_jsx("span", { children: props.label ?? 'Text' }), _jsx("textarea", { name: "text", cols: 50, rows: 10 })] }), _jsx("p", { children: "We were not able to read text from your clipboard. Please paste your data in the text area." }), _jsxs(Actions, { children: [_jsx(Button.Done, { type: "submit", children: "Submit" }), _jsx(Button.Secondary, { type: "reset", onClick: props.onDismiss, children: "Cancel" })] })] }));
}
function ClipboardFallbackWrite(props) {
    const onDismissRef = useRef(props.onDismiss);
    onDismissRef.current = props.onDismiss;
    const onSubmit = useCallback((event) => {
        event.preventDefault();
        onDismissRef.current();
    }, []);
    const downloadLink = useMemo(() => URL.createObjectURL(props.file), [props.file]);
    useEffect(() => {
        return () => URL.revokeObjectURL(downloadLink);
    }, [downloadLink]);
    if (props.mode !== 'write')
        return null;
    return (_jsxs(ClipboardForm, { onSubmit: onSubmit, children: [_jsx("p", { children: props.label ?? 'Download' }), _jsx("a", { href: downloadLink, download: props.file.name, children: "We were not able to write data to your clipboard. Please download your data with this link." }), _jsx(Actions, { children: _jsx(Button.Secondary, { type: "submit", children: "Dismiss" }) })] }));
}
function ClipboardFallbackWriteText(props) {
    const onDismissRef = useRef(props.onDismiss);
    onDismissRef.current = props.onDismiss;
    const onSubmit = useCallback((event) => {
        event.preventDefault();
        onDismissRef.current();
    }, []);
    if (props.mode !== 'writeText')
        return null;
    return (_jsxs(ClipboardForm, { onSubmit: onSubmit, children: [_jsx("span", { children: props.label ?? 'Text' }), _jsx("textarea", { name: "text", cols: 30, rows: 10, ref: (node) => node?.select(), children: props.text }), _jsx("p", { children: "We were not able to write text to your clipboard. Please copy your data in the text area." }), _jsx(Actions, { children: _jsx(Button.Secondary, { type: "submit", children: "Dismiss" }) })] }));
}
